
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_person_wrapper.h"

// Argument includes
#include <QString>
#include <person.h>
#include <qdatastream.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_Person_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

PersonWrapper::PersonWrapper()
{
}

PersonWrapper::PersonWrapper(const ::QString & name, const ::QString & email) : KCalendarCore::Person(name, email)
{
}

PersonWrapper::~PersonWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_KCalendarCore_Person_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_Person_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KCalendarCore::Person >()))
        return -1;

    PersonWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Person", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Person::Person()
    // 1: Person::Person(const KCalendarCore::Person&)
    // 2: Person::Person(const QString&,const QString&)
    if (numArgs == 0) {
        overloadId = 0; // Person()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 2; // Person::Person(const QString&,const QString&)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Person::Person(const KCalendarCore::Person&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Person()
        {

            // Person::Person()
            cptr = new PersonWrapper();
            break;
        }
        case 1: // Person(const KCalendarCore::Person &person)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KCalendarCore::Person *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Person::Person(const KCalendarCore::Person&)
                cptr = new PersonWrapper(*cppArg0);
            }
            break;
        }
        case 2: // Person(const QString &name, const QString &email)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Person::Person(const QString&,const QString&)
                cptr = new PersonWrapper(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< KCalendarCore::Person >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KCalendarCore_PersonFunc_email(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Person *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Person::email()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Person *>(cppSelf)->email();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_PersonFunc_fromFullName([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static Person::fromFullName(const QString&)->KCalendarCore::Person
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // static Person::fromFullName(const QString&)->KCalendarCore::Person
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromFullName", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // static Person::fromFullName(const QString&)->KCalendarCore::Person
            KCalendarCore::Person* cppResult = new KCalendarCore::Person(::KCalendarCore::Person::fromFullName(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), cppResult, true, true);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_PersonFunc_fullName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Person *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Person::fullName()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Person *>(cppSelf)->fullName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_PersonFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Person *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Person::isEmpty()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Person *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_PersonFunc_isValidEmail([[maybe_unused]] PyObject *self, PyObject *pyArg)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: static Person::isValidEmail(const QString&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // static Person::isValidEmail(const QString&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isValidEmail", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // static Person::isValidEmail(const QString&)->bool
            bool cppResult = ::KCalendarCore::Person::isValidEmail(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_PersonFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Person *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Person::name()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Person *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_PersonFunc_setEmail(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Person *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Person::setEmail(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Person::setEmail(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEmail", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Person::setEmail(const QString&)
            cppSelf->setEmail(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_PersonFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Person *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Person::setName(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Person::setName(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Person::setName(const QString&)
            cppSelf->setName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_KCalendarCore_Person_PropertyStrings[] = {
    "email::",
    "fullName:",
    "isEmpty:",
    "name::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_Person_methods[] = {
    {"email", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_PersonFunc_email), METH_NOARGS, nullptr},
    {"fromFullName", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_PersonFunc_fromFullName), METH_O|METH_STATIC, nullptr},
    {"fullName", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_PersonFunc_fullName), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_PersonFunc_isEmpty), METH_NOARGS, nullptr},
    {"isValidEmail", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_PersonFunc_isValidEmail), METH_O|METH_STATIC, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_PersonFunc_name), METH_NOARGS, nullptr},
    {"setEmail", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_PersonFunc_setEmail), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_PersonFunc_setName), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_KCalendarCore_PersonFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Person *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: Person::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // Person::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Person::operator<<(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_PersonFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Person *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: Person::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // Person::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Person::operator>>(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

// Rich comparison
static PyObject * Sbk_KCalendarCore_Person_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::KCalendarCore::Person *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), (pyArg)))) {
                // Person::operator!=(const KCalendarCore::Person&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::Person *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), (pyArg)))) {
                // Person::operator==(const KCalendarCore::Person&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::Person *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_KCalendarCore_Person_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_Person_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_Person_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_Person_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_Person_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_KCalendarCore_Person_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_Person_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_Person_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_PersonFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_PersonFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_Person_spec = {
    "1:KCalendarCore.KCalendarCore.Person",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_Person_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Person_PythonToCpp_Person_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_Person_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Person_PythonToCpp_Person_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_Person_TypeF()))
        return Person_PythonToCpp_Person_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Person_PTR_CppToPython_Person(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_Person_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::KCalendarCore::Person *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_KCalendarCore_Person_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_Person_SignatureStrings[] = {
    "2:KCalendarCore.KCalendarCore.Person(self,*:KeywordOnly=None,isEmpty:bool=None,fullName:QString=None,name:QString=None,email:QString=None)",
    "1:KCalendarCore.KCalendarCore.Person(self,person:KCalendarCore.KCalendarCore.Person,*:KeywordOnly=None,isEmpty:bool=None,fullName:QString=None,name:QString=None,email:QString=None)",
    "0:KCalendarCore.KCalendarCore.Person(self,name:QString,email:QString,*:KeywordOnly=None,isEmpty:bool=None,fullName:QString=None,name:QString=None,email:QString=None)",
    "KCalendarCore.KCalendarCore.Person.email(self)->QString",
    "KCalendarCore.KCalendarCore.Person.fromFullName(fullName:QString)->KCalendarCore.KCalendarCore.Person",
    "KCalendarCore.KCalendarCore.Person.fullName(self)->QString",
    "KCalendarCore.KCalendarCore.Person.isEmpty(self)->bool",
    "KCalendarCore.KCalendarCore.Person.isValidEmail(email:QString)->bool",
    "KCalendarCore.KCalendarCore.Person.name(self)->QString",
    "KCalendarCore.KCalendarCore.Person.setEmail(self,email:QString)",
    "KCalendarCore.KCalendarCore.Person.setName(self,name:QString)",
    "KCalendarCore.KCalendarCore.Person.__lshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.Person.__rshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.Person.__ne__(self,person:KCalendarCore.KCalendarCore.Person)->bool",
    "KCalendarCore.KCalendarCore.Person.__eq__(self,person:KCalendarCore.KCalendarCore.Person)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_Person_SignatureByteSize = 261;
static constexpr uint8_t KCalendarCore_Person_SignatureBytes[261] = {
    0x78, 0xda, 0xbd, 0x94, 0x41, 0x8b, 0xc2, 0x30, 0x10, 0x85, 0xef, 0xfb, 0x4b, 0xac, 0xb8, 0xc5,
    0xdd, 0xc3, 0x1e, 0x02, 0x7a, 0xd1, 0xee, 0x45, 0x70, 0x2d, 0x85, 0xbd, 0x86, 0x48, 0xa7, 0x1a,
    0x98, 0x24, 0x9a, 0x44, 0xa4, 0xff, 0x7e, 0xdd, 0xb4, 0x15, 0xb3, 0x22, 0x4e, 0x05, 0xf7, 0xd6,
    0x4c, 0xf2, 0xde, 0xfb, 0x32, 0x13, 0xfa, 0xce, 0x16, 0x33, 0x81, 0xa0, 0x4b, 0x61, 0x67, 0xc6,
    0x42, 0x1a, 0xaf, 0x56, 0x60, 0x9d, 0xd1, 0x03, 0x07, 0x58, 0x8d, 0x86, 0x6c, 0x01, 0xf5, 0xd1,
    0xd8, 0xf2, 0x4b, 0x63, 0x3d, 0x59, 0x1a, 0x0d, 0x23, 0xe9, 0x32, 0xb5, 0xf3, 0x35, 0x5b, 0x1b,
    0x83, 0x4d, 0xa5, 0x3a, 0x20, 0x2e, 0x85, 0x02, 0x96, 0x17, 0xde, 0x4a, 0xbd, 0x69, 0xaa, 0xfa,
    0xaa, 0x02, 0x4a, 0x48, 0x8c, 0x4a, 0xc9, 0xcb, 0x1b, 0x19, 0x65, 0x17, 0xbe, 0x09, 0xc7, 0x9f,
    0x0f, 0x3d, 0x26, 0x43, 0x5f, 0xfa, 0xc5, 0x56, 0xcf, 0xa7, 0xbc, 0xcf, 0x98, 0x06, 0x59, 0x20,
    0x4d, 0x5e, 0xa7, 0xad, 0x9a, 0xa2, 0xab, 0xac, 0x51, 0x9f, 0x2d, 0xda, 0xe0, 0x2f, 0xe3, 0xc9,
    0xea, 0xbe, 0x05, 0x29, 0xa5, 0x4b, 0xe8, 0x0f, 0xd8, 0x76, 0xb2, 0x53, 0xfe, 0x36, 0x94, 0x26,
    0xfb, 0x16, 0x28, 0xcb, 0x2c, 0xb4, 0x25, 0xea, 0x69, 0x0f, 0x13, 0xfd, 0x18, 0xb2, 0x03, 0x9f,
    0x9d, 0xc7, 0x11, 0x0f, 0x34, 0x21, 0xea, 0xcf, 0xcd, 0x8a, 0x5e, 0x08, 0x49, 0xcd, 0x39, 0xba,
    0xad, 0xac, 0x3c, 0xe7, 0x8d, 0x81, 0xf3, 0x16, 0x84, 0x62, 0xab, 0xba, 0x90, 0x25, 0x7c, 0xa4,
    0xb9, 0x0f, 0x87, 0xf3, 0xb9, 0xf0, 0xa2, 0x08, 0x5b, 0xa7, 0xcb, 0xdd, 0xde, 0xa4, 0x25, 0xda,
    0x7f, 0x4f, 0xd4, 0xd0, 0xa5, 0x91, 0xff, 0x26, 0x3d, 0x06, 0xcf, 0x39, 0xec, 0x1f, 0xf6, 0xff,
    0x01, 0x67, 0x82, 0x06, 0xd7
};
#endif

PyTypeObject *init_KCalendarCore_Person(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_KCalendarCore_Person_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Person",
        "KCalendarCore::Person*",
        &Sbk_KCalendarCore_Person_spec,
        &Shiboken::callCppDestructor< KCalendarCore::Person >,
        Sbk_KCalendarCore_Person_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_Person_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_Person_SignatureBytes, KCalendarCore_Person_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_Person_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Person_PythonToCpp_Person_PTR,
        is_Person_PythonToCpp_Person_PTR_Convertible,
        Person_PTR_CppToPython_Person);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Person");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Person*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Person&");
    Shiboken::Conversions::registerConverterAlias(converter, "Person");
    Shiboken::Conversions::registerConverterAlias(converter, "Person*");
    Shiboken::Conversions::registerConverterAlias(converter, "Person&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::Person).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(PersonWrapper).name());

    qRegisterMetaType< ::KCalendarCore::Person *>();

    return pyType;
}
