
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_icalformat_wrapper.h"

// Argument includes
#include <QString>
#include <duration.h>
#include <qbytearray.h>
#include <qtimezone.h>
#include <recurrencerule.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_ICalFormat_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

ICalFormatWrapper::ICalFormatWrapper()
{
}

ICalFormatWrapper::~ICalFormatWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_KCalendarCore_ICalFormat_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_ICalFormat_Init(PyObject *self, [[maybe_unused]] PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KCalendarCore::ICalFormat >()))
        return -1;

    ICalFormatWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // ICalFormat::ICalFormat()
        cptr = new ICalFormatWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< KCalendarCore::ICalFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KCalendarCore_ICalFormatFunc_durationFromString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::ICalFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ICalFormat::durationFromString(const QString&)const->KCalendarCore::Duration
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // ICalFormat::durationFromString(const QString&)const->KCalendarCore::Duration
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "durationFromString", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ICalFormat::durationFromString(const QString&)const->KCalendarCore::Duration
            KCalendarCore::Duration cppResult = const_cast<const ::KCalendarCore::ICalFormat *>(cppSelf)->durationFromString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Duration_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_ICalFormatFunc_fromString(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::ICalFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "fromString", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: ICalFormat::fromString(KCalendarCore::RecurrenceRule*,const QString&)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // ICalFormat::fromString(KCalendarCore::RecurrenceRule*,const QString&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromString", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::KCalendarCore::RecurrenceRule *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ICalFormat::fromString(KCalendarCore::RecurrenceRule*,const QString&)->bool
            bool cppResult = cppSelf->fromString(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_ICalFormatFunc_setTimeZone(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::ICalFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ICalFormat::setTimeZone(const QTimeZone&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArg)))) {
        overloadId = 0; // ICalFormat::setTimeZone(const QTimeZone&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTimeZone", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // ICalFormat::setTimeZone(const QTimeZone&)
            cppSelf->setTimeZone(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_ICalFormatFunc_timeZone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::ICalFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ICalFormat::timeZone()const->QTimeZone
        QTimeZone cppResult = const_cast<const ::KCalendarCore::ICalFormat *>(cppSelf)->timeZone();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_ICalFormatFunc_timeZoneId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::ICalFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ICalFormat::timeZoneId()const->QByteArray
        QByteArray cppResult = const_cast<const ::KCalendarCore::ICalFormat *>(cppSelf)->timeZoneId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_ICalFormatFunc_toString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::ICalFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ICalFormat::toString(KCalendarCore::RecurrenceRule*)->QString
    // 1: ICalFormat::toString(const KCalendarCore::Duration&)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Duration_IDX]), (pyArg)))) {
        overloadId = 1; // ICalFormat::toString(const KCalendarCore::Duration&)const->QString
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArg)))) {
        overloadId = 0; // ICalFormat::toString(KCalendarCore::RecurrenceRule*)->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "toString", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // toString(KCalendarCore::RecurrenceRule *rule)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::KCalendarCore::RecurrenceRule *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // ICalFormat::toString(KCalendarCore::RecurrenceRule*)->QString
                QString cppResult = cppSelf->toString(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // toString(const KCalendarCore::Duration &duration) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::KCalendarCore::Duration cppArg0_local;
            ::KCalendarCore::Duration *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // ICalFormat::toString(const KCalendarCore::Duration&)const->QString
                QString cppResult = const_cast<const ::KCalendarCore::ICalFormat *>(cppSelf)->toString(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_KCalendarCore_ICalFormat_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_ICalFormat_methods[] = {
    {"durationFromString", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ICalFormatFunc_durationFromString), METH_O, nullptr},
    {"fromString", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ICalFormatFunc_fromString), METH_VARARGS, nullptr},
    {"setTimeZone", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ICalFormatFunc_setTimeZone), METH_O, nullptr},
    {"timeZone", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ICalFormatFunc_timeZone), METH_NOARGS, nullptr},
    {"timeZoneId", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ICalFormatFunc_timeZoneId), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ICalFormatFunc_toString), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_KCalendarCore_ICalFormat_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_ICalFormat_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_ICalFormat_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_ICalFormat_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_ICalFormat_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_ICalFormat_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_ICalFormat_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_ICalFormat_spec = {
    "1:KCalendarCore.KCalendarCore.ICalFormat",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_ICalFormat_slots
};

} //extern "C"

static void *Sbk_KCalendarCore_ICalFormat_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::CalFormat >())
        return dynamic_cast< ::KCalendarCore::ICalFormat *>(reinterpret_cast< ::KCalendarCore::CalFormat *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void ICalFormat_PythonToCpp_ICalFormat_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_ICalFormat_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_ICalFormat_PythonToCpp_ICalFormat_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_ICalFormat_TypeF()))
        return ICalFormat_PythonToCpp_ICalFormat_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *ICalFormat_PTR_CppToPython_ICalFormat(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_ICalFormat_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::KCalendarCore::ICalFormat *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_KCalendarCore_ICalFormat_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_ICalFormat_SignatureStrings[] = {
    "KCalendarCore.KCalendarCore.ICalFormat(self)",
    "KCalendarCore.KCalendarCore.ICalFormat.durationFromString(self,duration:QString)->KCalendarCore.KCalendarCore.Duration",
    "KCalendarCore.KCalendarCore.ICalFormat.fromString(self,rule:KCalendarCore.KCalendarCore.RecurrenceRule,string:QString)->bool",
    "KCalendarCore.KCalendarCore.ICalFormat.setTimeZone(self,timeZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "KCalendarCore.KCalendarCore.ICalFormat.timeZone(self)->PySide6.QtCore.QTimeZone",
    "KCalendarCore.KCalendarCore.ICalFormat.timeZoneId(self)->PySide6.QtCore.QByteArray",
    "1:KCalendarCore.KCalendarCore.ICalFormat.toString(self,rule:KCalendarCore.KCalendarCore.RecurrenceRule)->QString",
    "0:KCalendarCore.KCalendarCore.ICalFormat.toString(self,duration:typing.Union[KCalendarCore.KCalendarCore.Duration, int])->QString",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_ICalFormat_SignatureByteSize = 230;
static constexpr uint8_t KCalendarCore_ICalFormat_SignatureBytes[230] = {
    0x78, 0xda, 0xa5, 0x52, 0xbd, 0x0e, 0x82, 0x30, 0x10, 0xde, 0x79, 0x0a, 0x47, 0x4d, 0xb0, 0xd1,
    0xc5, 0x81, 0xc1, 0xc4, 0x9f, 0x98, 0x10, 0x16, 0x11, 0x5d, 0x34, 0x0e, 0x15, 0x0e, 0xd3, 0xa4,
    0xb4, 0xe6, 0x38, 0x06, 0x7c, 0x7a, 0x1b, 0x40, 0x03, 0x26, 0x98, 0xaa, 0xe3, 0x5d, 0xef, 0xfb,
    0xb9, 0x7e, 0x17, 0xac, 0xb8, 0x04, 0x95, 0x70, 0x5c, 0x69, 0x04, 0x16, 0x74, 0x2a, 0xdf, 0x54,
    0x1b, 0x8d, 0x19, 0xa7, 0x61, 0x0e, 0x32, 0x1d, 0x39, 0x81, 0xd5, 0x30, 0x4b, 0x0a, 0xe4, 0x24,
    0xb4, 0xda, 0xa0, 0xce, 0x22, 0x42, 0xa1, 0xae, 0x15, 0xde, 0x7d, 0xf6, 0xbd, 0xb0, 0xee, 0x8e,
    0xc6, 0xf3, 0x4f, 0x8c, 0xeb, 0x66, 0xdc, 0x56, 0x36, 0x7d, 0x93, 0xc3, 0x42, 0x82, 0xf7, 0x09,
    0xbb, 0x83, 0xb8, 0x40, 0x04, 0x15, 0xc3, 0xce, 0x8c, 0xba, 0x79, 0x85, 0x6d, 0x99, 0xbb, 0x68,
    0x2d, 0x6d, 0xc5, 0x73, 0xa0, 0xbd, 0xc8, 0xe0, 0xa8, 0x15, 0xd4, 0xea, 0xd4, 0x54, 0x1e, 0x95,
    0x37, 0x43, 0xc7, 0x0e, 0xca, 0xac, 0x72, 0xda, 0x96, 0x91, 0x48, 0x60, 0xc6, 0x42, 0xaa, 0x08,
    0xc2, 0x27, 0xc6, 0x1d, 0xf4, 0xbd, 0x30, 0x5f, 0x09, 0x12, 0x5c, 0x8a, 0x7b, 0xf5, 0x19, 0x67,
    0xeb, 0x14, 0xa8, 0x6d, 0xc7, 0x6c, 0xd3, 0x27, 0xf0, 0x2d, 0x9f, 0x9f, 0xf4, 0x31, 0x2e, 0x4b,
    0x82, 0x05, 0x22, 0x2f, 0x9d, 0xa9, 0x67, 0x4b, 0xaa, 0xff, 0x48, 0xcc, 0x58, 0x68, 0xc2, 0x72,
    0x26, 0xbf, 0x09, 0xbe, 0x2e, 0xb2, 0x13, 0x92, 0xcd, 0x51, 0xba, 0x03, 0xa1, 0xe8, 0xdc, 0x72,
    0xf0, 0x00, 0xd8, 0x4a, 0x32, 0xae
};
#endif

PyTypeObject *init_KCalendarCore_ICalFormat(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_ICalFormat_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CalFormat_IDX]));
    Shiboken::AutoDecRef Sbk_KCalendarCore_ICalFormat_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "ICalFormat",
        "KCalendarCore::ICalFormat*",
        &Sbk_KCalendarCore_ICalFormat_spec,
        &Shiboken::callCppDestructor< KCalendarCore::ICalFormat >,
        Sbk_KCalendarCore_ICalFormat_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_ICalFormat_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_ICalFormat_SignatureBytes, KCalendarCore_ICalFormat_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_ICalFormat_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        ICalFormat_PythonToCpp_ICalFormat_PTR,
        is_ICalFormat_PythonToCpp_ICalFormat_PTR_Convertible,
        ICalFormat_PTR_CppToPython_ICalFormat);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::ICalFormat");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::ICalFormat*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::ICalFormat&");
    Shiboken::Conversions::registerConverterAlias(converter, "ICalFormat");
    Shiboken::Conversions::registerConverterAlias(converter, "ICalFormat*");
    Shiboken::Conversions::registerConverterAlias(converter, "ICalFormat&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::ICalFormat).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(ICalFormatWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_KCalendarCore_ICalFormat_typeDiscovery);

    qRegisterMetaType< ::KCalendarCore::ICalFormat *>();

    return pyType;
}
