
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_todo_wrapper.h"

// Wrappers providing overrides
#include "kcalendarcore_incidencebase_wrapper.h"
#include "kcalendarcore_customproperties_wrapper.h"
#include "kcalendarcore_recurrence_recurrenceobserver_wrapper.h"
#include "kcalendarcore_incidence_wrapper.h"

// Argument includes
#include <QList>
#include <QtCore/qlatin1stringview.h>
#include <duration.h>
#include <incidence.h>
#include <incidencebase.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qtimezone.h>
#include <recurrence.h>
#include <todo.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_Todo_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void TodoWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

TodoWrapper::TodoWrapper()
{
}

TodoWrapper::TodoWrapper(const ::KCalendarCore::Incidence & other) : KCalendarCore::Todo(other)
{
}

::KCalendarCore::Todo * TodoWrapper::clone() const
{
    static const char *funcName = "clone";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::clone();
    }
    return sbk_o_clone("Todo", funcName, gil, pyOverride);
}

::KCalendarCore::Todo * TodoWrapper::sbk_o_clone([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< KCalendarCore::Todo >()), Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::KCalendarCore::Todo *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void TodoWrapper::customPropertyUpdate()
{
    static const char *funcName = "customPropertyUpdate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::customPropertyUpdate();
    }
    CustomPropertiesWrapper::sbk_o_customPropertyUpdate("Todo", funcName, gil, pyOverride);
}

void TodoWrapper::customPropertyUpdated()
{
    static const char *funcName = "customPropertyUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::customPropertyUpdated();
    }
    CustomPropertiesWrapper::sbk_o_customPropertyUpdate("Todo", funcName, gil, pyOverride);
}

::QDateTime TodoWrapper::dateTime(::KCalendarCore::IncidenceBase::DateTimeRole role) const
{
    static const char *funcName = "dateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::dateTime(role);
    }
    return IncidenceBaseWrapper::sbk_o_dateTime("Todo", funcName, gil, pyOverride, role);
}

::QDateTime TodoWrapper::dtStart() const
{
    static const char *funcName = "dtStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::dtStart();
    }
    return IncidenceBaseWrapper::sbk_o_dtStart("Todo", funcName, gil, pyOverride);
}

::QDateTime TodoWrapper::endDateForStart(const ::QDateTime & startDt) const
{
    static const char *funcName = "endDateForStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::endDateForStart(startDt);
    }
    return IncidenceWrapper::sbk_o_endDateForStart("Todo", funcName, gil, pyOverride, startDt);
}

bool TodoWrapper::equals(const ::KCalendarCore::IncidenceBase & todo) const
{
    static const char *funcName = "equals";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::equals(todo);
    }
    return IncidenceBaseWrapper::sbk_o_equals("Todo", funcName, gil, pyOverride, todo);
}

::QLatin1String TodoWrapper::iconName(const ::QDateTime & recurrenceId) const
{
    static const char *funcName = "iconName";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::iconName(recurrenceId);
    }
    return IncidenceWrapper::sbk_o_iconName("Todo", funcName, gil, pyOverride, recurrenceId);
}

::QLatin1String TodoWrapper::mimeType() const
{
    static const char *funcName = "mimeType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::mimeType();
    }
    return IncidenceBaseWrapper::sbk_o_mimeType("Todo", funcName, gil, pyOverride);
}

::QDateTime TodoWrapper::recurrenceId() const
{
    static const char *funcName = "recurrenceId";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::recurrenceId();
    }
    return IncidenceBaseWrapper::sbk_o_dtStart("Todo", funcName, gil, pyOverride);
}

void TodoWrapper::recurrenceUpdated(::KCalendarCore::Recurrence * recurrence)
{
    static const char *funcName = "recurrenceUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::recurrenceUpdated(recurrence);
    }
    RecurrenceObserverWrapper::sbk_o_recurrenceUpdated("Todo", funcName, gil, pyOverride, recurrence);
}

bool TodoWrapper::recursOn(const ::QDate & date, const ::QTimeZone & timeZone) const
{
    static const char *funcName = "recursOn";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::recursOn(date, timeZone);
    }
    return IncidenceWrapper::sbk_o_recursOn("Todo", funcName, gil, pyOverride, date, timeZone);
}

void TodoWrapper::setAllDay(bool allDay)
{
    static const char *funcName = "setAllDay";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::setAllDay(allDay);
    }
    IncidenceBaseWrapper::sbk_o_setAllDay("Todo", funcName, gil, pyOverride, allDay);
}

void TodoWrapper::setDateTime(const ::QDateTime & dateTime, ::KCalendarCore::IncidenceBase::DateTimeRole role)
{
    static const char *funcName = "setDateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::setDateTime(dateTime, role);
    }
    IncidenceBaseWrapper::sbk_o_setDateTime("Todo", funcName, gil, pyOverride, dateTime, role);
}

void TodoWrapper::setDtStart(const ::QDateTime & dt)
{
    static const char *funcName = "setDtStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::setDtStart(dt);
    }
    IncidenceBaseWrapper::sbk_o_setDtStart("Todo", funcName, gil, pyOverride, dt);
}

void TodoWrapper::setDuration(const ::KCalendarCore::Duration & duration)
{
    static const char *funcName = "setDuration";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::setDuration(duration);
    }
    IncidenceBaseWrapper::sbk_o_setDuration("Todo", funcName, gil, pyOverride, duration);
}

void TodoWrapper::setLastModified(const ::QDateTime & lm)
{
    static const char *funcName = "setLastModified";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::setLastModified(lm);
    }
    IncidenceBaseWrapper::sbk_o_setDtStart("Todo", funcName, gil, pyOverride, lm);
}

void TodoWrapper::setReadOnly(bool readonly)
{
    static const char *funcName = "setReadOnly";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::setReadOnly(readonly);
    }
    IncidenceBaseWrapper::sbk_o_setAllDay("Todo", funcName, gil, pyOverride, readonly);
}

void TodoWrapper::shiftTimes(const ::QTimeZone & oldZone, const ::QTimeZone & newZone)
{
    static const char *funcName = "shiftTimes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::shiftTimes(oldZone, newZone);
    }
    IncidenceBaseWrapper::sbk_o_shiftTimes("Todo", funcName, gil, pyOverride, oldZone, newZone);
}

::QList<QDateTime> TodoWrapper::startDateTimesForDate(const ::QDate & date, const ::QTimeZone & timeZone) const
{
    static const char *funcName = "startDateTimesForDate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::startDateTimesForDate(date, timeZone);
    }
    return IncidenceWrapper::sbk_o_startDateTimesForDate("Todo", funcName, gil, pyOverride, date, timeZone);
}

::QList<QDateTime> TodoWrapper::startDateTimesForDateTime(const ::QDateTime & datetime) const
{
    static const char *funcName = "startDateTimesForDateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::startDateTimesForDateTime(datetime);
    }
    return IncidenceWrapper::sbk_o_startDateTimesForDateTime("Todo", funcName, gil, pyOverride, datetime);
}

bool TodoWrapper::supportsGroupwareCommunication() const
{
    static const char *funcName = "supportsGroupwareCommunication";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::supportsGroupwareCommunication();
    }
    return IncidenceWrapper::sbk_o_supportsGroupwareCommunication("Todo", funcName, gil, pyOverride);
}

::KCalendarCore::IncidenceBase::IncidenceType TodoWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::type();
    }
    return IncidenceBaseWrapper::sbk_o_type("Todo", funcName, gil, pyOverride);
}

::QByteArray TodoWrapper::typeStr() const
{
    static const char *funcName = "typeStr";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::typeStr();
    }
    return IncidenceBaseWrapper::sbk_o_typeStr("Todo", funcName, gil, pyOverride);
}

void TodoWrapper::virtual_hook(::KCalendarCore::IncidenceBase::VirtualHook id, void * data)
{
    static const char *funcName = "virtual_hook";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Todo_TypeF(), gil, funcName, m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Todo::virtual_hook(id, data);
    }
    IncidenceBaseWrapper::sbk_o_virtual_hook("Todo", funcName, gil, pyOverride, id, data);
}

TodoWrapper::~TodoWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_KCalendarCore_Todo_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_Todo_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KCalendarCore::Todo >()))
        return -1;

    TodoWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Todo", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Todo::Todo()
    // 1: Todo::Todo(const KCalendarCore::Incidence&)
    // 2: Todo::Todo(const KCalendarCore::Todo&)
    if (numArgs == 0) {
        overloadId = 0; // Todo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), (pyArgs[0])))) {
        overloadId = 2; // Todo::Todo(const KCalendarCore::Todo&)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Todo::Todo(const KCalendarCore::Incidence&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Todo()
        {

            // Todo::Todo()
            cptr = new TodoWrapper();
            break;
        }
        case 1: // Todo(const KCalendarCore::Incidence &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KCalendarCore::Incidence *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Todo::Todo(const KCalendarCore::Incidence&)
                cptr = new TodoWrapper(*cppArg0);
            }
            break;
        }
        case 2: // Todo(const KCalendarCore::Todo &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KCalendarCore::Todo *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Todo::Todo(const KCalendarCore::Todo&)
                cptr = new TodoWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< KCalendarCore::Todo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KCalendarCore_TodoFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::clone()const->KCalendarCore::Todo*
        KCalendarCore::Todo * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Todo *>(cppSelf)->::KCalendarCore::Todo::clone()
            : const_cast<const ::KCalendarCore::Todo *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_completed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Todo::completed()const->QDateTime
        QDateTime cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->completed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_dateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), (pyArg)))) {
        overloadId = 0; // IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        ::KCalendarCore::IncidenceBase::DateTimeRole cppArg0{KCalendarCore::IncidenceBase::RoleAlarmStartOffset};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
            QDateTime cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Todo *>(cppSelf)->::KCalendarCore::Todo::dateTime(cppArg0)
                : const_cast<const ::KCalendarCore::Todo *>(cppSelf)->dateTime(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_deserialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::deserialize(QDataStream&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::deserialize(QDataStream&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deserialize", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("deserialize(QDataStream &in)");
        return {};
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_TodoFunc_dtDue(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "dtDue", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    if (PyArg_ParseTuple(args, "|O:dtDue", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Todo::dtDue(bool=)const->QDateTime
    if (numArgs == 0) {
        overloadId = 0; // dtDue(bool)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // Todo::dtDue(bool=)const->QDateTime
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dtDue", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"first", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "dtDue", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);
            }
        }
        bool cppArg0 = false;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Todo::dtDue(bool=)const->QDateTime
            QDateTime cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->dtDue(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_dtRecurrence(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Todo::dtRecurrence()const->QDateTime
        QDateTime cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->dtRecurrence();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_dtStart(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dtStart", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::dtStart()const->QDateTime
    // 1: Todo::dtStart(bool)const->QDateTime
    if (numArgs == 0) {
        overloadId = 0; // dtStart()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 1; // Todo::dtStart(bool)const->QDateTime
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dtStart", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // dtStart() const
        {

            // IncidenceBase::dtStart()const->QDateTime
            QDateTime cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Todo *>(cppSelf)->::KCalendarCore::Todo::dtStart()
                : const_cast<const ::KCalendarCore::Todo *>(cppSelf)->dtStart();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            break;
        }
        case 1: // dtStart(bool first) const
        {
            bool cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Todo::dtStart(bool)const->QDateTime
                QDateTime cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->dtStart(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_equals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "equals", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::IncidenceBase *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Todo *>(cppSelf)->::KCalendarCore::Todo::equals(*cppArg0)
                : const_cast<const ::KCalendarCore::Todo *>(cppSelf)->equals(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_hasCompletedDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Todo::hasCompletedDate()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->hasCompletedDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_hasDueDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Todo::hasDueDate()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->hasDueDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_hasStartDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Todo::hasStartDate()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->hasStartDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_iconName(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "iconName", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    if (PyArg_ParseTuple(args, "|O:iconName", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::iconName(const QDateTime&=)const->QLatin1String
    if (numArgs == 0) {
        overloadId = 0; // iconName(QDateTime)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))) {
        overloadId = 0; // Incidence::iconName(const QDateTime&=)const->QLatin1String
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "iconName", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"recurrenceId", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "iconName", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local{};
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::iconName(const QDateTime&=)const->QLatin1String
            QLatin1String cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Todo *>(cppSelf)->::KCalendarCore::Todo::iconName(*cppArg0)
                : const_cast<const ::KCalendarCore::Todo *>(cppSelf)->iconName(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_isCompleted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Todo::isCompleted()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->isCompleted();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_isInProgress(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Todo::isInProgress(bool)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Todo::isInProgress(bool)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isInProgress", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Todo::isInProgress(bool)const->bool
            bool cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->isInProgress(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_isNotStarted(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Todo::isNotStarted(bool)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Todo::isNotStarted(bool)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isNotStarted", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Todo::isNotStarted(bool)const->bool
            bool cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->isNotStarted(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_isOpenEnded(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Todo::isOpenEnded()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->isOpenEnded();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_isOverdue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Todo::isOverdue()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->isOverdue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_mimeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::mimeType()const->QLatin1String
        QLatin1String cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Todo *>(cppSelf)->::KCalendarCore::Todo::mimeType()
            : const_cast<const ::KCalendarCore::Todo *>(cppSelf)->mimeType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_percentComplete(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Todo::percentComplete()const->int
        int cppResult = const_cast<const ::KCalendarCore::Todo *>(cppSelf)->percentComplete();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_recursOn(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "recursOn", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::recursOn(const QDate&,const QTimeZone&)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // Incidence::recursOn(const QDate&,const QTimeZone&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "recursOn", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0_local;
        ::QDate *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::recursOn(const QDate&,const QTimeZone&)const->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Todo *>(cppSelf)->::KCalendarCore::Todo::recursOn(*cppArg0, *cppArg1)
                : const_cast<const ::KCalendarCore::Todo *>(cppSelf)->recursOn(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_serialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::serialize(QDataStream&)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::serialize(QDataStream&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "serialize", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("serialize(QDataStream &out) const");
        return {};
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_TodoFunc_setAllDay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setAllDay(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setAllDay(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAllDay", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setAllDay(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Todo::setAllDay(cppArg0)
                : cppSelf->setAllDay(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_TodoFunc_setCompleted(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Todo::setCompleted(bool)
    // 1: Todo::setCompleted(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 1; // Todo::setCompleted(const QDateTime&)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Todo::setCompleted(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCompleted", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setCompleted(bool completed)
        {
            bool cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Todo::setCompleted(bool)
                cppSelf->setCompleted(cppArg0);
            }
            break;
        }
        case 1: // setCompleted(const QDateTime &completeDate)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Todo::setCompleted(const QDateTime&)
                cppSelf->setCompleted(*cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_TodoFunc_setDateTime(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDateTime", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::KCalendarCore::IncidenceBase::DateTimeRole cppArg1{KCalendarCore::IncidenceBase::RoleAlarmStartOffset};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Todo::setDateTime(*cppArg0, cppArg1)
                : cppSelf->setDateTime(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_TodoFunc_setDtDue(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setDtDue", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setDtDue", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Todo::setDtDue(const QDateTime&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setDtDue(QDateTime,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // Todo::setDtDue(const QDateTime&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDtDue", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"first", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setDtDue", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = false;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Todo::setDtDue(const QDateTime&,bool=)
            cppSelf->setDtDue(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_TodoFunc_setDtRecurrence(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Todo::setDtRecurrence(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Todo::setDtRecurrence(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDtRecurrence", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Todo::setDtRecurrence(const QDateTime&)
            cppSelf->setDtRecurrence(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_TodoFunc_setPercentComplete(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Todo::setPercentComplete(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Todo::setPercentComplete(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPercentComplete", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Todo::setPercentComplete(int)
            cppSelf->setPercentComplete(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_TodoFunc_shiftTimes(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "shiftTimes", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "shiftTimes", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Todo::shiftTimes(*cppArg0, *cppArg1)
                : cppSelf->shiftTimes(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_TodoFunc_supportsGroupwareCommunication(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::supportsGroupwareCommunication()const->bool
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Todo *>(cppSelf)->::KCalendarCore::Todo::supportsGroupwareCommunication()
            : const_cast<const ::KCalendarCore::Todo *>(cppSelf)->supportsGroupwareCommunication();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_todoMimeType([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static Todo::todoMimeType()->QLatin1String
        QLatin1String cppResult = ::KCalendarCore::Todo::todoMimeType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::type()const->KCalendarCore::IncidenceBase::IncidenceType
        KCalendarCore::IncidenceBase::IncidenceType cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Todo *>(cppSelf)->::KCalendarCore::Todo::type()
            : const_cast<const ::KCalendarCore::Todo *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceType_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_typeStr(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::typeStr()const->QByteArray
        QByteArray cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Todo *>(cppSelf)->::KCalendarCore::Todo::typeStr()
            : const_cast<const ::KCalendarCore::Todo *>(cppSelf)->typeStr();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_TodoFunc_virtual_hook(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "virtual_hook", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_VirtualHook_IDX]))), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "virtual_hook", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]);

    // Call function/method
    {
        ::KCalendarCore::IncidenceBase::VirtualHook cppArg0 = static_cast< ::KCalendarCore::IncidenceBase::VirtualHook>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        void* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Todo::virtual_hook(cppArg0, cppArg1)
                : cppSelf->virtual_hook(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_KCalendarCore_Todo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_Todo_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_clone), METH_NOARGS, nullptr},
    {"completed", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_completed), METH_NOARGS, nullptr},
    {"dateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_dateTime), METH_O, nullptr},
    {"deserialize", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_deserialize), METH_O, nullptr},
    {"dtDue", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_dtDue), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"dtRecurrence", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_dtRecurrence), METH_NOARGS, nullptr},
    {"dtStart", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_dtStart), METH_VARARGS, nullptr},
    {"equals", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_equals), METH_O, nullptr},
    {"hasCompletedDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_hasCompletedDate), METH_NOARGS, nullptr},
    {"hasDueDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_hasDueDate), METH_NOARGS, nullptr},
    {"hasStartDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_hasStartDate), METH_NOARGS, nullptr},
    {"iconName", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_iconName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isCompleted", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_isCompleted), METH_NOARGS, nullptr},
    {"isInProgress", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_isInProgress), METH_O, nullptr},
    {"isNotStarted", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_isNotStarted), METH_O, nullptr},
    {"isOpenEnded", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_isOpenEnded), METH_NOARGS, nullptr},
    {"isOverdue", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_isOverdue), METH_NOARGS, nullptr},
    {"mimeType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_mimeType), METH_NOARGS, nullptr},
    {"percentComplete", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_percentComplete), METH_NOARGS, nullptr},
    {"recursOn", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_recursOn), METH_VARARGS, nullptr},
    {"serialize", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_serialize), METH_O, nullptr},
    {"setAllDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_setAllDay), METH_O, nullptr},
    {"setCompleted", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_setCompleted), METH_O, nullptr},
    {"setDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_setDateTime), METH_VARARGS, nullptr},
    {"setDtDue", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_setDtDue), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setDtRecurrence", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_setDtRecurrence), METH_O, nullptr},
    {"setPercentComplete", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_setPercentComplete), METH_O, nullptr},
    {"shiftTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_shiftTimes), METH_VARARGS, nullptr},
    {"supportsGroupwareCommunication", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_supportsGroupwareCommunication), METH_NOARGS, nullptr},
    {"todoMimeType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_todoMimeType), METH_NOARGS|METH_STATIC, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_type), METH_NOARGS, nullptr},
    {"typeStr", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_typeStr), METH_NOARGS, nullptr},
    {"virtual_hook", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_TodoFunc_virtual_hook), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_KCalendarCore_Todo_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::KCalendarCore::Todo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<TodoWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_KCalendarCore_Todo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_Todo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_KCalendarCore_TodoSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::KCalendarCore::Todo *>(obj);
    if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]))
        return static_cast< ::KCalendarCore::Incidence *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]))
        return static_cast< ::KCalendarCore::IncidenceBase *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]))
        return static_cast< ::KCalendarCore::CustomProperties *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_RecurrenceObserver_IDX]))
        return static_cast< ::KCalendarCore::Recurrence::RecurrenceObserver *>(me);
    return me;
}



// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_Todo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_KCalendarCore_Todo_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_Todo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_Todo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_Todo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_Todo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_Todo_spec = {
    "1:KCalendarCore.KCalendarCore.Todo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_Todo_slots
};

} //extern "C"

static void *Sbk_KCalendarCore_Todo_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::CustomProperties >())
        return dynamic_cast< ::KCalendarCore::Todo *>(reinterpret_cast< ::KCalendarCore::CustomProperties *>(cptr));
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::Recurrence::RecurrenceObserver >())
        return dynamic_cast< ::KCalendarCore::Todo *>(reinterpret_cast< ::KCalendarCore::Recurrence::RecurrenceObserver *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Todo_PythonToCpp_Todo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_Todo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Todo_PythonToCpp_Todo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_Todo_TypeF()))
        return Todo_PythonToCpp_Todo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Todo_PTR_CppToPython_Todo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_Todo_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::KCalendarCore::Todo *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_KCalendarCore_Todo_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_Todo_SignatureStrings[] = {
    "2:KCalendarCore.KCalendarCore.Todo(self)",
    "1:KCalendarCore.KCalendarCore.Todo(self,other:KCalendarCore.KCalendarCore.Incidence)",
    "0:KCalendarCore.KCalendarCore.Todo(self,other:KCalendarCore.KCalendarCore.Todo)",
    "KCalendarCore.KCalendarCore.Todo.clone(self)->KCalendarCore.KCalendarCore.Todo",
    "KCalendarCore.KCalendarCore.Todo.completed(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Todo.dateTime(self,role:KCalendarCore.KCalendarCore.IncidenceBase.DateTimeRole)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Todo.deserialize(self,in:PySide6.QtCore.QDataStream)",
    "KCalendarCore.KCalendarCore.Todo.dtDue(self,first:bool=false)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Todo.dtRecurrence(self)->PySide6.QtCore.QDateTime",
    "1:KCalendarCore.KCalendarCore.Todo.dtStart(self)->PySide6.QtCore.QDateTime",
    "0:KCalendarCore.KCalendarCore.Todo.dtStart(self,first:bool)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Todo.equals(self,todo:KCalendarCore.KCalendarCore.IncidenceBase)->bool",
    "KCalendarCore.KCalendarCore.Todo.hasCompletedDate(self)->bool",
    "KCalendarCore.KCalendarCore.Todo.hasDueDate(self)->bool",
    "KCalendarCore.KCalendarCore.Todo.hasStartDate(self)->bool",
    "KCalendarCore.KCalendarCore.Todo.iconName(self,recurrenceId:PySide6.QtCore.QDateTime={})->QLatin1String",
    "KCalendarCore.KCalendarCore.Todo.isCompleted(self)->bool",
    "KCalendarCore.KCalendarCore.Todo.isInProgress(self,first:bool)->bool",
    "KCalendarCore.KCalendarCore.Todo.isNotStarted(self,first:bool)->bool",
    "KCalendarCore.KCalendarCore.Todo.isOpenEnded(self)->bool",
    "KCalendarCore.KCalendarCore.Todo.isOverdue(self)->bool",
    "KCalendarCore.KCalendarCore.Todo.mimeType(self)->QLatin1String",
    "KCalendarCore.KCalendarCore.Todo.percentComplete(self)->int",
    "KCalendarCore.KCalendarCore.Todo.recursOn(self,date:PySide6.QtCore.QDate,timeZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->bool",
    "KCalendarCore.KCalendarCore.Todo.serialize(self,out:PySide6.QtCore.QDataStream)",
    "KCalendarCore.KCalendarCore.Todo.setAllDay(self,allDay:bool)",
    "1:KCalendarCore.KCalendarCore.Todo.setCompleted(self,completed:bool)",
    "0:KCalendarCore.KCalendarCore.Todo.setCompleted(self,completeDate:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.Todo.setDateTime(self,dateTime:PySide6.QtCore.QDateTime,role:KCalendarCore.KCalendarCore.IncidenceBase.DateTimeRole)",
    "KCalendarCore.KCalendarCore.Todo.setDtDue(self,dtDue:PySide6.QtCore.QDateTime,first:bool=false)",
    "KCalendarCore.KCalendarCore.Todo.setDtRecurrence(self,dt:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.Todo.setPercentComplete(self,percent:int)",
    "KCalendarCore.KCalendarCore.Todo.shiftTimes(self,oldZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization],newZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "KCalendarCore.KCalendarCore.Todo.supportsGroupwareCommunication(self)->bool",
    "KCalendarCore.KCalendarCore.Todo.todoMimeType()->QLatin1String",
    "KCalendarCore.KCalendarCore.Todo.type(self)->KCalendarCore.KCalendarCore.IncidenceBase.IncidenceType",
    "KCalendarCore.KCalendarCore.Todo.typeStr(self)->PySide6.QtCore.QByteArray",
    "KCalendarCore.KCalendarCore.Todo.virtual_hook(self,id:KCalendarCore.KCalendarCore.IncidenceBase.VirtualHook,data:void)",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_Todo_SignatureByteSize = 592;
static constexpr uint8_t KCalendarCore_Todo_SignatureBytes[592] = {
    0x78, 0xda, 0xb5, 0x56, 0x4d, 0x6f, 0xd3, 0x40, 0x10, 0xbd, 0xe7, 0x57, 0x70, 0x24, 0x92, 0xb1,
    0x52, 0x0e, 0x1c, 0x2c, 0x15, 0xa9, 0x4d, 0x10, 0x44, 0x40, 0x93, 0x34, 0x81, 0x03, 0x08, 0xa1,
    0xc5, 0x3b, 0x69, 0x56, 0x6c, 0x76, 0xcc, 0xee, 0x38, 0x95, 0x41, 0xfc, 0x77, 0xc6, 0x5f, 0x69,
    0x13, 0x62, 0xbc, 0xae, 0xe9, 0xcd, 0x1f, 0x33, 0x6f, 0x66, 0xde, 0xbe, 0x99, 0xd9, 0xe7, 0xd1,
    0xdb, 0xb1, 0xd0, 0x60, 0xa4, 0xb0, 0x63, 0xb4, 0x10, 0x1e, 0xbe, 0xad, 0x50, 0xe2, 0x53, 0x07,
    0x7a, 0x3d, 0x1c, 0x9c, 0xf9, 0x19, 0x06, 0x48, 0x1b, 0xb0, 0xff, 0xb4, 0x9d, 0x9a, 0x58, 0x49,
    0x30, 0x31, 0x0c, 0x07, 0xa3, 0xff, 0x06, 0x9a, 0xdb, 0x0e, 0x07, 0x6d, 0x16, 0x61, 0xac, 0xd1,
    0x40, 0x59, 0xd1, 0xb3, 0x97, 0x6d, 0xd6, 0x1e, 0x70, 0xb8, 0x4d, 0x34, 0x10, 0xc8, 0x1a, 0x72,
    0x9e, 0x2d, 0xb9, 0xb6, 0x17, 0xe1, 0x82, 0x0a, 0xa3, 0xc5, 0x44, 0x10, 0xac, 0xd4, 0x16, 0xda,
    0xa1, 0x64, 0x65, 0x59, 0x16, 0x6c, 0x51, 0x83, 0x1f, 0x89, 0x97, 0xc2, 0x41, 0x58, 0x87, 0xb9,
    0x66, 0xb7, 0x7e, 0x59, 0x80, 0x03, 0xab, 0x84, 0x56, 0x3f, 0xab, 0x44, 0x94, 0x89, 0x4e, 0xa0,
    0x89, 0x25, 0x59, 0x10, 0x5b, 0x0f, 0xc2, 0x25, 0x4d, 0xd2, 0x0a, 0x6a, 0xad, 0xac, 0xa3, 0xe8,
    0x1b, 0xa2, 0x3e, 0x5f, 0x0b, 0xed, 0x7a, 0x26, 0x4a, 0xd7, 0x10, 0xa7, 0xd6, 0xe6, 0x14, 0xb4,
    0x92, 0xdf, 0xae, 0x5d, 0xc6, 0x5b, 0x92, 0xb0, 0xd4, 0x0a, 0x35, 0xea, 0x06, 0x75, 0xaf, 0xe8,
    0x5e, 0xe5, 0xc2, 0x8f, 0x94, 0x29, 0x2b, 0x21, 0x89, 0x3f, 0xf8, 0x6b, 0x83, 0xc3, 0xe6, 0xd1,
    0xdb, 0x43, 0x6c, 0x84, 0x1b, 0xd7, 0x72, 0xce, 0x13, 0xab, 0xa9, 0xf0, 0xf6, 0xe6, 0x83, 0x7e,
    0x90, 0x5f, 0xc1, 0x56, 0x77, 0x4f, 0x15, 0xa3, 0xb9, 0x12, 0xfb, 0x86, 0xd9, 0xab, 0x61, 0x2a,
    0xa3, 0x26, 0x9e, 0xcf, 0x7f, 0xfd, 0x66, 0xf8, 0xc5, 0x3b, 0x41, 0xca, 0x9c, 0xb1, 0x84, 0x95,
    0xb9, 0xf1, 0x88, 0x73, 0x47, 0x4b, 0xc7, 0x04, 0xdd, 0xd4, 0xcc, 0x2d, 0xde, 0x58, 0x70, 0xee,
    0x84, 0x18, 0x7c, 0x41, 0xae, 0xb0, 0xd4, 0x53, 0x15, 0xfe, 0x61, 0x20, 0xb3, 0x04, 0xcc, 0x2b,
    0x23, 0xbb, 0x97, 0x30, 0xdb, 0x81, 0x95, 0x69, 0xc7, 0xa3, 0xd9, 0x32, 0xd7, 0xab, 0x2c, 0xd9,
    0x7b, 0x75, 0x64, 0x3c, 0x01, 0x1b, 0x83, 0xa1, 0x9a, 0xf6, 0x1a, 0x45, 0x19, 0x6a, 0xf7, 0x2d,
    0x74, 0xe0, 0x66, 0xa6, 0xe4, 0x2a, 0x1f, 0xaa, 0x27, 0xd5, 0x10, 0x10, 0xa7, 0xf8, 0x89, 0x77,
    0x41, 0x44, 0x59, 0xc2, 0x49, 0x85, 0x1f, 0x8c, 0x42, 0xf3, 0xf9, 0xd8, 0x74, 0x55, 0x59, 0x05,
    0x4f, 0x9a, 0xfe, 0x70, 0xb3, 0x29, 0x2a, 0x06, 0x26, 0x97, 0x88, 0xe6, 0x8b, 0x37, 0x47, 0x47,
    0x73, 0x16, 0x53, 0xea, 0x37, 0x68, 0x1d, 0xd0, 0x85, 0xd6, 0x13, 0x91, 0x95, 0x78, 0xa2, 0x78,
    0x2e, 0x65, 0xe2, 0x33, 0xff, 0xd8, 0xfd, 0x50, 0xe6, 0xc1, 0x7e, 0xb7, 0x55, 0x20, 0xa3, 0x3e,
    0x20, 0x93, 0xa6, 0x83, 0xc8, 0x79, 0xf4, 0xab, 0x6e, 0x72, 0xb0, 0x20, 0xeb, 0x75, 0xd9, 0x08,
    0xda, 0x6b, 0x85, 0xfa, 0x25, 0x74, 0xb7, 0xda, 0x8a, 0x2d, 0xd7, 0x9c, 0xca, 0x5f, 0x9b, 0xcf,
    0x13, 0xff, 0x68, 0xc5, 0x71, 0x98, 0x9e, 0x1c, 0xce, 0x4f, 0x74, 0x56, 0x50, 0xb5, 0x5b, 0xc4,
    0xfd, 0xe5, 0x83, 0xb2, 0x51, 0x6b, 0xca, 0x23, 0x56, 0x33, 0x0d, 0xb5, 0x7c, 0x8c, 0x3e, 0x0a,
    0x0c, 0xdc, 0x3e, 0x4a, 0x7f, 0x7a, 0x54, 0x98, 0x26, 0x09, 0x5a, 0x72, 0xaf, 0x2d, 0xa6, 0xc9,
    0xad, 0xb0, 0xc0, 0x74, 0x6d, 0x53, 0xa3, 0xe2, 0x02, 0xa1, 0xdb, 0x24, 0xcc, 0x77, 0xf5, 0xfb,
    0x7a, 0x1a, 0x76, 0x9f, 0x84, 0x74, 0x6f, 0x88, 0xfa, 0x4b, 0x79, 0xff, 0x96, 0x47, 0xf5, 0x0b,
    0xc2, 0x09, 0x35, 0x5d, 0x7d, 0x2e, 0x33, 0x82, 0x0b, 0x6b, 0x45, 0xd6, 0x8e, 0xb4, 0x53, 0x96,
    0xf8, 0x9e, 0xf2, 0x75, 0x83, 0xf8, 0xbd, 0xba, 0x3e, 0xca, 0x0e, 0x2d, 0xf8, 0xb1, 0x74, 0x7f,
    0xc3, 0xde, 0x79, 0x7f, 0x8b, 0x68, 0x87, 0x4a, 0x0e, 0x07, 0x7f, 0x00, 0x6c, 0xba, 0x91, 0x20
};
#endif

PyTypeObject *init_KCalendarCore_Todo(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Todo_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]));
    Shiboken::AutoDecRef Sbk_KCalendarCore_Todo_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Todo",
        "KCalendarCore::Todo*",
        &Sbk_KCalendarCore_Todo_spec,
        &Shiboken::callCppDestructor< KCalendarCore::Todo >,
        Sbk_KCalendarCore_Todo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_Todo_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_Todo_SignatureBytes, KCalendarCore_Todo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_Todo_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Todo_PythonToCpp_Todo_PTR,
        is_Todo_PythonToCpp_Todo_PTR_Convertible,
        Todo_PTR_CppToPython_Todo);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Todo");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Todo*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Todo&");
    Shiboken::Conversions::registerConverterAlias(converter, "Todo");
    Shiboken::Conversions::registerConverterAlias(converter, "Todo*");
    Shiboken::Conversions::registerConverterAlias(converter, "Todo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::Todo).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(TodoWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_KCalendarCore_Todo_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_KCalendarCore_Todo_TypeF(), &Sbk_KCalendarCore_TodoSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_KCalendarCore_Todo_typeDiscovery);

    qRegisterMetaType< ::KCalendarCore::Todo *>();

    return pyType;
}
