/****************************************************************************
** Meta object code from reading C++ file 'event.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kcalendarcore-6.26.0/src/event.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'event.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KCalendarCore5EventE_t {};
} // unnamed namespace

template <> constexpr inline auto KCalendarCore::Event::qt_create_metaobjectdata<qt_meta_tag_ZN13KCalendarCore5EventE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCalendarCore::Event",
        "dtEnd",
        "transparency",
        "KCalendarCore::Event::Transparency",
        "Transparency",
        "Opaque",
        "Transparent"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'dtEnd'
        QtMocHelpers::PropertyData<QDateTime>(1, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'transparency'
        QtMocHelpers::PropertyData<KCalendarCore::Event::Transparency>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Transparency'
        QtMocHelpers::EnumData<enum Transparency>(4, 4, QMC::EnumFlags{}).add({
            {    5, Transparency::Opaque },
            {    6, Transparency::Transparent },
        }),
    };
    return QtMocHelpers::metaObjectData<Event, qt_meta_tag_ZN13KCalendarCore5EventE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCalendarCore::Event::staticMetaObject = { {
    QtPrivate::MetaObjectForType<Incidence>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore5EventE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore5EventE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KCalendarCore5EventE_t>.metaTypes,
    nullptr
} };

void KCalendarCore::Event::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Event *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QDateTime*>(_v) = _t->dtEnd(); break;
        case 1: *reinterpret_cast<KCalendarCore::Event::Transparency*>(_v) = _t->transparency(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDtEnd(*reinterpret_cast<QDateTime*>(_v)); break;
        case 1: _t->setTransparency(*reinterpret_cast<KCalendarCore::Event::Transparency*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
