
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_recurrencerule_wrapper.h"

// inner classes
#include "kcalendarcore_recurrencerule_ruleobserver_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qtimezone.h>
#include <recurrencerule.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_RecurrenceRule_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_RecurrenceRule_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KCalendarCore::RecurrenceRule >()))
        return -1;

    ::KCalendarCore::RecurrenceRule *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "RecurrenceRule", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: RecurrenceRule::RecurrenceRule()
    // 1: RecurrenceRule::RecurrenceRule(const KCalendarCore::RecurrenceRule&)
    if (numArgs == 0) {
        overloadId = 0; // RecurrenceRule()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArgs[0])))) {
        overloadId = 1; // RecurrenceRule::RecurrenceRule(const KCalendarCore::RecurrenceRule&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // RecurrenceRule()
        {

            // RecurrenceRule::RecurrenceRule()
            cptr = new ::KCalendarCore::RecurrenceRule();
            break;
        }
        case 1: // RecurrenceRule(const KCalendarCore::RecurrenceRule &r)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KCalendarCore::RecurrenceRule cppArg0_local;
            ::KCalendarCore::RecurrenceRule *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // RecurrenceRule::RecurrenceRule(const KCalendarCore::RecurrenceRule&)
                cptr = new ::KCalendarCore::RecurrenceRule(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::KCalendarCore::RecurrenceRule >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_addObserver(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::addObserver(KCalendarCore::RecurrenceRule::RuleObserver*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_RuleObserver_IDX]), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::addObserver(KCalendarCore::RecurrenceRule::RuleObserver*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addObserver", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::RecurrenceRule::RuleObserver *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::addObserver(KCalendarCore::RecurrenceRule::RuleObserver*)
            cppSelf->addObserver(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_allDay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::allDay()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->allDay();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_byHours(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::byHours()const->const QList<int>&
        const QList<int> & cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->byHours();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_byMinutes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::byMinutes()const->const QList<int>&
        const QList<int> & cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->byMinutes();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_byMonthDays(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::byMonthDays()const->const QList<int>&
        const QList<int> & cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->byMonthDays();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_byMonths(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::byMonths()const->const QList<int>&
        const QList<int> & cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->byMonths();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_bySeconds(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::bySeconds()const->const QList<int>&
        const QList<int> & cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->bySeconds();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_bySetPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::bySetPos()const->const QList<int>&
        const QList<int> & cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->bySetPos();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_byWeekNumbers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::byWeekNumbers()const->const QList<int>&
        const QList<int> & cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->byWeekNumbers();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_byYearDays(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::byYearDays()const->const QList<int>&
        const QList<int> & cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->byYearDays();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::clear()
        cppSelf->clear();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_dateMatchesRules(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::dateMatchesRules(const QDateTime&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::dateMatchesRules(const QDateTime&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dateMatchesRules", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::dateMatchesRules(const QDateTime&)const->bool
            bool cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->dateMatchesRules(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_dump(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::dump()const
        const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->dump();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_duration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::duration()const->int
        int cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->duration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_durationTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::durationTo(const QDate&)const->int
    // 1: RecurrenceRule::durationTo(const QDateTime&)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 1; // RecurrenceRule::durationTo(const QDateTime&)const->int
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::durationTo(const QDate&)const->int
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "durationTo", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // durationTo(const QDate &date) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDate cppArg0_local;
            ::QDate *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // RecurrenceRule::durationTo(const QDate&)const->int
                int cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->durationTo(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 1: // durationTo(const QDateTime &dt) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // RecurrenceRule::durationTo(const QDateTime&)const->int
                int cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->durationTo(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_endDt(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        [[maybe_unused]] bool* removed_cppArg0 = nullptr;

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::endDt(bool*=)const->QDateTime
            QDateTime cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->endDt();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_frequency(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::frequency()const->uint
        uint cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->frequency();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_getNextDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::getNextDate(const QDateTime&)const->QDateTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::getNextDate(const QDateTime&)const->QDateTime
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "getNextDate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::getNextDate(const QDateTime&)const->QDateTime
            QDateTime cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->getNextDate(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_getPreviousDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::getPreviousDate(const QDateTime&)const->QDateTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::getPreviousDate(const QDateTime&)const->QDateTime
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "getPreviousDate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::getPreviousDate(const QDateTime&)const->QDateTime
            QDateTime cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->getPreviousDate(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_isReadOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::isReadOnly()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->isReadOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_recurTimesOn(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "recurTimesOn", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: RecurrenceRule::recurTimesOn(const QDate&,const QTimeZone&)const->QList<QTime>
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // RecurrenceRule::recurTimesOn(const QDate&,const QTimeZone&)const->QList<QTime>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "recurTimesOn", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0_local;
        ::QDate *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::recurTimesOn(const QDate&,const QTimeZone&)const->QList<QTime>
            QList<QTime> cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->recurTimesOn(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QTime_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_recurrenceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::recurrenceType()const->KCalendarCore::RecurrenceRule::PeriodType
        KCalendarCore::RecurrenceRule::PeriodType cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->recurrenceType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_PeriodType_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_recurs(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::recurs()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->recurs();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_recursAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::recursAt(const QDateTime&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::recursAt(const QDateTime&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "recursAt", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::recursAt(const QDateTime&)const->bool
            bool cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->recursAt(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_recursOn(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "recursOn", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: RecurrenceRule::recursOn(const QDate&,const QTimeZone&)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // RecurrenceRule::recursOn(const QDate&,const QTimeZone&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "recursOn", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0_local;
        ::QDate *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::recursOn(const QDate&,const QTimeZone&)const->bool
            bool cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->recursOn(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_removeObserver(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::removeObserver(KCalendarCore::RecurrenceRule::RuleObserver*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_RuleObserver_IDX]), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::removeObserver(KCalendarCore::RecurrenceRule::RuleObserver*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeObserver", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::RecurrenceRule::RuleObserver *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::removeObserver(KCalendarCore::RecurrenceRule::RuleObserver*)
            cppSelf->removeObserver(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_rrule(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::rrule()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->rrule();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setAllDay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setAllDay(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setAllDay(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAllDay", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setAllDay(bool)
            cppSelf->setAllDay(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setByHours(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setByHours(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setByHours(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setByHours", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setByHours(const QList<int>&)
            cppSelf->setByHours(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setByMinutes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setByMinutes(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setByMinutes(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setByMinutes", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setByMinutes(const QList<int>&)
            cppSelf->setByMinutes(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setByMonthDays(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setByMonthDays(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setByMonthDays(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setByMonthDays", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setByMonthDays(const QList<int>&)
            cppSelf->setByMonthDays(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setByMonths(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setByMonths(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setByMonths(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setByMonths", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setByMonths(const QList<int>&)
            cppSelf->setByMonths(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setBySeconds(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setBySeconds(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setBySeconds(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBySeconds", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setBySeconds(const QList<int>&)
            cppSelf->setBySeconds(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setBySetPos(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setBySetPos(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setBySetPos(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBySetPos", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setBySetPos(const QList<int>&)
            cppSelf->setBySetPos(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setByWeekNumbers(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setByWeekNumbers(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setByWeekNumbers(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setByWeekNumbers", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setByWeekNumbers(const QList<int>&)
            cppSelf->setByWeekNumbers(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setByYearDays(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setByYearDays(const QList<int>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setByYearDays(const QList<int>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setByYearDays", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setByYearDays(const QList<int>&)
            cppSelf->setByYearDays(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setDirty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::setDirty()
        cppSelf->setDirty();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setDuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setDuration(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setDuration(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDuration", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setDuration(int)
            cppSelf->setDuration(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setEndDt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setEndDt(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setEndDt(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEndDt", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setEndDt(const QDateTime&)
            cppSelf->setEndDt(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setFrequency(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setFrequency(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setFrequency(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFrequency", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setFrequency(int)
            cppSelf->setFrequency(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setRRule(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setRRule(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setRRule(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRRule", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setRRule(const QString&)
            cppSelf->setRRule(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setReadOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setReadOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadOnly", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setReadOnly(bool)
            cppSelf->setReadOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setRecurrenceType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setRecurrenceType(KCalendarCore::RecurrenceRule::PeriodType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_PeriodType_IDX]))), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setRecurrenceType(KCalendarCore::RecurrenceRule::PeriodType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRecurrenceType", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        ::KCalendarCore::RecurrenceRule::PeriodType cppArg0{KCalendarCore::RecurrenceRule::rNone};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setRecurrenceType(KCalendarCore::RecurrenceRule::PeriodType)
            cppSelf->setRecurrenceType(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setStartDt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setStartDt(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setStartDt(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStartDt", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setStartDt(const QDateTime&)
            cppSelf->setStartDt(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_setWeekStart(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceRule::setWeekStart(short)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArg)))) {
        overloadId = 0; // RecurrenceRule::setWeekStart(short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWeekStart", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::setWeekStart(short)
            cppSelf->setWeekStart(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_shiftTimes(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "shiftTimes", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: RecurrenceRule::shiftTimes(const QTimeZone&,const QTimeZone&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // RecurrenceRule::shiftTimes(const QTimeZone&,const QTimeZone&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "shiftTimes", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::shiftTimes(const QTimeZone&,const QTimeZone&)
            cppSelf->shiftTimes(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_startDt(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::startDt()const->QDateTime
        QDateTime cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->startDt();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_timesInInterval(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "timesInInterval", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: RecurrenceRule::timesInInterval(const QDateTime&,const QDateTime&)const->QList<QDateTime>
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[1])))) {
        overloadId = 0; // RecurrenceRule::timesInInterval(const QDateTime&,const QDateTime&)const->QList<QDateTime>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "timesInInterval", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDateTime cppArg1_local;
        ::QDateTime *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceRule::timesInInterval(const QDateTime&,const QDateTime&)const->QList<QDateTime>
            QList<QDateTime> cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->timesInInterval(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDateTime_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc_weekStart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // RecurrenceRule::weekStart()const->short
        short cppResult = const_cast<const ::KCalendarCore::RecurrenceRule *>(cppSelf)->weekStart();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<short>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRule__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_KCalendarCore_RecurrenceRule_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_KCalendarCore_RecurrenceRule_EnumFlagInfo[] = {
    "PeriodType:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_RecurrenceRule_methods[] = {
    {"addObserver", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_addObserver), METH_O, nullptr},
    {"allDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_allDay), METH_NOARGS, nullptr},
    {"byHours", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_byHours), METH_NOARGS, nullptr},
    {"byMinutes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_byMinutes), METH_NOARGS, nullptr},
    {"byMonthDays", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_byMonthDays), METH_NOARGS, nullptr},
    {"byMonths", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_byMonths), METH_NOARGS, nullptr},
    {"bySeconds", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_bySeconds), METH_NOARGS, nullptr},
    {"bySetPos", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_bySetPos), METH_NOARGS, nullptr},
    {"byWeekNumbers", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_byWeekNumbers), METH_NOARGS, nullptr},
    {"byYearDays", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_byYearDays), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_clear), METH_NOARGS, nullptr},
    {"dateMatchesRules", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_dateMatchesRules), METH_O, nullptr},
    {"dump", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_dump), METH_NOARGS, nullptr},
    {"duration", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_duration), METH_NOARGS, nullptr},
    {"durationTo", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_durationTo), METH_O, nullptr},
    {"endDt", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_endDt), METH_NOARGS, nullptr},
    {"frequency", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_frequency), METH_NOARGS, nullptr},
    {"getNextDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_getNextDate), METH_O, nullptr},
    {"getPreviousDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_getPreviousDate), METH_O, nullptr},
    {"isReadOnly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_isReadOnly), METH_NOARGS, nullptr},
    {"recurTimesOn", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_recurTimesOn), METH_VARARGS, nullptr},
    {"recurrenceType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_recurrenceType), METH_NOARGS, nullptr},
    {"recurs", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_recurs), METH_NOARGS, nullptr},
    {"recursAt", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_recursAt), METH_O, nullptr},
    {"recursOn", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_recursOn), METH_VARARGS, nullptr},
    {"removeObserver", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_removeObserver), METH_O, nullptr},
    {"rrule", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_rrule), METH_NOARGS, nullptr},
    {"setAllDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setAllDay), METH_O, nullptr},
    {"setByHours", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setByHours), METH_O, nullptr},
    {"setByMinutes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setByMinutes), METH_O, nullptr},
    {"setByMonthDays", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setByMonthDays), METH_O, nullptr},
    {"setByMonths", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setByMonths), METH_O, nullptr},
    {"setBySeconds", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setBySeconds), METH_O, nullptr},
    {"setBySetPos", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setBySetPos), METH_O, nullptr},
    {"setByWeekNumbers", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setByWeekNumbers), METH_O, nullptr},
    {"setByYearDays", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setByYearDays), METH_O, nullptr},
    {"setDirty", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setDirty), METH_NOARGS, nullptr},
    {"setDuration", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setDuration), METH_O, nullptr},
    {"setEndDt", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setEndDt), METH_O, nullptr},
    {"setFrequency", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setFrequency), METH_O, nullptr},
    {"setRRule", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setRRule), METH_O, nullptr},
    {"setReadOnly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setReadOnly), METH_O, nullptr},
    {"setRecurrenceType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setRecurrenceType), METH_O, nullptr},
    {"setStartDt", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setStartDt), METH_O, nullptr},
    {"setWeekStart", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_setWeekStart), METH_O, nullptr},
    {"shiftTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_shiftTimes), METH_VARARGS, nullptr},
    {"startDt", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_startDt), METH_NOARGS, nullptr},
    {"timesInInterval", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_timesInInterval), METH_VARARGS, nullptr},
    {"weekStart", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRuleFunc_weekStart), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_RecurrenceRule__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: RecurrenceRule::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // RecurrenceRule::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // RecurrenceRule::operator<<(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) << (cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_RecurrenceRuleFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: RecurrenceRule::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // RecurrenceRule::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // RecurrenceRule::operator>>(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

// Rich comparison
static PyObject * Sbk_KCalendarCore_RecurrenceRule_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArg)))) {
                // RecurrenceRule::operator!=(const KCalendarCore::RecurrenceRule&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::RecurrenceRule cppArg0_local;
                ::KCalendarCore::RecurrenceRule *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), (pyArg)))) {
                // RecurrenceRule::operator==(const KCalendarCore::RecurrenceRule&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::RecurrenceRule cppArg0_local;
                ::KCalendarCore::RecurrenceRule *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_KCalendarCore_RecurrenceRule_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_RecurrenceRule_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_RecurrenceRule_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_RecurrenceRule_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_RecurrenceRule_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_KCalendarCore_RecurrenceRule_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_RecurrenceRule_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_RecurrenceRule_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_RecurrenceRuleFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_RecurrenceRuleFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_RecurrenceRule_spec = {
    "1:KCalendarCore.KCalendarCore.RecurrenceRule",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_RecurrenceRule_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_KCalendarCore_RecurrenceRule_PeriodType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::RecurrenceRule::PeriodType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::RecurrenceRule::PeriodType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_RecurrenceRule_PeriodType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_PeriodType_IDX])))
        return Enum_PythonToCpp_KCalendarCore_RecurrenceRule_PeriodType;
    return {};
}

static PyObject *KCalendarCore_RecurrenceRule_PeriodType_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::RecurrenceRule::PeriodType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::RecurrenceRule::PeriodType *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void RecurrenceRule_PythonToCpp_RecurrenceRule_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_RecurrenceRule_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_RecurrenceRule_PythonToCpp_RecurrenceRule_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_RecurrenceRule_TypeF()))
        return RecurrenceRule_PythonToCpp_RecurrenceRule_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *RecurrenceRule_PTR_CppToPython_RecurrenceRule(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_RecurrenceRule_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_KCalendarCore_RecurrenceRule_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *RecurrenceRule_COPY_CppToPython_RecurrenceRule(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::KCalendarCore::RecurrenceRule *>(cppIn);
    return Shiboken::Object::newObject(Sbk_KCalendarCore_RecurrenceRule_TypeF(), new ::KCalendarCore::RecurrenceRule(*source), true, true);
}

// Python to C++ copy conversion.
static void RecurrenceRule_PythonToCpp_RecurrenceRule_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::KCalendarCore::RecurrenceRule *>(cppOut) = *reinterpret_cast< ::KCalendarCore::RecurrenceRule *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_RecurrenceRule_PythonToCpp_RecurrenceRule_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_RecurrenceRule_TypeF()))
        return RecurrenceRule_PythonToCpp_RecurrenceRule_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_RecurrenceRule_SignatureStrings[] = {
    "1:KCalendarCore.KCalendarCore.RecurrenceRule(self)",
    "0:KCalendarCore.KCalendarCore.RecurrenceRule(self,r:KCalendarCore.KCalendarCore.RecurrenceRule)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.addObserver(self,observer:KCalendarCore.KCalendarCore.RecurrenceRule.RuleObserver)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.allDay(self)->bool",
    "KCalendarCore.KCalendarCore.RecurrenceRule.byHours(self)->QList[int]",
    "KCalendarCore.KCalendarCore.RecurrenceRule.byMinutes(self)->QList[int]",
    "KCalendarCore.KCalendarCore.RecurrenceRule.byMonthDays(self)->QList[int]",
    "KCalendarCore.KCalendarCore.RecurrenceRule.byMonths(self)->QList[int]",
    "KCalendarCore.KCalendarCore.RecurrenceRule.bySeconds(self)->QList[int]",
    "KCalendarCore.KCalendarCore.RecurrenceRule.bySetPos(self)->QList[int]",
    "KCalendarCore.KCalendarCore.RecurrenceRule.byWeekNumbers(self)->QList[int]",
    "KCalendarCore.KCalendarCore.RecurrenceRule.byYearDays(self)->QList[int]",
    "KCalendarCore.KCalendarCore.RecurrenceRule.clear(self)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.dateMatchesRules(self,dt:PySide6.QtCore.QDateTime)->bool",
    "KCalendarCore.KCalendarCore.RecurrenceRule.dump(self)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.duration(self)->int",
    "1:KCalendarCore.KCalendarCore.RecurrenceRule.durationTo(self,date:PySide6.QtCore.QDate)->int",
    "0:KCalendarCore.KCalendarCore.RecurrenceRule.durationTo(self,dt:PySide6.QtCore.QDateTime)->int",
    "KCalendarCore.KCalendarCore.RecurrenceRule.endDt(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.RecurrenceRule.frequency(self)->uint",
    "KCalendarCore.KCalendarCore.RecurrenceRule.getNextDate(self,preDateTime:PySide6.QtCore.QDateTime)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.RecurrenceRule.getPreviousDate(self,afterDateTime:PySide6.QtCore.QDateTime)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.RecurrenceRule.isReadOnly(self)->bool",
    "KCalendarCore.KCalendarCore.RecurrenceRule.recurTimesOn(self,date:PySide6.QtCore.QDate,timeZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->QList[PySide6.QtCore.QTime]",
    "KCalendarCore.KCalendarCore.RecurrenceRule.recurrenceType(self)->KCalendarCore.KCalendarCore.RecurrenceRule.PeriodType",
    "KCalendarCore.KCalendarCore.RecurrenceRule.recurs(self)->bool",
    "KCalendarCore.KCalendarCore.RecurrenceRule.recursAt(self,dt:PySide6.QtCore.QDateTime)->bool",
    "KCalendarCore.KCalendarCore.RecurrenceRule.recursOn(self,date:PySide6.QtCore.QDate,timeZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->bool",
    "KCalendarCore.KCalendarCore.RecurrenceRule.removeObserver(self,observer:KCalendarCore.KCalendarCore.RecurrenceRule.RuleObserver)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.rrule(self)->QString",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setAllDay(self,allDay:bool)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setByHours(self,byHours:QList[int])",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setByMinutes(self,byMinutes:QList[int])",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setByMonthDays(self,byMonthDays:QList[int])",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setByMonths(self,byMonths:QList[int])",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setBySeconds(self,bySeconds:QList[int])",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setBySetPos(self,bySetPos:QList[int])",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setByWeekNumbers(self,byWeekNumbers:QList[int])",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setByYearDays(self,byYearDays:QList[int])",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setDirty(self)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setDuration(self,duration:int)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setEndDt(self,endDateTime:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setFrequency(self,freq:int)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setRRule(self,rrule:QString)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setReadOnly(self,readOnly:bool)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setRecurrenceType(self,period:KCalendarCore.KCalendarCore.RecurrenceRule.PeriodType)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setStartDt(self,start:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.setWeekStart(self,weekStart:short)",
    "KCalendarCore.KCalendarCore.RecurrenceRule.shiftTimes(self,oldTz:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization],newTz:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "KCalendarCore.KCalendarCore.RecurrenceRule.startDt(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.RecurrenceRule.timesInInterval(self,start:PySide6.QtCore.QDateTime,end:PySide6.QtCore.QDateTime)->QList[PySide6.QtCore.QDateTime]",
    "KCalendarCore.KCalendarCore.RecurrenceRule.weekStart(self)->short",
    "KCalendarCore.KCalendarCore.RecurrenceRule.__copy__(self)->typing._Self",
    "KCalendarCore.KCalendarCore.RecurrenceRule.__lshift__(self,out:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.RecurrenceRule.__rshift__(self,in:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.RecurrenceRule.__ne__(self,r:KCalendarCore.KCalendarCore.RecurrenceRule)->bool",
    "KCalendarCore.KCalendarCore.RecurrenceRule.__eq__(self,r:KCalendarCore.KCalendarCore.RecurrenceRule)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_RecurrenceRule_SignatureByteSize = 721;
static constexpr uint8_t KCalendarCore_RecurrenceRule_SignatureBytes[721] = {
    0x78, 0xda, 0xc5, 0x98, 0x5d, 0x6f, 0xda, 0x30, 0x14, 0x86, 0xef, 0xf9, 0x15, 0xbb, 0x1c, 0x92,
    0x87, 0xda, 0x9b, 0x5d, 0xe4, 0x62, 0x52, 0x57, 0x36, 0x0d, 0x6d, 0x2d, 0x9f, 0xd3, 0xb4, 0x55,
    0x28, 0x32, 0xe4, 0x50, 0xac, 0x05, 0x9b, 0xda, 0x0e, 0x2c, 0xfd, 0xf5, 0xb3, 0x93, 0x38, 0x24,
    0x1d, 0xa5, 0x3d, 0x71, 0xd6, 0xde, 0x20, 0x1d, 0xc5, 0xe7, 0x39, 0x5f, 0x8e, 0xfd, 0x86, 0xf3,
    0xe0, 0xeb, 0x25, 0x8d, 0x81, 0x47, 0x54, 0x5e, 0x0a, 0x09, 0xbd, 0xba, 0x35, 0x81, 0x65, 0x22,
    0x25, 0xf0, 0x25, 0x4c, 0x92, 0x18, 0xde, 0x2a, 0x88, 0x57, 0xdd, 0xce, 0x19, 0xd6, 0x85, 0x48,
    0x84, 0x47, 0xb7, 0xf3, 0xfc, 0xb5, 0x3d, 0x1a, 0x45, 0xc3, 0x85, 0x02, 0xb9, 0x03, 0x99, 0x47,
    0x12, 0x85, 0x85, 0x08, 0xd8, 0xb3, 0x3f, 0x8e, 0x82, 0x8b, 0x1e, 0xc7, 0x7d, 0x9a, 0xe6, 0x5d,
    0x79, 0xf7, 0x61, 0x21, 0x44, 0x8c, 0xf1, 0x5e, 0xa4, 0x5f, 0x44, 0x22, 0x95, 0x73, 0x1f, 0x7f,
    0x63, 0x4a, 0xdf, 0x30, 0xae, 0xe7, 0x38, 0xc8, 0x15, 0xe3, 0x89, 0x06, 0x7f, 0x8c, 0xe0, 0x7a,
    0x6d, 0xaa, 0x69, 0x07, 0xe4, 0x4d, 0x99, 0xc2, 0x52, 0xf0, 0xa8, 0x05, 0x8c, 0x1e, 0x09, 0x6f,
    0xca, 0x0f, 0x80, 0xdf, 0xd7, 0xc9, 0x66, 0x01, 0xfe, 0xd3, 0xfa, 0x09, 0x54, 0xfa, 0x77, 0x79,
    0x19, 0x1b, 0x4c, 0xf1, 0x36, 0x22, 0xdc, 0x22, 0xaa, 0xe1, 0x8a, 0xea, 0xe5, 0x1a, 0x94, 0xb5,
    0xf3, 0x24, 0x48, 0xa4, 0x83, 0x51, 0x3a, 0x65, 0x11, 0xbc, 0xef, 0x8d, 0x75, 0xe6, 0x36, 0xee,
    0x9b, 0x85, 0x33, 0xb6, 0x81, 0x06, 0xbb, 0x3a, 0x4a, 0x36, 0xdb, 0x06, 0x99, 0x25, 0x92, 0x6a,
    0x26, 0xb8, 0x6b, 0x8b, 0x69, 0x48, 0xe7, 0x3c, 0x68, 0x00, 0x98, 0x89, 0xa2, 0x28, 0x53, 0xc1,
    0xd1, 0xb2, 0x0a, 0xf8, 0x99, 0x17, 0xfc, 0x64, 0xc7, 0x2c, 0x1e, 0x01, 0x37, 0x0f, 0xfa, 0xda,
    0xd5, 0xfd, 0x18, 0x16, 0x03, 0x5c, 0x49, 0xb8, 0x4b, 0x8c, 0x55, 0x1e, 0x4c, 0x09, 0x32, 0xa3,
    0x5b, 0xd0, 0xd7, 0xf0, 0x47, 0xdb, 0xd8, 0x79, 0xbd, 0x5b, 0x09, 0x2e, 0x91, 0x53, 0x85, 0xb7,
    0x91, 0xbc, 0x89, 0x3d, 0x92, 0xb0, 0x63, 0x22, 0x51, 0x87, 0xf8, 0x74, 0xa5, 0x41, 0xbe, 0x54,
    0x06, 0x4c, 0x4d, 0x80, 0x46, 0x43, 0x1e, 0x37, 0x3e, 0xd8, 0xa5, 0x35, 0x6d, 0x58, 0x35, 0xe4,
    0x4f, 0xec, 0x46, 0xa2, 0xcd, 0xb2, 0x5f, 0x82, 0x43, 0xa0, 0xd3, 0x2d, 0xe3, 0xb7, 0xbd, 0xef,
    0xdc, 0xec, 0xb3, 0x9b, 0x87, 0x4b, 0x67, 0xc5, 0x2a, 0xf2, 0xe6, 0xb1, 0x27, 0xbd, 0x01, 0x67,
    0x9a, 0xd1, 0x98, 0xdd, 0x67, 0x3b, 0x75, 0x5e, 0x1e, 0x2d, 0xc7, 0x1c, 0xe6, 0xe8, 0x6a, 0x32,
    0x73, 0x96, 0x6e, 0xc1, 0xf5, 0x04, 0x01, 0x18, 0x81, 0x64, 0x22, 0xb2, 0xce, 0xe8, 0xb0, 0xca,
    0x6b, 0x04, 0xea, 0x42, 0xff, 0x8f, 0x13, 0x2e, 0x67, 0xbf, 0xea, 0x68, 0xf1, 0x29, 0x6f, 0xc4,
    0x0e, 0x5e, 0x51, 0x29, 0x49, 0x59, 0xca, 0x47, 0xb3, 0x31, 0xa7, 0x5a, 0x9a, 0x86, 0x60, 0xfc,
    0x15, 0xe8, 0x8b, 0x83, 0xd8, 0x22, 0xb9, 0xf0, 0x0a, 0x6c, 0x1b, 0xba, 0x48, 0xcc, 0xc7, 0x8a,
    0xea, 0x22, 0x85, 0x04, 0x0b, 0x0e, 0xb7, 0x30, 0x1e, 0x57, 0xd5, 0x5f, 0xa4, 0x94, 0x63, 0x7e,
    0xc8, 0x9a, 0x16, 0x23, 0x15, 0x71, 0xe6, 0x8f, 0xad, 0x33, 0xfd, 0x80, 0x55, 0x91, 0x46, 0x4a,
    0xcd, 0xe6, 0x89, 0x2c, 0x05, 0x1b, 0x71, 0xf2, 0xcd, 0x0b, 0xf8, 0x50, 0xbb, 0x91, 0x9a, 0x9c,
    0xf3, 0x42, 0xd7, 0xb4, 0x1c, 0x39, 0x68, 0x3b, 0x0f, 0x68, 0x9f, 0x49, 0x9d, 0xe2, 0xe5, 0x93,
    0xf5, 0xac, 0x2a, 0x28, 0xe2, 0x14, 0x4b, 0x60, 0x92, 0xc0, 0x92, 0x3e, 0x95, 0x82, 0x84, 0x58,
    0x6d, 0xf2, 0xe4, 0xb5, 0x8b, 0xc4, 0x7f, 0xae, 0xc9, 0x13, 0x62, 0xd5, 0x4a, 0x93, 0x2c, 0x27,
    0x95, 0xaf, 0x4b, 0x7b, 0xb8, 0x04, 0xc5, 0xa9, 0x82, 0xe6, 0x54, 0x2f, 0x7b, 0x22, 0x0b, 0xab,
    0xd1, 0xd1, 0x32, 0xf9, 0xf7, 0xa6, 0x24, 0xdb, 0xec, 0xf2, 0x0b, 0x1a, 0x5d, 0x97, 0xd8, 0xf8,
    0x53, 0x4d, 0xa5, 0x76, 0xa3, 0x53, 0xd6, 0x68, 0x6d, 0x68, 0xf6, 0x95, 0xc9, 0xf0, 0x39, 0x7c,
    0xef, 0xcc, 0x40, 0xad, 0x85, 0x44, 0xce, 0x6e, 0xcd, 0x56, 0x3a, 0x53, 0x47, 0xc5, 0x3d, 0x14,
    0x47, 0xb3, 0xfb, 0xb6, 0xef, 0x48, 0xc2, 0x61, 0xdf, 0x3e, 0x15, 0x57, 0x67, 0x65, 0x1a, 0x2d,
    0x49, 0x53, 0xab, 0x28, 0xd4, 0x80, 0x0f, 0xb8, 0x91, 0xc3, 0x3b, 0x1a, 0x3f, 0x67, 0xd0, 0xf6,
    0x15, 0x3e, 0x25, 0x7e, 0x8e, 0x8b, 0x44, 0xb7, 0x00, 0x25, 0x14, 0xf7, 0xb5, 0x3d, 0x62, 0xd8,
    0xd9, 0xde, 0xc0, 0x10, 0xc2, 0x70, 0x29, 0xb6, 0x69, 0x18, 0x3a, 0x40, 0x31, 0xbe, 0x70, 0x6a,
    0x4c, 0x1c, 0x27, 0xce, 0x76, 0x59, 0x41, 0x22, 0x22, 0x39, 0xda, 0x20, 0x6a, 0x4e, 0x0c, 0xa0,
    0x9b, 0xe3, 0xc3, 0x29, 0x1e, 0xe2, 0xc2, 0xca, 0x5a, 0x58, 0xc6, 0x5f, 0x26, 0x2a, 0x07, 0x17,
    0x11, 0xf5, 0x3f, 0x1b, 0x5e, 0x46, 0x86, 0x21, 0xdc, 0xf9, 0x84, 0xfa, 0x0b, 0x42, 0x94, 0x7f,
    0xbe
};
#endif

PyTypeObject *init_KCalendarCore_RecurrenceRule(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_KCalendarCore_RecurrenceRule_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "RecurrenceRule",
        "KCalendarCore::RecurrenceRule",
        &Sbk_KCalendarCore_RecurrenceRule_spec,
        &Shiboken::callCppDestructor< ::KCalendarCore::RecurrenceRule >,
        Sbk_KCalendarCore_RecurrenceRule_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_RecurrenceRule_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_RecurrenceRule_SignatureBytes, KCalendarCore_RecurrenceRule_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_RecurrenceRule_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        RecurrenceRule_PythonToCpp_RecurrenceRule_PTR,
        is_RecurrenceRule_PythonToCpp_RecurrenceRule_PTR_Convertible,
        RecurrenceRule_PTR_CppToPython_RecurrenceRule,
        RecurrenceRule_COPY_CppToPython_RecurrenceRule);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::RecurrenceRule");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::RecurrenceRule*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::RecurrenceRule&");
    Shiboken::Conversions::registerConverterAlias(converter, "RecurrenceRule");
    Shiboken::Conversions::registerConverterAlias(converter, "RecurrenceRule*");
    Shiboken::Conversions::registerConverterAlias(converter, "RecurrenceRule&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::RecurrenceRule).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        RecurrenceRule_PythonToCpp_RecurrenceRule_COPY,
        is_RecurrenceRule_PythonToCpp_RecurrenceRule_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_KCalendarCore_RecurrenceRule_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'PeriodType'.
    const char *PeriodType_Initializer[] = {
        "rNone",
        "rSecondly",
        "rMinutely",
        "rHourly",
        "rDaily",
        "rWeekly",
        "rMonthly",
        "rYearly",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PeriodType_InitializerValues[] = {
        uint8_t(KCalendarCore::RecurrenceRule::PeriodType::rNone),     //  0x00  0
        uint8_t(KCalendarCore::RecurrenceRule::PeriodType::rSecondly), //  0x01  1
        uint8_t(KCalendarCore::RecurrenceRule::PeriodType::rMinutely), //  0x02  2
        uint8_t(KCalendarCore::RecurrenceRule::PeriodType::rHourly),   //  0x03  3
        uint8_t(KCalendarCore::RecurrenceRule::PeriodType::rDaily),    //  0x04  4
        uint8_t(KCalendarCore::RecurrenceRule::PeriodType::rWeekly),   //  0x05  5
        uint8_t(KCalendarCore::RecurrenceRule::PeriodType::rMonthly),  //  0x06  6
        uint8_t(KCalendarCore::RecurrenceRule::PeriodType::rYearly)    //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.RecurrenceRule.PeriodType",
        PeriodType_Initializer, PeriodType_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_RecurrenceRule_PeriodType_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::RecurrenceRule::PeriodType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_RecurrenceRule_PeriodType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_RecurrenceRule_PeriodType,
            is_Enum_PythonToCpp_KCalendarCore_RecurrenceRule_PeriodType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::RecurrenceRule::PeriodType");
        Shiboken::Conversions::registerConverterAlias(converter, "RecurrenceRule::PeriodType");
        Shiboken::Conversions::registerConverterAlias(converter, "PeriodType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PeriodType' enum.

    qRegisterMetaType< ::KCalendarCore::RecurrenceRule >("RecurrenceRule");
    qRegisterMetaType< ::KCalendarCore::RecurrenceRule >("KCalendarCore::RecurrenceRule");
    qRegisterMetaType< ::KCalendarCore::RecurrenceRule::PeriodType >("RecurrenceRule::PeriodType");
    qRegisterMetaType< ::KCalendarCore::RecurrenceRule::PeriodType >("KCalendarCore::RecurrenceRule::PeriodType");

    return pyType;
}
