
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_incidencebase_incidenceobserver_wrapper.h"

// Wrappers providing overrides
#include "kcalendarcore_incidencebase_incidenceobserver_wrapper.h"

// Argument includes
#include <QString>
#include <qdatetime.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void IncidenceObserverWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

IncidenceObserverWrapper::IncidenceObserverWrapper()
{
}

void IncidenceObserverWrapper::incidenceUpdate(const ::QString & uid, const ::QDateTime & recurrenceId)
{
    static const char *funcName = "incidenceUpdate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("IncidenceObserver.incidenceUpdate");
        return;
    }
    sbk_o_incidenceUpdate("IncidenceObserver", funcName, gil, pyOverride, uid, recurrenceId);
}

void IncidenceObserverWrapper::sbk_o_incidenceUpdate([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QString & uid, [[maybe_unused]] const ::QDateTime & recurrenceId)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &uid),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &recurrenceId)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &uid),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &recurrenceId)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void IncidenceObserverWrapper::incidenceUpdated(const ::QString & uid, const ::QDateTime & recurrenceId)
{
    static const char *funcName = "incidenceUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("IncidenceObserver.incidenceUpdated");
        return;
    }
    IncidenceObserverWrapper::sbk_o_incidenceUpdate("IncidenceObserver", funcName, gil, pyOverride, uid, recurrenceId);
}

IncidenceObserverWrapper::~IncidenceObserverWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_Init(PyObject *self, [[maybe_unused]] PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("KCalendarCore::IncidenceBase::IncidenceObserver");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KCalendarCore::IncidenceBase::IncidenceObserver >()))
        return -1;

    IncidenceObserverWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // IncidenceObserver::IncidenceObserver()
        cptr = new IncidenceObserverWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< KCalendarCore::IncidenceBase::IncidenceObserver >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KCalendarCore_IncidenceBase_IncidenceObserverFunc_incidenceUpdate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase::IncidenceObserver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "incidenceUpdate", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceObserver::incidenceUpdate(const QString&,const QDateTime&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[1])))) {
        overloadId = 0; // IncidenceObserver::incidenceUpdate(const QString&,const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "incidenceUpdate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDateTime cppArg1_local;
        ::QDateTime *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceObserver::incidenceUpdate(const QString&,const QDateTime&)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("IncidenceObserver.incidenceUpdate");
                return {};
            }
            cppSelf->incidenceUpdate(cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBase_IncidenceObserverFunc_incidenceUpdated(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase::IncidenceObserver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "incidenceUpdated", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceObserver::incidenceUpdated(const QString&,const QDateTime&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[1])))) {
        overloadId = 0; // IncidenceObserver::incidenceUpdated(const QString&,const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "incidenceUpdated", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDateTime cppArg1_local;
        ::QDateTime *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceObserver::incidenceUpdated(const QString&,const QDateTime&)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("IncidenceObserver.incidenceUpdated");
                return {};
            }
            cppSelf->incidenceUpdated(cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_methods[] = {
    {"incidenceUpdate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBase_IncidenceObserverFunc_incidenceUpdate), METH_VARARGS, nullptr},
    {"incidenceUpdated", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBase_IncidenceObserverFunc_incidenceUpdated), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::KCalendarCore::IncidenceBase::IncidenceObserver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<IncidenceObserverWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_spec = {
    "1:KCalendarCore.KCalendarCore.IncidenceBase.IncidenceObserver",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void IncidenceObserver_PythonToCpp_IncidenceObserver_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_IncidenceObserver_PythonToCpp_IncidenceObserver_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_TypeF()))
        return IncidenceObserver_PythonToCpp_IncidenceObserver_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *IncidenceObserver_PTR_CppToPython_IncidenceObserver(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::KCalendarCore::IncidenceBase::IncidenceObserver *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_IncidenceBase_IncidenceObserver_SignatureStrings[] = {
    "KCalendarCore.KCalendarCore.IncidenceBase.IncidenceObserver(self)",
    "KCalendarCore.KCalendarCore.IncidenceBase.IncidenceObserver.incidenceUpdate(self,uid:QString,recurrenceId:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.IncidenceBase.IncidenceObserver.incidenceUpdated(self,uid:QString,recurrenceId:PySide6.QtCore.QDateTime)",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_IncidenceBase_IncidenceObserver_SignatureByteSize = 118;
static constexpr uint8_t KCalendarCore_IncidenceBase_IncidenceObserver_SignatureBytes[118] = {
    0x78, 0xda, 0xf3, 0x76, 0x4e, 0xcc, 0x49, 0xcd, 0x4b, 0x49, 0x2c, 0x72, 0xce, 0x2f, 0x4a, 0xd5,
    0xf3, 0x46, 0xe1, 0x79, 0xe6, 0x25, 0x67, 0xa6, 0xa4, 0xe6, 0x25, 0xa7, 0x3a, 0x25, 0x16, 0x23,
    0xf1, 0xfc, 0x93, 0x8a, 0x53, 0x8b, 0xca, 0x52, 0x8b, 0x34, 0x8a, 0x53, 0x73, 0xd2, 0x34, 0xb9,
    0xbc, 0xc9, 0x37, 0x41, 0x2f, 0x13, 0x26, 0x12, 0x5a, 0x90, 0x92, 0x58, 0x92, 0x0a, 0x36, 0x51,
    0xa7, 0x34, 0x33, 0xc5, 0x2a, 0x30, 0xb8, 0xa4, 0x28, 0x33, 0x2f, 0x5d, 0xa7, 0x28, 0x35, 0xb9,
    0xb4, 0xa8, 0x08, 0xa4, 0xc2, 0x33, 0xc5, 0x2a, 0xa0, 0x32, 0x18, 0xa8, 0xda, 0x4c, 0x2f, 0xb0,
    0x04, 0x6c, 0x78, 0xa0, 0x0b, 0x50, 0x4b, 0x48, 0x66, 0x6e, 0x2a, 0x55, 0xdd, 0x90, 0x42, 0xb6,
    0x23, 0x00, 0x56, 0xd5, 0x79, 0xdb
};
#endif

PyTypeObject *init_KCalendarCore_IncidenceBase_IncidenceObserver(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "IncidenceObserver",
        "KCalendarCore::IncidenceBase::IncidenceObserver*",
        &Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_spec,
        &Shiboken::callCppDestructor< KCalendarCore::IncidenceBase::IncidenceObserver >,
        Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_IncidenceBase_IncidenceObserver_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_IncidenceBase_IncidenceObserver_SignatureBytes, KCalendarCore_IncidenceBase_IncidenceObserver_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_IncidenceBase_IncidenceObserver_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        IncidenceObserver_PythonToCpp_IncidenceObserver_PTR,
        is_IncidenceObserver_PythonToCpp_IncidenceObserver_PTR_Convertible,
        IncidenceObserver_PTR_CppToPython_IncidenceObserver);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::IncidenceBase::IncidenceObserver");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::IncidenceBase::IncidenceObserver*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::IncidenceBase::IncidenceObserver&");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceBase::IncidenceObserver");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceBase::IncidenceObserver*");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceBase::IncidenceObserver&");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceObserver");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceObserver*");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceObserver&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::IncidenceBase::IncidenceObserver).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(IncidenceObserverWrapper).name());

    qRegisterMetaType< ::KCalendarCore::IncidenceBase::IncidenceObserver *>();

    return pyType;
}
