#ifndef SBK_CALFORMATWRAPPER_H
#define SBK_CALFORMATWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <calformat.h>

#include <sbkpython.h>

#include <array>
namespace Shiboken { struct AutoDecRef; class GilState; }

class CalFormatWrapper : public KCalendarCore::CalFormat
{
public:
    CalFormatWrapper(const CalFormatWrapper &) = delete;
    CalFormatWrapper& operator=(const CalFormatWrapper &) = delete;
    CalFormatWrapper(CalFormatWrapper &&) = delete;
    CalFormatWrapper& operator=(CalFormatWrapper &&) = delete;
    ~CalFormatWrapper() override;

    static void pysideInitQtMetaTypes();

private:
};

#endif // SBK_CALFORMATWRAPPER_H
