#ifndef SBK_ICALFORMATWRAPPER_H
#define SBK_ICALFORMATWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <icalformat.h>

#include <sbkpython.h>

#include <array>
namespace Shiboken { struct AutoDecRef; class GilState; }

class ICalFormatWrapper : public KCalendarCore::ICalFormat
{
public:
    ICalFormatWrapper();
    ICalFormatWrapper(const ICalFormatWrapper &) = delete;
    ICalFormatWrapper& operator=(const ICalFormatWrapper &) = delete;
    ICalFormatWrapper(ICalFormatWrapper &&) = delete;
    ICalFormatWrapper& operator=(ICalFormatWrapper &&) = delete;
    ~ICalFormatWrapper() override;

    static void pysideInitQtMetaTypes();

private:
};

#endif // SBK_ICALFORMATWRAPPER_H
