#ifndef SBK_PERSONWRAPPER_H
#define SBK_PERSONWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <person.h>

#include <sbkpython.h>

#include <array>
namespace Shiboken { struct AutoDecRef; class GilState; }

class PersonWrapper : public KCalendarCore::Person
{
public:
    PersonWrapper();
    PersonWrapper(const ::QString & name, const ::QString & email);
    PersonWrapper(const PersonWrapper &) = delete;
    PersonWrapper(const KCalendarCore::Person& self) : KCalendarCore::Person(self)
    {
    }
    PersonWrapper& operator=(const PersonWrapper &) = delete;
    PersonWrapper(PersonWrapper &&) = delete;
    PersonWrapper& operator=(PersonWrapper &&) = delete;
    ~PersonWrapper() override;

    static void pysideInitQtMetaTypes();

private:
};

#endif // SBK_PERSONWRAPPER_H
