/****************************************************************************
** Meta object code from reading C++ file 'incidencebase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kcalendarcore-6.26.0/src/incidencebase.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'incidencebase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KCalendarCore13IncidenceBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto KCalendarCore::IncidenceBase::qt_create_metaobjectdata<qt_meta_tag_ZN13KCalendarCore13IncidenceBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCalendarCore::IncidenceBase",
        "uid",
        "lastModified",
        "dtStart",
        "allDay",
        "organizer",
        "KCalendarCore::Person",
        "attendees",
        "QList<KCalendarCore::Attendee>",
        "url",
        "QUrl"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'uid'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'lastModified'
        QtMocHelpers::PropertyData<QDateTime>(2, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'dtStart'
        QtMocHelpers::PropertyData<QDateTime>(3, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'allDay'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'organizer'
        QtMocHelpers::PropertyData<KCalendarCore::Person>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'attendees'
        QtMocHelpers::PropertyData<QList<KCalendarCore::Attendee>>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IncidenceBase, qt_meta_tag_ZN13KCalendarCore13IncidenceBaseE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCalendarCore::IncidenceBase::staticMetaObject = { {
    QtPrivate::MetaObjectForType<CustomProperties>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore13IncidenceBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore13IncidenceBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KCalendarCore13IncidenceBaseE_t>.metaTypes,
    nullptr
} };

void KCalendarCore::IncidenceBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<IncidenceBase *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KCalendarCore::Person >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KCalendarCore::Attendee> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->uid(); break;
        case 1: *reinterpret_cast<QDateTime*>(_v) = _t->lastModified(); break;
        case 2: *reinterpret_cast<QDateTime*>(_v) = _t->dtStart(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->allDay(); break;
        case 4: *reinterpret_cast<KCalendarCore::Person*>(_v) = _t->organizer(); break;
        case 5: *reinterpret_cast<QList<KCalendarCore::Attendee>*>(_v) = _t->attendees(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUid(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setLastModified(*reinterpret_cast<QDateTime*>(_v)); break;
        case 2: _t->setDtStart(*reinterpret_cast<QDateTime*>(_v)); break;
        case 3: _t->setAllDay(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setOrganizer(*reinterpret_cast<KCalendarCore::Person*>(_v)); break;
        case 6: _t->setUrl(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
