
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_conference_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <conference.h>
#include <customproperties.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_Conference_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_Conference_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KCalendarCore::Conference >()))
        return -1;

    ::KCalendarCore::Conference *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:Conference", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Conference::Conference()
    // 1: Conference::Conference(const KCalendarCore::Conference&)
    // 2: Conference::Conference(const QUrl&,const QString&,const QStringList&=,const QString&=)
    if (numArgs == 0) {
        overloadId = 0; // Conference()
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // Conference(QUrl,QString,QStringList,QString)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // Conference(QUrl,QString,QStringList,QString)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                overloadId = 2; // Conference::Conference(const QUrl&,const QString&,const QStringList&=,const QString&=)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Conference::Conference(const KCalendarCore::Conference&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

    // Resolve keyword arguments
    switch (overloadId) {
        case 0: // Conference::Conference()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);
            }
            break;
        }
        case 1: // Conference::Conference(const KCalendarCore::Conference&)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);
            }
            break;
        }
        case 2: // Conference::Conference(const QUrl&,const QString&,const QStringList&=,const QString&=)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"features", 2}, {"language", 3}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[2])))))
                    || (pyArgs[3] != nullptr && !((pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);
                }
            }
            break;
        }
    }

    // PyMI support
    Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Conference()
        {

            // Conference::Conference()
            cptr = new ::KCalendarCore::Conference();
            break;
        }
        case 1: // Conference(const KCalendarCore::Conference &conference)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KCalendarCore::Conference cppArg0_local;
            ::KCalendarCore::Conference *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Conference::Conference(const KCalendarCore::Conference&)
                cptr = new ::KCalendarCore::Conference(*cppArg0);
            }
            break;
        }
        case 2: // Conference(const QUrl &uri, const QString &label, const QStringList &features, const QString &language)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QStringList cppArg2{};
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3{};
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Conference::Conference(const QUrl&,const QString&,const QStringList&=,const QString&=)
                cptr = new ::KCalendarCore::Conference(*cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::KCalendarCore::Conference >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_addFeature(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Conference::addFeature(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Conference::addFeature(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addFeature", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Conference::addFeature(const QString&)
            cppSelf->addFeature(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_customProperties(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Conference::customProperties()->KCalendarCore::CustomProperties&
        KCalendarCore::CustomProperties & cppResult = cppSelf->customProperties();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_features(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Conference::features()const->QStringList
        QStringList cppResult = const_cast<const ::KCalendarCore::Conference *>(cppSelf)->features();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Conference::isNull()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Conference *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_label(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Conference::label()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Conference *>(cppSelf)->label();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_language(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Conference::language()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Conference *>(cppSelf)->language();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_removeFeature(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Conference::removeFeature(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Conference::removeFeature(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeFeature", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Conference::removeFeature(const QString&)
            cppSelf->removeFeature(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_setCustomProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setCustomProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Conference::setCustomProperty(const QByteArray&,const QString&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // Conference::setCustomProperty(const QByteArray&,const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCustomProperty", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Conference::setCustomProperty(const QByteArray&,const QString&)
            cppSelf->setCustomProperty(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_setFeatures(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Conference::setFeatures(const QStringList&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // Conference::setFeatures(const QStringList&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFeatures", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Conference::setFeatures(const QStringList&)
            cppSelf->setFeatures(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_setLabel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Conference::setLabel(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Conference::setLabel(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabel", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Conference::setLabel(const QString&)
            cppSelf->setLabel(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_setLanguage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Conference::setLanguage(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Conference::setLanguage(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLanguage", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Conference::setLanguage(const QString&)
            cppSelf->setLanguage(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_setUri(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Conference::setUri(const QUrl&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // Conference::setUri(const QUrl&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUri", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Conference::setUri(const QUrl&)
            cppSelf->setUri(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc_uri(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Conference::uri()const->QUrl
        QUrl cppResult = const_cast<const ::KCalendarCore::Conference *>(cppSelf)->uri();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_Conference__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_KCalendarCore_Conference_PropertyStrings[] = {
    "features::",
    "isNull:",
    "label::",
    "language::",
    "uri::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_Conference_methods[] = {
    {"addFeature", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_addFeature), METH_O, nullptr},
    {"customProperties", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_customProperties), METH_NOARGS, nullptr},
    {"features", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_features), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_isNull), METH_NOARGS, nullptr},
    {"label", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_label), METH_NOARGS, nullptr},
    {"language", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_language), METH_NOARGS, nullptr},
    {"removeFeature", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_removeFeature), METH_O, nullptr},
    {"setCustomProperty", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_setCustomProperty), METH_VARARGS, nullptr},
    {"setFeatures", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_setFeatures), METH_O, nullptr},
    {"setLabel", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_setLabel), METH_O, nullptr},
    {"setLanguage", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_setLanguage), METH_O, nullptr},
    {"setUri", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_setUri), METH_O, nullptr},
    {"uri", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_ConferenceFunc_uri), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_Conference__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_KCalendarCore_ConferenceFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: Conference::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // Conference::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Conference::operator<<(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_ConferenceFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: Conference::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // Conference::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Conference::operator>>(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

// Rich comparison
static PyObject * Sbk_KCalendarCore_Conference_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), (pyArg)))) {
                // Conference::operator!=(const KCalendarCore::Conference&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::Conference cppArg0_local;
                ::KCalendarCore::Conference *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), (pyArg)))) {
                // Conference::operator==(const KCalendarCore::Conference&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::Conference cppArg0_local;
                ::KCalendarCore::Conference *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_KCalendarCore_Conference_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_Conference_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_Conference_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_Conference_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_Conference_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_KCalendarCore_Conference_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_Conference_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_Conference_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_ConferenceFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_ConferenceFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_Conference_spec = {
    "1:KCalendarCore.KCalendarCore.Conference",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_Conference_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Conference_PythonToCpp_Conference_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_Conference_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Conference_PythonToCpp_Conference_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_Conference_TypeF()))
        return Conference_PythonToCpp_Conference_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Conference_PTR_CppToPython_Conference(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_Conference_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_KCalendarCore_Conference_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Conference_COPY_CppToPython_Conference(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::KCalendarCore::Conference *>(cppIn);
    return Shiboken::Object::newObject(Sbk_KCalendarCore_Conference_TypeF(), new ::KCalendarCore::Conference(*source), true, true);
}

// Python to C++ copy conversion.
static void Conference_PythonToCpp_Conference_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::KCalendarCore::Conference *>(cppOut) = *reinterpret_cast< ::KCalendarCore::Conference *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Conference_PythonToCpp_Conference_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_Conference_TypeF()))
        return Conference_PythonToCpp_Conference_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_Conference_SignatureStrings[] = {
    "2:KCalendarCore.KCalendarCore.Conference(self,*:KeywordOnly=None,isNull:bool=None,features:QStringList=None,label:QString=None,uri:QUrl=None,language:QString=None)",
    "1:KCalendarCore.KCalendarCore.Conference(self,conference:KCalendarCore.KCalendarCore.Conference,*:KeywordOnly=None,isNull:bool=None,features:QStringList=None,label:QString=None,uri:QUrl=None,language:QString=None)",
    "0:KCalendarCore.KCalendarCore.Conference(self,uri:typing.Union[PySide6.QtCore.QUrl, QString],label:QString,features:QStringList={},language:QString={},*:KeywordOnly=None,isNull:bool=None,features:QStringList=None,label:QString=None,uri:QUrl=None,language:QString=None)",
    "KCalendarCore.KCalendarCore.Conference.addFeature(self,feature:QString)",
    "KCalendarCore.KCalendarCore.Conference.customProperties(self)->KCalendarCore.KCalendarCore.CustomProperties",
    "KCalendarCore.KCalendarCore.Conference.features(self)->QStringList",
    "KCalendarCore.KCalendarCore.Conference.isNull(self)->bool",
    "KCalendarCore.KCalendarCore.Conference.label(self)->QString",
    "KCalendarCore.KCalendarCore.Conference.language(self)->QString",
    "KCalendarCore.KCalendarCore.Conference.removeFeature(self,feature:QString)",
    "KCalendarCore.KCalendarCore.Conference.setCustomProperty(self,xname:typing.Union[PySide6.QtCore.QByteArray, char*],xvalue:QString)",
    "KCalendarCore.KCalendarCore.Conference.setFeatures(self,features:QStringList)",
    "KCalendarCore.KCalendarCore.Conference.setLabel(self,label:QString)",
    "KCalendarCore.KCalendarCore.Conference.setLanguage(self,language:QString)",
    "KCalendarCore.KCalendarCore.Conference.setUri(self,uri:typing.Union[PySide6.QtCore.QUrl, QString])",
    "KCalendarCore.KCalendarCore.Conference.uri(self)->PySide6.QtCore.QUrl",
    "KCalendarCore.KCalendarCore.Conference.__copy__(self)->typing._Self",
    "KCalendarCore.KCalendarCore.Conference.__lshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.Conference.__rshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.Conference.__ne__(self,other:KCalendarCore.KCalendarCore.Conference)->bool",
    "KCalendarCore.KCalendarCore.Conference.__eq__(self,conference:KCalendarCore.KCalendarCore.Conference)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_Conference_SignatureByteSize = 400;
static constexpr uint8_t KCalendarCore_Conference_SignatureBytes[400] = {
    0x78, 0xda, 0xc5, 0x95, 0x51, 0x4f, 0xc2, 0x30, 0x10, 0xc7, 0xdf, 0xfd, 0x14, 0x3c, 0x0a, 0x99,
    0x8b, 0xfa, 0xe0, 0xc3, 0x12, 0x4d, 0x14, 0xc3, 0x0b, 0x04, 0x21, 0x0b, 0x4f, 0xc6, 0x2c, 0x65,
    0xbb, 0x41, 0x93, 0xae, 0xc5, 0x6b, 0x87, 0x34, 0xc6, 0xef, 0xee, 0x58, 0x57, 0x64, 0xb0, 0x90,
    0x8e, 0x98, 0xf0, 0xd8, 0x6b, 0xef, 0xf7, 0xff, 0xf7, 0x6e, 0xd7, 0xdd, 0x07, 0xc3, 0x3e, 0x61,
    0xc0, 0x13, 0x82, 0x7d, 0x81, 0xe0, 0xd7, 0x57, 0x7d, 0xc1, 0x53, 0x40, 0xe0, 0x31, 0x5c, 0x4b,
    0x60, 0xa9, 0xd7, 0x0b, 0x86, 0xa0, 0xbf, 0x04, 0x26, 0x6f, 0x9c, 0xe9, 0xc7, 0xb1, 0xe0, 0xe0,
    0x51, 0x39, 0xce, 0x19, 0x0b, 0xe6, 0x42, 0x30, 0x13, 0x48, 0x81, 0xa8, 0x1c, 0x41, 0x06, 0xd3,
    0x50, 0x21, 0xe5, 0x8b, 0x11, 0x95, 0xca, 0xec, 0x30, 0x32, 0x07, 0x66, 0xc3, 0x26, 0x94, 0x23,
    0x0d, 0xa6, 0x33, 0x64, 0xf6, 0x00, 0x5f, 0xe4, 0x64, 0x01, 0xb5, 0x33, 0xdd, 0xab, 0xbb, 0x56,
    0x1e, 0xe3, 0xdd, 0xda, 0x31, 0xed, 0x42, 0xb7, 0xba, 0x6d, 0x75, 0xab, 0x2d, 0x52, 0xe9, 0x55,
    0x91, 0xee, 0xcf, 0x38, 0x15, 0xfc, 0x7d, 0xa2, 0x43, 0x9a, 0xc0, 0x83, 0x3f, 0x55, 0xe5, 0xf9,
    0xad, 0x9c, 0xd7, 0xa9, 0x14, 0x3e, 0xea, 0xa6, 0x9a, 0xcd, 0x7f, 0xff, 0x1c, 0x3b, 0x2b, 0x62,
    0x97, 0x29, 0x86, 0x5b, 0x29, 0x7c, 0x92, 0x24, 0x03, 0xa3, 0x6d, 0xaa, 0x52, 0x19, 0xb1, 0x30,
    0x67, 0x4e, 0x9c, 0x4b, 0x25, 0xb2, 0x09, 0x8a, 0x15, 0xa0, 0xa2, 0x20, 0x4b, 0x5a, 0xf7, 0xe6,
    0xe9, 0x64, 0xfa, 0x41, 0x8e, 0xab, 0x96, 0x2d, 0x96, 0xd5, 0xd8, 0xab, 0x99, 0x2b, 0xc2, 0x34,
    0xc0, 0x02, 0xb6, 0x7d, 0x70, 0xcd, 0x2c, 0xfb, 0x71, 0xa0, 0xec, 0x9e, 0x6b, 0x5a, 0x75, 0x66,
    0x3a, 0x42, 0x26, 0xd6, 0xf0, 0x2f, 0xed, 0x92, 0xa0, 0x6a, 0xd5, 0xd7, 0x06, 0xb7, 0xe1, 0x24,
    0x83, 0xd3, 0x53, 0xf1, 0xa2, 0x15, 0x3c, 0x23, 0x12, 0xed, 0x75, 0xe2, 0x25, 0xc1, 0xde, 0x87,
    0xb7, 0x59, 0x13, 0x96, 0x9f, 0x65, 0x61, 0xb0, 0xdf, 0xc8, 0xc6, 0x19, 0x68, 0x43, 0x1b, 0xed,
    0x3a, 0x53, 0x1f, 0x9a, 0x76, 0x8c, 0xbd, 0x0e, 0x1d, 0x8d, 0x56, 0x1b, 0xd2, 0x0c, 0xe9, 0x39,
    0xef, 0x8c, 0xb3, 0x44, 0x5e, 0xf1, 0x8b, 0xcf, 0xa8, 0x01, 0xe8, 0x4a, 0x89, 0xa2, 0x58, 0xac,
    0x74, 0x14, 0x59, 0x54, 0x65, 0x34, 0x0a, 0x8b, 0xa5, 0x3b, 0x83, 0xc9, 0x25, 0x4d, 0x55, 0x45,
    0xf1, 0xa4, 0x42, 0x20, 0x59, 0x70, 0xe8, 0xea, 0x95, 0x28, 0x12, 0x96, 0x5b, 0x0d, 0x96, 0xff,
    0x36, 0xdd, 0x55, 0xf1, 0x22, 0xaa, 0x1c, 0xac, 0xa2, 0x50, 0x4b, 0x40, 0xc7, 0x5f, 0x4e, 0xcb,
    0x47, 0x26, 0x8a, 0xe0, 0xd3, 0xca, 0xb4, 0xfe, 0xfb, 0x5a, 0xad, 0x5f, 0x4a, 0xa9, 0x20, 0x20
};
#endif

PyTypeObject *init_KCalendarCore_Conference(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_KCalendarCore_Conference_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Conference",
        "KCalendarCore::Conference",
        &Sbk_KCalendarCore_Conference_spec,
        &Shiboken::callCppDestructor< ::KCalendarCore::Conference >,
        Sbk_KCalendarCore_Conference_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_Conference_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_Conference_SignatureBytes, KCalendarCore_Conference_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_Conference_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Conference_PythonToCpp_Conference_PTR,
        is_Conference_PythonToCpp_Conference_PTR_Convertible,
        Conference_PTR_CppToPython_Conference,
        Conference_COPY_CppToPython_Conference);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Conference");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Conference*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Conference&");
    Shiboken::Conversions::registerConverterAlias(converter, "Conference");
    Shiboken::Conversions::registerConverterAlias(converter, "Conference*");
    Shiboken::Conversions::registerConverterAlias(converter, "Conference&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::Conference).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Conference_PythonToCpp_Conference_COPY,
        is_Conference_PythonToCpp_Conference_COPY_Convertible);

    qRegisterMetaType< ::KCalendarCore::Conference >("Conference");
    qRegisterMetaType< ::KCalendarCore::Conference >("KCalendarCore::Conference");

    return pyType;
}
