/****************************************************************************
** Meta object code from reading C++ file 'attachment.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kcalendarcore-6.26.0/src/attachment.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'attachment.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KCalendarCore10AttachmentE_t {};
} // unnamed namespace

template <> constexpr inline auto KCalendarCore::Attachment::qt_create_metaobjectdata<qt_meta_tag_ZN13KCalendarCore10AttachmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCalendarCore::Attachment",
        "isEmpty",
        "uri",
        "isUri",
        "isBinary",
        "size",
        "mimeType",
        "showInline",
        "label",
        "isLocal"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isEmpty'
        QtMocHelpers::PropertyData<bool>(1, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'uri'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isUri'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'isBinary'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'size'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'mimeType'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'showInline'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'label'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isLocal'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Attachment, qt_meta_tag_ZN13KCalendarCore10AttachmentE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCalendarCore::Attachment::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore10AttachmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore10AttachmentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KCalendarCore10AttachmentE_t>.metaTypes,
    nullptr
} };

void KCalendarCore::Attachment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Attachment *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isEmpty(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->uri(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isUri(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isBinary(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->size(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->mimeType(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->showInline(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isLocal(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setUri(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setMimeType(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setShowInline(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setLabel(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setLocal(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
