
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_event_wrapper.h"

// Wrappers providing overrides
#include "kcalendarcore_incidencebase_wrapper.h"
#include "kcalendarcore_customproperties_wrapper.h"
#include "kcalendarcore_recurrence_recurrenceobserver_wrapper.h"
#include "kcalendarcore_incidence_wrapper.h"

// Argument includes
#include <QList>
#include <QtCore/qlatin1stringview.h>
#include <duration.h>
#include <event.h>
#include <incidence.h>
#include <incidencebase.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qtimezone.h>
#include <recurrence.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_Event_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void EventWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

EventWrapper::EventWrapper()
{
}

EventWrapper::EventWrapper(const ::KCalendarCore::Incidence & other) : KCalendarCore::Event(other)
{
}

::KCalendarCore::Event * EventWrapper::clone() const
{
    static const char *funcName = "clone";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::clone();
    }
    return sbk_o_clone("Event", funcName, gil, pyOverride);
}

::KCalendarCore::Event * EventWrapper::sbk_o_clone([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< KCalendarCore::Event >()), Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::KCalendarCore::Event *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void EventWrapper::customPropertyUpdate()
{
    static const char *funcName = "customPropertyUpdate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::customPropertyUpdate();
    }
    CustomPropertiesWrapper::sbk_o_customPropertyUpdate("Event", funcName, gil, pyOverride);
}

void EventWrapper::customPropertyUpdated()
{
    static const char *funcName = "customPropertyUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::customPropertyUpdated();
    }
    CustomPropertiesWrapper::sbk_o_customPropertyUpdate("Event", funcName, gil, pyOverride);
}

::QDateTime EventWrapper::dateTime(::KCalendarCore::IncidenceBase::DateTimeRole role) const
{
    static const char *funcName = "dateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::dateTime(role);
    }
    return IncidenceBaseWrapper::sbk_o_dateTime("Event", funcName, gil, pyOverride, role);
}

::QDateTime EventWrapper::dtEnd() const
{
    // This method belongs to a property.
    static const char *funcName = "1:dtEnd";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::dtEnd();
    }
    return IncidenceBaseWrapper::sbk_o_dtStart("Event", funcName, gil, pyOverride);
}

::QDateTime EventWrapper::dtStart() const
{
    // This method belongs to a property.
    static const char *funcName = "1:dtStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::dtStart();
    }
    return IncidenceBaseWrapper::sbk_o_dtStart("Event", funcName, gil, pyOverride);
}

::QDateTime EventWrapper::endDateForStart(const ::QDateTime & startDt) const
{
    static const char *funcName = "endDateForStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::endDateForStart(startDt);
    }
    return IncidenceWrapper::sbk_o_endDateForStart("Event", funcName, gil, pyOverride, startDt);
}

bool EventWrapper::equals(const ::KCalendarCore::IncidenceBase & event) const
{
    static const char *funcName = "equals";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::equals(event);
    }
    return IncidenceBaseWrapper::sbk_o_equals("Event", funcName, gil, pyOverride, event);
}

::QLatin1String EventWrapper::iconName(const ::QDateTime & recurrenceId) const
{
    static const char *funcName = "iconName";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::iconName(recurrenceId);
    }
    return IncidenceWrapper::sbk_o_iconName("Event", funcName, gil, pyOverride, recurrenceId);
}

::QLatin1String EventWrapper::mimeType() const
{
    static const char *funcName = "mimeType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::mimeType();
    }
    return IncidenceBaseWrapper::sbk_o_mimeType("Event", funcName, gil, pyOverride);
}

::QDateTime EventWrapper::recurrenceId() const
{
    static const char *funcName = "recurrenceId";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::recurrenceId();
    }
    return IncidenceBaseWrapper::sbk_o_dtStart("Event", funcName, gil, pyOverride);
}

void EventWrapper::recurrenceUpdated(::KCalendarCore::Recurrence * recurrence)
{
    static const char *funcName = "recurrenceUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::recurrenceUpdated(recurrence);
    }
    RecurrenceObserverWrapper::sbk_o_recurrenceUpdated("Event", funcName, gil, pyOverride, recurrence);
}

bool EventWrapper::recursOn(const ::QDate & date, const ::QTimeZone & timeZone) const
{
    static const char *funcName = "recursOn";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::recursOn(date, timeZone);
    }
    return IncidenceWrapper::sbk_o_recursOn("Event", funcName, gil, pyOverride, date, timeZone);
}

void EventWrapper::setAllDay(bool allDay)
{
    static const char *funcName = "setAllDay";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::setAllDay(allDay);
    }
    IncidenceBaseWrapper::sbk_o_setAllDay("Event", funcName, gil, pyOverride, allDay);
}

void EventWrapper::setDateTime(const ::QDateTime & dateTime, ::KCalendarCore::IncidenceBase::DateTimeRole role)
{
    static const char *funcName = "setDateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::setDateTime(dateTime, role);
    }
    IncidenceBaseWrapper::sbk_o_setDateTime("Event", funcName, gil, pyOverride, dateTime, role);
}

void EventWrapper::setDtStart(const ::QDateTime & dt)
{
    static const char *funcName = "setDtStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::setDtStart(dt);
    }
    IncidenceBaseWrapper::sbk_o_setDtStart("Event", funcName, gil, pyOverride, dt);
}

void EventWrapper::setDuration(const ::KCalendarCore::Duration & duration)
{
    static const char *funcName = "setDuration";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::setDuration(duration);
    }
    IncidenceBaseWrapper::sbk_o_setDuration("Event", funcName, gil, pyOverride, duration);
}

void EventWrapper::setLastModified(const ::QDateTime & lm)
{
    static const char *funcName = "setLastModified";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::setLastModified(lm);
    }
    IncidenceBaseWrapper::sbk_o_setDtStart("Event", funcName, gil, pyOverride, lm);
}

void EventWrapper::setReadOnly(bool readonly)
{
    static const char *funcName = "setReadOnly";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::setReadOnly(readonly);
    }
    IncidenceBaseWrapper::sbk_o_setAllDay("Event", funcName, gil, pyOverride, readonly);
}

void EventWrapper::shiftTimes(const ::QTimeZone & oldZone, const ::QTimeZone & newZone)
{
    static const char *funcName = "shiftTimes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::shiftTimes(oldZone, newZone);
    }
    IncidenceBaseWrapper::sbk_o_shiftTimes("Event", funcName, gil, pyOverride, oldZone, newZone);
}

::QList<QDateTime> EventWrapper::startDateTimesForDate(const ::QDate & date, const ::QTimeZone & timeZone) const
{
    static const char *funcName = "startDateTimesForDate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::startDateTimesForDate(date, timeZone);
    }
    return IncidenceWrapper::sbk_o_startDateTimesForDate("Event", funcName, gil, pyOverride, date, timeZone);
}

::QList<QDateTime> EventWrapper::startDateTimesForDateTime(const ::QDateTime & datetime) const
{
    static const char *funcName = "startDateTimesForDateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::startDateTimesForDateTime(datetime);
    }
    return IncidenceWrapper::sbk_o_startDateTimesForDateTime("Event", funcName, gil, pyOverride, datetime);
}

bool EventWrapper::supportsGroupwareCommunication() const
{
    static const char *funcName = "supportsGroupwareCommunication";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::supportsGroupwareCommunication();
    }
    return IncidenceWrapper::sbk_o_supportsGroupwareCommunication("Event", funcName, gil, pyOverride);
}

::KCalendarCore::IncidenceBase::IncidenceType EventWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::type();
    }
    return IncidenceBaseWrapper::sbk_o_type("Event", funcName, gil, pyOverride);
}

::QByteArray EventWrapper::typeStr() const
{
    static const char *funcName = "typeStr";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::typeStr();
    }
    return IncidenceBaseWrapper::sbk_o_typeStr("Event", funcName, gil, pyOverride);
}

void EventWrapper::virtual_hook(::KCalendarCore::IncidenceBase::VirtualHook id, void * data)
{
    static const char *funcName = "virtual_hook";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Event_TypeF(), gil, funcName, m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Event::virtual_hook(id, data);
    }
    IncidenceBaseWrapper::sbk_o_virtual_hook("Event", funcName, gil, pyOverride, id, data);
}

EventWrapper::~EventWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_KCalendarCore_Event_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_Event_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KCalendarCore::Event >()))
        return -1;

    EventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Event", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Event::Event()
    // 1: Event::Event(const KCalendarCore::Event&)
    // 2: Event::Event(const KCalendarCore::Incidence&)
    if (numArgs == 0) {
        overloadId = 0; // Event()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), (pyArgs[0])))) {
        overloadId = 2; // Event::Event(const KCalendarCore::Incidence&)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Event::Event(const KCalendarCore::Event&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Event()
        {

            // Event::Event()
            cptr = new EventWrapper();
            break;
        }
        case 1: // Event(const KCalendarCore::Event &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KCalendarCore::Event *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Event::Event(const KCalendarCore::Event&)
                cptr = new EventWrapper(*cppArg0);
            }
            break;
        }
        case 2: // Event(const KCalendarCore::Incidence &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KCalendarCore::Incidence *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Event::Event(const KCalendarCore::Incidence&)
                cptr = new EventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< KCalendarCore::Event >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KCalendarCore_EventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::clone()const->KCalendarCore::Event*
        KCalendarCore::Event * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Event *>(cppSelf)->::KCalendarCore::Event::clone()
            : const_cast<const ::KCalendarCore::Event *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_dateEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Event::dateEnd()const->QDate
        QDate cppResult = const_cast<const ::KCalendarCore::Event *>(cppSelf)->dateEnd();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_dateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), (pyArg)))) {
        overloadId = 0; // IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        ::KCalendarCore::IncidenceBase::DateTimeRole cppArg0{KCalendarCore::IncidenceBase::RoleAlarmStartOffset};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
            QDateTime cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Event *>(cppSelf)->::KCalendarCore::Event::dateTime(cppArg0)
                : const_cast<const ::KCalendarCore::Event *>(cppSelf)->dateTime(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_deserialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::deserialize(QDataStream&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::deserialize(QDataStream&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deserialize", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("deserialize(QDataStream &in)");
        return {};
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_EventFunc_dtEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Event::dtEnd()const->QDateTime
        QDateTime cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Event *>(cppSelf)->::KCalendarCore::Event::dtEnd()
            : const_cast<const ::KCalendarCore::Event *>(cppSelf)->dtEnd();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_equals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "equals", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::IncidenceBase *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Event *>(cppSelf)->::KCalendarCore::Event::equals(*cppArg0)
                : const_cast<const ::KCalendarCore::Event *>(cppSelf)->equals(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_eventMimeType([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static Event::eventMimeType()->QLatin1String
        QLatin1String cppResult = ::KCalendarCore::Event::eventMimeType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_hasEndDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Event::hasEndDate()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Event *>(cppSelf)->hasEndDate();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_iconName(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "iconName", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    if (PyArg_ParseTuple(args, "|O:iconName", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::iconName(const QDateTime&=)const->QLatin1String
    if (numArgs == 0) {
        overloadId = 0; // iconName(QDateTime)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))) {
        overloadId = 0; // Incidence::iconName(const QDateTime&=)const->QLatin1String
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "iconName", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"recurrenceId", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "iconName", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local{};
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::iconName(const QDateTime&=)const->QLatin1String
            QLatin1String cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Event *>(cppSelf)->::KCalendarCore::Event::iconName(*cppArg0)
                : const_cast<const ::KCalendarCore::Event *>(cppSelf)->iconName(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_isMultiDay(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "isMultiDay", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    if (PyArg_ParseTuple(args, "|O:isMultiDay", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Event::isMultiDay(const QTimeZone&=)const->bool
    if (numArgs == 0) {
        overloadId = 0; // isMultiDay(QTimeZone)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))) {
        overloadId = 0; // Event::isMultiDay(const QTimeZone&=)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isMultiDay", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"zone", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "isMultiDay", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTimeZone cppArg0_local{};
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // Event::isMultiDay(const QTimeZone&=)const->bool
            bool cppResult = const_cast<const ::KCalendarCore::Event *>(cppSelf)->isMultiDay(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_mimeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::mimeType()const->QLatin1String
        QLatin1String cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Event *>(cppSelf)->::KCalendarCore::Event::mimeType()
            : const_cast<const ::KCalendarCore::Event *>(cppSelf)->mimeType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_serialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::serialize(QDataStream&)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::serialize(QDataStream&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "serialize", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("serialize(QDataStream &out) const");
        return {};
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_EventFunc_setAllDay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setAllDay(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setAllDay(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAllDay", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setAllDay(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Event::setAllDay(cppArg0)
                : cppSelf->setAllDay(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_EventFunc_setDateTime(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDateTime", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::KCalendarCore::IncidenceBase::DateTimeRole cppArg1{KCalendarCore::IncidenceBase::RoleAlarmStartOffset};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Event::setDateTime(*cppArg0, cppArg1)
                : cppSelf->setDateTime(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_EventFunc_setDtEnd(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Event::setDtEnd(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Event::setDtEnd(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDtEnd", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Event::setDtEnd(const QDateTime&)
            cppSelf->setDtEnd(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_EventFunc_setDtStart(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setDtStart(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setDtStart(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDtStart", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setDtStart(const QDateTime&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Event::setDtStart(*cppArg0)
                : cppSelf->setDtStart(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_EventFunc_setDuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setDuration(const KCalendarCore::Duration&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Duration_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setDuration(const KCalendarCore::Duration&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDuration", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::Duration cppArg0_local;
        ::KCalendarCore::Duration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setDuration(const KCalendarCore::Duration&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Event::setDuration(*cppArg0)
                : cppSelf->setDuration(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_EventFunc_setTransparency(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Event::setTransparency(KCalendarCore::Event::Transparency)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_Transparency_IDX]))), (pyArg)))) {
        overloadId = 0; // Event::setTransparency(KCalendarCore::Event::Transparency)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTransparency", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        ::KCalendarCore::Event::Transparency cppArg0{KCalendarCore::Event::Opaque};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Event::setTransparency(KCalendarCore::Event::Transparency)
            cppSelf->setTransparency(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_EventFunc_shiftTimes(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "shiftTimes", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "shiftTimes", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Event::shiftTimes(*cppArg0, *cppArg1)
                : cppSelf->shiftTimes(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_EventFunc_supportsGroupwareCommunication(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::supportsGroupwareCommunication()const->bool
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Event *>(cppSelf)->::KCalendarCore::Event::supportsGroupwareCommunication()
            : const_cast<const ::KCalendarCore::Event *>(cppSelf)->supportsGroupwareCommunication();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_transparency(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Event::transparency()const->KCalendarCore::Event::Transparency
        KCalendarCore::Event::Transparency cppResult = const_cast<const ::KCalendarCore::Event *>(cppSelf)->transparency();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_Transparency_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::type()const->KCalendarCore::IncidenceBase::IncidenceType
        KCalendarCore::IncidenceBase::IncidenceType cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Event *>(cppSelf)->::KCalendarCore::Event::type()
            : const_cast<const ::KCalendarCore::Event *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceType_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_typeStr(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::typeStr()const->QByteArray
        QByteArray cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Event *>(cppSelf)->::KCalendarCore::Event::typeStr()
            : const_cast<const ::KCalendarCore::Event *>(cppSelf)->typeStr();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_EventFunc_virtual_hook(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "virtual_hook", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_VirtualHook_IDX]))), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "virtual_hook", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]);

    // Call function/method
    {
        ::KCalendarCore::IncidenceBase::VirtualHook cppArg0 = static_cast< ::KCalendarCore::IncidenceBase::VirtualHook>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        void* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Event::virtual_hook(cppArg0, cppArg1)
                : cppSelf->virtual_hook(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_KCalendarCore_Event_PropertyStrings[] = {
    "dtEnd::",
    "transparency::",
    nullptr // Sentinel
};

static const char *Sbk_KCalendarCore_Event_EnumFlagInfo[] = {
    "Transparency:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_Event_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_clone), METH_NOARGS, nullptr},
    {"dateEnd", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_dateEnd), METH_NOARGS, nullptr},
    {"dateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_dateTime), METH_O, nullptr},
    {"deserialize", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_deserialize), METH_O, nullptr},
    {"dtEnd", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_dtEnd), METH_NOARGS, nullptr},
    {"equals", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_equals), METH_O, nullptr},
    {"eventMimeType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_eventMimeType), METH_NOARGS|METH_STATIC, nullptr},
    {"hasEndDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_hasEndDate), METH_NOARGS, nullptr},
    {"iconName", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_iconName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isMultiDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_isMultiDay), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"mimeType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_mimeType), METH_NOARGS, nullptr},
    {"serialize", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_serialize), METH_O, nullptr},
    {"setAllDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_setAllDay), METH_O, nullptr},
    {"setDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_setDateTime), METH_VARARGS, nullptr},
    {"setDtEnd", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_setDtEnd), METH_O, nullptr},
    {"setDtStart", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_setDtStart), METH_O, nullptr},
    {"setDuration", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_setDuration), METH_O, nullptr},
    {"setTransparency", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_setTransparency), METH_O, nullptr},
    {"shiftTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_shiftTimes), METH_VARARGS, nullptr},
    {"supportsGroupwareCommunication", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_supportsGroupwareCommunication), METH_NOARGS, nullptr},
    {"transparency", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_transparency), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_type), METH_NOARGS, nullptr},
    {"typeStr", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_typeStr), METH_NOARGS, nullptr},
    {"virtual_hook", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_EventFunc_virtual_hook), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_KCalendarCore_Event_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::KCalendarCore::Event *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<EventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_KCalendarCore_Event_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_Event_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_KCalendarCore_EventSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::KCalendarCore::Event *>(obj);
    if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]))
        return static_cast< ::KCalendarCore::Incidence *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]))
        return static_cast< ::KCalendarCore::IncidenceBase *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]))
        return static_cast< ::KCalendarCore::CustomProperties *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_RecurrenceObserver_IDX]))
        return static_cast< ::KCalendarCore::Recurrence::RecurrenceObserver *>(me);
    return me;
}



// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_Event_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_KCalendarCore_Event_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_Event_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_Event_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_Event_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_Event_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_Event_spec = {
    "1:KCalendarCore.KCalendarCore.Event",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_Event_slots
};

} //extern "C"

static void *Sbk_KCalendarCore_Event_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::CustomProperties >())
        return dynamic_cast< ::KCalendarCore::Event *>(reinterpret_cast< ::KCalendarCore::CustomProperties *>(cptr));
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::Recurrence::RecurrenceObserver >())
        return dynamic_cast< ::KCalendarCore::Event *>(reinterpret_cast< ::KCalendarCore::Recurrence::RecurrenceObserver *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_KCalendarCore_Event_Transparency(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::Event::Transparency>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::Event::Transparency *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_Event_Transparency_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_Transparency_IDX])))
        return Enum_PythonToCpp_KCalendarCore_Event_Transparency;
    return {};
}

static PyObject *KCalendarCore_Event_Transparency_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::Event::Transparency>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::Event::Transparency *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Event_PythonToCpp_Event_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_Event_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Event_PythonToCpp_Event_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_Event_TypeF()))
        return Event_PythonToCpp_Event_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Event_PTR_CppToPython_Event(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_Event_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::KCalendarCore::Event *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_KCalendarCore_Event_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_Event_SignatureStrings[] = {
    "2:KCalendarCore.KCalendarCore.Event(self,*:KeywordOnly=None,dtEnd:QDateTime=None,transparency:KCalendarCore.KCalendarCore.Event.Transparency=None)",
    "1:KCalendarCore.KCalendarCore.Event(self,other:KCalendarCore.KCalendarCore.Event,*:KeywordOnly=None,dtEnd:QDateTime=None,transparency:KCalendarCore.KCalendarCore.Event.Transparency=None)",
    "0:KCalendarCore.KCalendarCore.Event(self,other:KCalendarCore.KCalendarCore.Incidence,*:KeywordOnly=None,dtEnd:QDateTime=None,transparency:KCalendarCore.KCalendarCore.Event.Transparency=None)",
    "KCalendarCore.KCalendarCore.Event.clone(self)->KCalendarCore.KCalendarCore.Event",
    "KCalendarCore.KCalendarCore.Event.dateEnd(self)->PySide6.QtCore.QDate",
    "KCalendarCore.KCalendarCore.Event.dateTime(self,role:KCalendarCore.KCalendarCore.IncidenceBase.DateTimeRole)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Event.deserialize(self,in:PySide6.QtCore.QDataStream)",
    "KCalendarCore.KCalendarCore.Event.dtEnd(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Event.equals(self,event:KCalendarCore.KCalendarCore.IncidenceBase)->bool",
    "KCalendarCore.KCalendarCore.Event.eventMimeType()->QLatin1String",
    "KCalendarCore.KCalendarCore.Event.hasEndDate(self)->bool",
    "KCalendarCore.KCalendarCore.Event.iconName(self,recurrenceId:PySide6.QtCore.QDateTime={})->QLatin1String",
    "KCalendarCore.KCalendarCore.Event.isMultiDay(self,zone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization]={})->bool",
    "KCalendarCore.KCalendarCore.Event.mimeType(self)->QLatin1String",
    "KCalendarCore.KCalendarCore.Event.serialize(self,out:PySide6.QtCore.QDataStream)",
    "KCalendarCore.KCalendarCore.Event.setAllDay(self,allDay:bool)",
    "KCalendarCore.KCalendarCore.Event.setDateTime(self,dateTime:PySide6.QtCore.QDateTime,role:KCalendarCore.KCalendarCore.IncidenceBase.DateTimeRole)",
    "KCalendarCore.KCalendarCore.Event.setDtEnd(self,dtEnd:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.Event.setDtStart(self,dt:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.Event.setDuration(self,duration:typing.Union[KCalendarCore.KCalendarCore.Duration, int])",
    "KCalendarCore.KCalendarCore.Event.setTransparency(self,transparency:KCalendarCore.KCalendarCore.Event.Transparency)",
    "KCalendarCore.KCalendarCore.Event.shiftTimes(self,oldZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization],newZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "KCalendarCore.KCalendarCore.Event.supportsGroupwareCommunication(self)->bool",
    "KCalendarCore.KCalendarCore.Event.transparency(self)->KCalendarCore.KCalendarCore.Event.Transparency",
    "KCalendarCore.KCalendarCore.Event.type(self)->KCalendarCore.KCalendarCore.IncidenceBase.IncidenceType",
    "KCalendarCore.KCalendarCore.Event.typeStr(self)->PySide6.QtCore.QByteArray",
    "KCalendarCore.KCalendarCore.Event.virtual_hook(self,id:KCalendarCore.KCalendarCore.IncidenceBase.VirtualHook,data:void)",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_Event_SignatureByteSize = 542;
static constexpr uint8_t KCalendarCore_Event_SignatureBytes[542] = {
    0x78, 0xda, 0xbd, 0x55, 0x4d, 0x4f, 0xdb, 0x40, 0x10, 0xbd, 0xf3, 0x2b, 0x38, 0x92, 0x2a, 0xb5,
    0x4a, 0x0f, 0x3d, 0x58, 0xa2, 0x12, 0x24, 0x08, 0x10, 0x85, 0x36, 0x4d, 0xda, 0x03, 0x15, 0xaa,
    0xa6, 0xde, 0xa1, 0x59, 0x75, 0xbd, 0xeb, 0xae, 0xc7, 0x89, 0x0c, 0xea, 0x7f, 0xef, 0xac, 0x3f,
    0xd2, 0x24, 0xaa, 0xc9, 0x40, 0x80, 0x4b, 0x14, 0xdb, 0x3b, 0x6f, 0xde, 0x7b, 0xb3, 0x33, 0xf3,
    0x36, 0x3e, 0x1f, 0x80, 0x41, 0xab, 0xc0, 0x0f, 0x9c, 0xc7, 0x68, 0xf5, 0xe9, 0x78, 0x86, 0x96,
    0xf6, 0x72, 0x34, 0x37, 0xfd, 0x57, 0xf1, 0x39, 0x96, 0x73, 0xe7, 0xd5, 0x47, 0x6b, 0xca, 0x83,
    0x4b, 0x67, 0xb1, 0xaf, 0xe8, 0xd8, 0xaa, 0x78, 0x34, 0x04, 0xc2, 0x89, 0x4e, 0xb1, 0x7e, 0x49,
    0x1e, 0x6c, 0x9e, 0x81, 0x47, 0x9b, 0x94, 0x9b, 0xb1, 0xa3, 0xc9, 0xd2, 0xf1, 0x0a, 0xa0, 0xb7,
    0xb3, 0x2f, 0xa5, 0xe4, 0x68, 0x8a, 0x7e, 0xf3, 0xe1, 0x17, 0xa4, 0xfe, 0xe6, 0xe9, 0xa8, 0x9f,
    0xd9, 0x44, 0x2b, 0x86, 0xc6, 0x17, 0xa4, 0xbf, 0x39, 0x28, 0x31, 0x7c, 0xb0, 0x92, 0xd0, 0x7b,
    0xfd, 0x7e, 0xe3, 0x71, 0x01, 0xa0, 0x62, 0x09, 0xac, 0xa5, 0x85, 0xfc, 0x54, 0x8e, 0x59, 0xf5,
    0xbb, 0x68, 0x44, 0xd5, 0x99, 0x4a, 0xa1, 0x10, 0x25, 0x18, 0x51, 0x9b, 0xeb, 0x9d, 0x41, 0x99,
    0xb7, 0x47, 0x90, 0x63, 0xd4, 0xba, 0xf8, 0x99, 0xc3, 0x3a, 0x28, 0x84, 0xcf, 0x12, 0x1a, 0x98,
    0xa3, 0xd7, 0x60, 0xf4, 0x6d, 0xc3, 0x44, 0xdb, 0xf8, 0x3f, 0x70, 0x30, 0x26, 0x8f, 0x90, 0x4a,
    0xfc, 0xae, 0x0a, 0x7d, 0x9f, 0x39, 0x42, 0x66, 0xf8, 0xbb, 0x00, 0x93, 0xd7, 0xa4, 0x30, 0xbc,
    0x91, 0xfb, 0xc3, 0x89, 0x7f, 0x38, 0x67, 0x24, 0x49, 0xc2, 0xef, 0x05, 0x13, 0x9a, 0x94, 0x19,
    0xee, 0x71, 0xdc, 0xe8, 0x03, 0x90, 0xb6, 0xfb, 0x2c, 0x57, 0xdb, 0x9f, 0x02, 0x80, 0x29, 0xe4,
    0x2c, 0x37, 0xc8, 0x6a, 0x25, 0x0b, 0x33, 0xeb, 0xc4, 0xd9, 0x4b, 0x58, 0xd4, 0x1f, 0x93, 0xc2,
    0x87, 0x7b, 0x8d, 0x67, 0x2a, 0xee, 0x32, 0xed, 0xe0, 0xee, 0xcf, 0x23, 0x18, 0xea, 0xfc, 0xa2,
    0x30, 0xa4, 0x87, 0x50, 0xd6, 0xa9, 0x6e, 0xb9, 0x1d, 0x62, 0x2a, 0x33, 0x8e, 0x8e, 0xbe, 0x58,
    0xed, 0xec, 0xb7, 0xf5, 0x7c, 0x21, 0xd7, 0x55, 0x68, 0xcf, 0xdd, 0xae, 0x2f, 0x6c, 0xb7, 0xa6,
    0xea, 0xd6, 0x30, 0x17, 0x67, 0xaf, 0x6b, 0x66, 0x42, 0xe5, 0x69, 0x6b, 0x77, 0x63, 0xd8, 0x43,
    0x05, 0xad, 0x5d, 0x58, 0x57, 0xd0, 0x96, 0x37, 0x36, 0x47, 0x3a, 0x34, 0x66, 0x61, 0x10, 0x54,
    0xff, 0xe3, 0xa0, 0x46, 0x18, 0x3d, 0x5c, 0xe9, 0xe5, 0xb6, 0xb3, 0x3b, 0xeb, 0xb8, 0x55, 0xb7,
    0x0b, 0x19, 0x2d, 0x9a, 0xb0, 0x19, 0xbc, 0x5d, 0x5c, 0xc4, 0x78, 0x63, 0x02, 0x4f, 0x2d, 0xe2,
    0xd6, 0x70, 0x85, 0xaf, 0x2e, 0x4e, 0x83, 0xd7, 0x3c, 0xad, 0xde, 0xca, 0xfb, 0x80, 0xda, 0xf8,
    0xfe, 0xae, 0xb6, 0x74, 0x2d, 0x4c, 0xba, 0xbc, 0x3d, 0xea, 0xc4, 0x5b, 0xac, 0x1f, 0x51, 0xce,
    0xa9, 0xbe, 0xa1, 0xe0, 0x4a, 0x33, 0xc5, 0x9c, 0x51, 0x57, 0xcf, 0xd0, 0x7c, 0x7d, 0x8b, 0xf3,
    0xe7, 0xc0, 0x15, 0x49, 0x2c, 0xb2, 0xcc, 0x79, 0xca, 0x4f, 0xbc, 0x2b, 0xb2, 0x39, 0x5b, 0x33,
    0x70, 0x69, 0x5a, 0x58, 0x9d, 0xfc, 0x2b, 0xaf, 0x7c, 0x30, 0xd0, 0x7a, 0x81, 0x24, 0x0b, 0x7b,
    0xa5, 0x2a, 0x92, 0x24, 0x4b, 0x93, 0x47, 0xde, 0x82, 0x8b, 0xa7, 0x30, 0xb8, 0x84, 0x59, 0x78,
    0x00, 0x75, 0xad, 0xc1, 0xa3, 0x92, 0xf0, 0xd0, 0x7b, 0x90, 0x10, 0x9e, 0x69, 0x4f, 0xbc, 0x09,
    0xbf, 0x4f, 0x9d, 0xfb, 0xd5, 0xac, 0x68, 0xf5, 0x80, 0xe1, 0xf1, 0xb5, 0x0e, 0x3f, 0xe5, 0xe8,
    0x30, 0x99, 0x20, 0x9e, 0x39, 0xad, 0x7a, 0x3b, 0x7f, 0x01, 0xf1, 0x15, 0x1a, 0xd6
};
#endif

PyTypeObject *init_KCalendarCore_Event(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]));
    Shiboken::AutoDecRef Sbk_KCalendarCore_Event_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Event",
        "KCalendarCore::Event*",
        &Sbk_KCalendarCore_Event_spec,
        &Shiboken::callCppDestructor< KCalendarCore::Event >,
        Sbk_KCalendarCore_Event_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_Event_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_Event_SignatureBytes, KCalendarCore_Event_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_Event_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Event_PythonToCpp_Event_PTR,
        is_Event_PythonToCpp_Event_PTR_Convertible,
        Event_PTR_CppToPython_Event);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Event");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Event*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Event&");
    Shiboken::Conversions::registerConverterAlias(converter, "Event");
    Shiboken::Conversions::registerConverterAlias(converter, "Event*");
    Shiboken::Conversions::registerConverterAlias(converter, "Event&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::Event).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(EventWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_KCalendarCore_Event_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_KCalendarCore_Event_TypeF(), &Sbk_KCalendarCore_EventSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_KCalendarCore_Event_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_KCalendarCore_Event_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'Transparency'.
    const char *Transparency_Initializer[] = {
        "Opaque",
        "Transparent",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Transparency_InitializerValues[] = {
        uint8_t(KCalendarCore::Event::Transparency::Opaque),     //  0x00  0
        uint8_t(KCalendarCore::Event::Transparency::Transparent) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.Event.Transparency",
        Transparency_Initializer, Transparency_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Event_Transparency_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::Event::Transparency'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_Event_Transparency_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_Event_Transparency,
            is_Enum_PythonToCpp_KCalendarCore_Event_Transparency_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Event::Transparency");
        Shiboken::Conversions::registerConverterAlias(converter, "Event::Transparency");
        Shiboken::Conversions::registerConverterAlias(converter, "Transparency");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Transparency' enum.

    qRegisterMetaType< ::KCalendarCore::Event *>();
    qRegisterMetaType< ::KCalendarCore::Event::Transparency >("Event::Transparency");
    qRegisterMetaType< ::KCalendarCore::Event::Transparency >("KCalendarCore::Event::Transparency");

    return pyType;
}
