/****************************************************************************
** Meta object code from reading C++ file 'attendee.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kcalendarcore-6.26.0/src/attendee.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'attendee.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KCalendarCore8AttendeeE_t {};
} // unnamed namespace

template <> constexpr inline auto KCalendarCore::Attendee::qt_create_metaobjectdata<qt_meta_tag_ZN13KCalendarCore8AttendeeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCalendarCore::Attendee",
        "isNull",
        "name",
        "fullName",
        "email",
        "role",
        "Role",
        "uid",
        "status",
        "PartStat",
        "cuType",
        "CuType",
        "rsvp",
        "delegate",
        "delegator",
        "NeedsAction",
        "Accepted",
        "Declined",
        "Tentative",
        "Delegated",
        "Completed",
        "InProcess",
        "None",
        "ReqParticipant",
        "OptParticipant",
        "NonParticipant",
        "Chair",
        "Individual",
        "Group",
        "Resource",
        "Room",
        "Unknown"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isNull'
        QtMocHelpers::PropertyData<bool>(1, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'fullName'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'email'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'role'
        QtMocHelpers::PropertyData<enum Role>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'uid'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'status'
        QtMocHelpers::PropertyData<enum PartStat>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'cuType'
        QtMocHelpers::PropertyData<enum CuType>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'rsvp'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'delegate'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'delegator'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PartStat'
        QtMocHelpers::EnumData<enum PartStat>(9, 9, QMC::EnumFlags{}).add({
            {   15, PartStat::NeedsAction },
            {   16, PartStat::Accepted },
            {   17, PartStat::Declined },
            {   18, PartStat::Tentative },
            {   19, PartStat::Delegated },
            {   20, PartStat::Completed },
            {   21, PartStat::InProcess },
            {   22, PartStat::None },
        }),
        // enum 'Role'
        QtMocHelpers::EnumData<enum Role>(6, 6, QMC::EnumFlags{}).add({
            {   23, Role::ReqParticipant },
            {   24, Role::OptParticipant },
            {   25, Role::NonParticipant },
            {   26, Role::Chair },
        }),
        // enum 'CuType'
        QtMocHelpers::EnumData<enum CuType>(11, 11, QMC::EnumFlags{}).add({
            {   27, CuType::Individual },
            {   28, CuType::Group },
            {   29, CuType::Resource },
            {   30, CuType::Room },
            {   31, CuType::Unknown },
        }),
    };
    return QtMocHelpers::metaObjectData<Attendee, qt_meta_tag_ZN13KCalendarCore8AttendeeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCalendarCore::Attendee::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore8AttendeeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore8AttendeeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KCalendarCore8AttendeeE_t>.metaTypes,
    nullptr
} };

void KCalendarCore::Attendee::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Attendee *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isNull(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->fullName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->email(); break;
        case 4: *reinterpret_cast<enum Role*>(_v) = _t->role(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->uid(); break;
        case 6: *reinterpret_cast<enum PartStat*>(_v) = _t->status(); break;
        case 7: *reinterpret_cast<enum CuType*>(_v) = _t->cuType(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->RSVP(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->delegate(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->delegator(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setEmail(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setRole(*reinterpret_cast<enum Role*>(_v)); break;
        case 5: _t->setUid(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setStatus(*reinterpret_cast<enum PartStat*>(_v)); break;
        case 7: _t->setCuType(*reinterpret_cast<enum CuType*>(_v)); break;
        case 8: _t->setRSVP(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setDelegate(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setDelegator(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
