
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_calendar_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <calendar.h>
#include <calfilter.h>
#include <person.h>
#include <qbytearray.h>
#include <qdatetime.h>
#include <qicon.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qtimezone.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_Calendar_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_Calendar_Init([[maybe_unused]] PyObject *self, [[maybe_unused]] PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    Shiboken::Errors::setInstantiateAbstractClassDisabledWrapper("KCalendarCore::Calendar");
    return -1;
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_accessMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::accessMode()const->KCalendarCore::AccessMode
        KCalendarCore::AccessMode cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->accessMode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_AccessMode_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_batchAdding(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::batchAdding()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->batchAdding();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_categories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::categories()const->QStringList
        QStringList cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->categories();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_color(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::color()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->color();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_endBatchAdding(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::endBatchAdding()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::KCalendarCore::Calendar::endBatchAdding()
            : cppSelf->endBatchAdding();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_filter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::filter()const->KCalendarCore::CalFilter*
        KCalendarCore::CalFilter * cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->filter();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CalFilter_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_icon(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::icon()const->QIcon
        QIcon cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->icon();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::id()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->id();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_isLoading(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::isLoading()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->isLoading();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_isModified(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::isModified()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->isModified();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::name()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_owner(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::owner()const->KCalendarCore::Person
        KCalendarCore::Person* cppResult = new KCalendarCore::Person(const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->owner());
        pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), cppResult, true, true);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_productId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::productId()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->productId();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_setAccessMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Calendar::setAccessMode(const KCalendarCore::AccessMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_AccessMode_IDX]))), (pyArg)))) {
        overloadId = 0; // Calendar::setAccessMode(const KCalendarCore::AccessMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAccessMode", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        ::KCalendarCore::AccessMode cppArg0{KCalendarCore::ReadOnly};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::setAccessMode(const KCalendarCore::AccessMode)
            cppSelf->setAccessMode(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_setColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Calendar::setColor(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Calendar::setColor(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColor", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::setColor(const QString&)
            cppSelf->setColor(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_setFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Calendar::setFilter(KCalendarCore::CalFilter*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CalFilter_IDX]), (pyArg)))) {
        overloadId = 0; // Calendar::setFilter(KCalendarCore::CalFilter*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFilter", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::CalFilter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::setFilter(KCalendarCore::CalFilter*)
            cppSelf->setFilter(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_setIcon(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Calendar::setIcon(const QIcon&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), (pyArg)))) {
        overloadId = 0; // Calendar::setIcon(const QIcon&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIcon", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QIcon cppArg0_local;
        ::QIcon *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::setIcon(const QIcon&)
            cppSelf->setIcon(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_setId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Calendar::setId(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Calendar::setId(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setId", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::setId(const QString&)
            cppSelf->setId(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_setModified(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Calendar::setModified(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Calendar::setModified(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setModified", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::setModified(bool)
            cppSelf->setModified(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Calendar::setName(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Calendar::setName(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::setName(const QString&)
            cppSelf->setName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_setOwner(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Calendar::setOwner(const KCalendarCore::Person&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), (pyArg)))) {
        overloadId = 0; // Calendar::setOwner(const KCalendarCore::Person&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOwner", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::Person *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::setOwner(const KCalendarCore::Person&)
            cppSelf->setOwner(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_setProductId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Calendar::setProductId(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Calendar::setProductId(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProductId", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::setProductId(const QString&)
            cppSelf->setProductId(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_setTimeZone(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Calendar::setTimeZone(const QTimeZone&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArg)))) {
        overloadId = 0; // Calendar::setTimeZone(const QTimeZone&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTimeZone", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::setTimeZone(const QTimeZone&)
            cppSelf->setTimeZone(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_setTimeZoneId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Calendar::setTimeZoneId(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Calendar::setTimeZoneId(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTimeZoneId", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::setTimeZoneId(const QByteArray&)
            cppSelf->setTimeZoneId(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_shiftTimes(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "shiftTimes", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Calendar::shiftTimes(const QTimeZone&,const QTimeZone&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // Calendar::shiftTimes(const QTimeZone&,const QTimeZone&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "shiftTimes", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Calendar::shiftTimes(const QTimeZone&,const QTimeZone&)
            cppSelf->shiftTimes(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_startBatchAdding(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::startBatchAdding()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::KCalendarCore::Calendar::startBatchAdding()
            : cppSelf->startBatchAdding();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_timeZone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::timeZone()const->QTimeZone
        QTimeZone cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->timeZone();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CalendarFunc_timeZoneId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Calendar *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::timeZoneId()const->QByteArray
        QByteArray cppResult = const_cast<const ::KCalendarCore::Calendar *>(cppSelf)->timeZoneId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_KCalendarCore_Calendar_PropertyStrings[] = {
    "accessMode::",
    "color::",
    "icon::",
    "id::",
    "isLoading:",
    "name::",
    "owner::",
    "productId::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_Calendar_methods[] = {
    {"accessMode", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_accessMode), METH_NOARGS, nullptr},
    {"batchAdding", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_batchAdding), METH_NOARGS, nullptr},
    {"categories", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_categories), METH_NOARGS, nullptr},
    {"color", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_color), METH_NOARGS, nullptr},
    {"endBatchAdding", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_endBatchAdding), METH_NOARGS, nullptr},
    {"filter", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_filter), METH_NOARGS, nullptr},
    {"icon", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_icon), METH_NOARGS, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_id), METH_NOARGS, nullptr},
    {"isLoading", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_isLoading), METH_NOARGS, nullptr},
    {"isModified", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_isModified), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_name), METH_NOARGS, nullptr},
    {"owner", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_owner), METH_NOARGS, nullptr},
    {"productId", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_productId), METH_NOARGS, nullptr},
    {"setAccessMode", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_setAccessMode), METH_O, nullptr},
    {"setColor", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_setColor), METH_O, nullptr},
    {"setFilter", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_setFilter), METH_O, nullptr},
    {"setIcon", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_setIcon), METH_O, nullptr},
    {"setId", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_setId), METH_O, nullptr},
    {"setModified", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_setModified), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_setName), METH_O, nullptr},
    {"setOwner", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_setOwner), METH_O, nullptr},
    {"setProductId", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_setProductId), METH_O, nullptr},
    {"setTimeZone", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_setTimeZone), METH_O, nullptr},
    {"setTimeZoneId", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_setTimeZoneId), METH_O, nullptr},
    {"shiftTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_shiftTimes), METH_VARARGS, nullptr},
    {"startBatchAdding", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_startBatchAdding), METH_NOARGS, nullptr},
    {"timeZone", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_timeZone), METH_NOARGS, nullptr},
    {"timeZoneId", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CalendarFunc_timeZoneId), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_KCalendarCore_Calendar_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_KCalendarCore_Calendar_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_Calendar_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
int *
Sbk_KCalendarCore_Calendar_mi_init(const void *cptr)
{
    static int mi_offsets[] = {-2, 0, 0, 0, 0, 0, 0};
    if (mi_offsets[0] == -2) {
        const auto *class_ptr = reinterpret_cast<const KCalendarCore::Calendar *>(cptr);
        const auto base = reinterpret_cast<uintptr_t>(class_ptr);
        int *p = mi_offsets;
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(static_cast<const KCalendarCore::Calendar *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const KCalendarCore::CustomProperties *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const KCalendarCore::CustomProperties *>(static_cast<const KCalendarCore::Calendar *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const KCalendarCore::IncidenceBase::IncidenceObserver *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const KCalendarCore::IncidenceBase::IncidenceObserver *>(static_cast<const KCalendarCore::Calendar *>(static_cast<const void *>(class_ptr)))) - base);
        std::sort(mi_offsets, p);
        auto *end = std::unique(mi_offsets, p);
        *end++ = -1;
        if (mi_offsets[0] == 0)
            std::memmove(&mi_offsets[0], &mi_offsets[1], (end - mi_offsets  - 1) * sizeof(int));
    }
    return mi_offsets;
}
static void * Sbk_KCalendarCore_CalendarSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::KCalendarCore::Calendar *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]))
        return static_cast< ::KCalendarCore::CustomProperties *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]))
        return static_cast< ::KCalendarCore::IncidenceBase::IncidenceObserver *>(me);
    return me;
}



// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_Calendar_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_KCalendarCore_Calendar_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_Calendar_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_Calendar_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_Calendar_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_Calendar_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_Calendar_spec = {
    "1:KCalendarCore.KCalendarCore.Calendar",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_Calendar_slots
};

} //extern "C"

static void *Sbk_KCalendarCore_Calendar_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::KCalendarCore::Calendar *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::CustomProperties >())
        return dynamic_cast< ::KCalendarCore::Calendar *>(reinterpret_cast< ::KCalendarCore::CustomProperties *>(cptr));
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::IncidenceBase::IncidenceObserver >())
        return dynamic_cast< ::KCalendarCore::Calendar *>(reinterpret_cast< ::KCalendarCore::IncidenceBase::IncidenceObserver *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Calendar_PythonToCpp_Calendar_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_Calendar_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Calendar_PythonToCpp_Calendar_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_Calendar_TypeF()))
        return Calendar_PythonToCpp_Calendar_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Calendar_PTR_CppToPython_Calendar(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::KCalendarCore::Calendar *>(const_cast<void *>(cppIn)), Sbk_KCalendarCore_Calendar_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_Calendar_SignatureStrings[] = {
    "1:KCalendarCore.KCalendarCore.Calendar(self,timeZoneId:typing.Union[PySide6.QtCore.QByteArray, char*],*:KeywordOnly=None,productId:QString=None,owner:KCalendarCore.Person=None,id:QString=None,name:QString=None,icon:QIcon=None,color:QString=None,accessMode:KCalendarCore.KCalendarCore.AccessMode=None,isLoading:bool=None)",
    "0:KCalendarCore.KCalendarCore.Calendar(self,timeZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization],*:KeywordOnly=None,productId:QString=None,owner:KCalendarCore.Person=None,id:QString=None,name:QString=None,icon:QIcon=None,color:QString=None,accessMode:KCalendarCore.KCalendarCore.AccessMode=None,isLoading:bool=None)",
    "KCalendarCore.KCalendarCore.Calendar.accessMode(self)->KCalendarCore.KCalendarCore.AccessMode",
    "KCalendarCore.KCalendarCore.Calendar.batchAdding(self)->bool",
    "KCalendarCore.KCalendarCore.Calendar.categories(self)->QStringList",
    "KCalendarCore.KCalendarCore.Calendar.color(self)->QString",
    "KCalendarCore.KCalendarCore.Calendar.endBatchAdding(self)",
    "KCalendarCore.KCalendarCore.Calendar.filter(self)->KCalendarCore.KCalendarCore.CalFilter",
    "KCalendarCore.KCalendarCore.Calendar.icon(self)->PySide6.QtGui.QIcon",
    "KCalendarCore.KCalendarCore.Calendar.id(self)->QString",
    "KCalendarCore.KCalendarCore.Calendar.isLoading(self)->bool",
    "KCalendarCore.KCalendarCore.Calendar.isModified(self)->bool",
    "KCalendarCore.KCalendarCore.Calendar.name(self)->QString",
    "KCalendarCore.KCalendarCore.Calendar.owner(self)->KCalendarCore.KCalendarCore.Person",
    "KCalendarCore.KCalendarCore.Calendar.productId(self)->QString",
    "KCalendarCore.KCalendarCore.Calendar.setAccessMode(self,mode:KCalendarCore.KCalendarCore.AccessMode)",
    "KCalendarCore.KCalendarCore.Calendar.setColor(self,color:QString)",
    "KCalendarCore.KCalendarCore.Calendar.setFilter(self,filter:KCalendarCore.KCalendarCore.CalFilter)",
    "KCalendarCore.KCalendarCore.Calendar.setIcon(self,icon:typing.Union[PySide6.QtGui.QIcon, PySide6.QtGui.QPixmap])",
    "KCalendarCore.KCalendarCore.Calendar.setId(self,id:QString)",
    "KCalendarCore.KCalendarCore.Calendar.setModified(self,modified:bool)",
    "KCalendarCore.KCalendarCore.Calendar.setName(self,name:QString)",
    "KCalendarCore.KCalendarCore.Calendar.setOwner(self,owner:KCalendarCore.KCalendarCore.Person)",
    "KCalendarCore.KCalendarCore.Calendar.setProductId(self,id:QString)",
    "KCalendarCore.KCalendarCore.Calendar.setTimeZone(self,timeZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "KCalendarCore.KCalendarCore.Calendar.setTimeZoneId(self,timeZoneId:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "KCalendarCore.KCalendarCore.Calendar.shiftTimes(self,oldZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization],newZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "KCalendarCore.KCalendarCore.Calendar.startBatchAdding(self)",
    "KCalendarCore.KCalendarCore.Calendar.timeZone(self)->PySide6.QtCore.QTimeZone",
    "KCalendarCore.KCalendarCore.Calendar.timeZoneId(self)->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_Calendar_SignatureByteSize = 488;
static constexpr uint8_t KCalendarCore_Calendar_SignatureBytes[488] = {
    0x78, 0xda, 0xdd, 0x56, 0x4d, 0x4b, 0xc3, 0x40, 0x10, 0xbd, 0xfb, 0x2b, 0x3c, 0x5a, 0x89, 0x41,
    0x2f, 0x1e, 0x02, 0x0a, 0x6d, 0x41, 0x29, 0x7e, 0xb4, 0xa5, 0x7a, 0x51, 0x7a, 0x58, 0x77, 0xa7,
    0x76, 0x20, 0xdd, 0x2d, 0xbb, 0x5b, 0x6a, 0xfc, 0xf5, 0x26, 0x9b, 0x6c, 0xda, 0x0d, 0x56, 0x26,
    0x01, 0x11, 0xbc, 0x04, 0x76, 0x33, 0xf3, 0x66, 0xf2, 0xe6, 0xcd, 0x4c, 0x2e, 0x92, 0xbb, 0x21,
    0x4b, 0x41, 0x0a, 0xa6, 0x87, 0x4a, 0x43, 0x1c, 0x9e, 0xfc, 0xe1, 0xc4, 0x40, 0xba, 0x88, 0x2c,
    0xae, 0xe0, 0x45, 0x49, 0x18, 0x89, 0xc4, 0x66, 0x6b, 0x94, 0xef, 0xf1, 0xb3, 0x44, 0x25, 0x5f,
    0x27, 0xd9, 0x0c, 0x05, 0x5c, 0xc6, 0x53, 0xeb, 0x9c, 0xa6, 0x83, 0xcc, 0x42, 0x5f, 0x6b, 0x96,
    0x45, 0xc7, 0x7c, 0xc9, 0xf4, 0xe9, 0x3c, 0x3a, 0x4d, 0xee, 0x20, 0xdb, 0x2a, 0x2d, 0xc6, 0x32,
    0xcd, 0xae, 0x1e, 0x73, 0x8c, 0x68, 0xad, 0x95, 0xd8, 0x70, 0x9b, 0x63, 0x4d, 0x67, 0x56, 0xe7,
    0x60, 0xe5, 0xb5, 0xda, 0x4a, 0xd0, 0x8d, 0x9c, 0x26, 0xa0, 0x8d, 0x92, 0xe5, 0x7b, 0x6c, 0xd8,
    0x4b, 0xb6, 0x82, 0xf0, 0x06, 0xb9, 0x92, 0xc9, 0x74, 0xc4, 0xbd, 0x07, 0x57, 0xa9, 0xd2, 0xa1,
    0x09, 0xe3, 0x1c, 0x8c, 0x79, 0x50, 0x02, 0x7e, 0xfc, 0xfa, 0x7e, 0x6d, 0x56, 0x21, 0x9b, 0x7b,
    0xc5, 0x44, 0x8e, 0x92, 0xbc, 0x29, 0x95, 0xba, 0xbb, 0xde, 0xd1, 0x79, 0x07, 0x02, 0x7f, 0xa6,
    0xef, 0xa9, 0xb2, 0x8a, 0x8e, 0x0f, 0xbd, 0x89, 0x47, 0x12, 0x2d, 0xb2, 0x14, 0x3f, 0x99, 0xcd,
    0x11, 0xfe, 0x35, 0xbf, 0x14, 0x76, 0xe3, 0x5d, 0x40, 0x47, 0x74, 0xef, 0xec, 0x9a, 0x16, 0x97,
    0x86, 0xfe, 0xc6, 0x2c, 0x5f, 0xf6, 0x45, 0x91, 0x99, 0x87, 0x2f, 0x12, 0xa4, 0x39, 0x73, 0x66,
    0xe1, 0x5d, 0x69, 0x04, 0xe3, 0x7d, 0x2b, 0xaa, 0xee, 0xd1, 0x58, 0x22, 0x44, 0xc1, 0x70, 0xc3,
    0x9b, 0xe6, 0x99, 0x3f, 0x07, 0xcd, 0xe4, 0x69, 0x9e, 0x0b, 0x4c, 0x2d, 0x68, 0x0a, 0x9b, 0xf9,
    0xe1, 0xc6, 0x19, 0xd3, 0x80, 0x0b, 0xf9, 0x78, 0xd8, 0x9d, 0xbe, 0x6f, 0x37, 0x18, 0x3b, 0x4d,
    0x11, 0x41, 0x44, 0x27, 0x3a, 0x6a, 0x81, 0xb5, 0x2f, 0x23, 0x16, 0x7a, 0xc1, 0x05, 0x82, 0x68,
    0xef, 0x5b, 0xf4, 0x50, 0xa7, 0x7c, 0x5d, 0xb3, 0x52, 0x6a, 0x50, 0x76, 0x30, 0x0d, 0xb4, 0x1e,
    0x0c, 0x9d, 0x52, 0x32, 0x60, 0xfb, 0x61, 0xb3, 0x45, 0x2b, 0x7a, 0x9f, 0xf7, 0xc8, 0x41, 0x86,
    0xb5, 0xe6, 0xc3, 0x01, 0x43, 0x47, 0xb8, 0xd9, 0x29, 0x38, 0x2a, 0xd5, 0x9c, 0x90, 0x64, 0x4c,
    0x8f, 0x30, 0xf2, 0x52, 0x2e, 0x67, 0xe2, 0x81, 0xa1, 0x5e, 0x4b, 0x7b, 0x7f, 0x9e, 0xbb, 0xcb,
    0x09, 0x7e, 0xac, 0xd8, 0x7a, 0xde, 0x22, 0xa0, 0xa8, 0xc2, 0x89, 0xf6, 0x74, 0x04, 0xf2, 0x2d,
    0x6a, 0xe6, 0x4e, 0x6e, 0xd2, 0xd2, 0x41, 0x1e, 0xbd, 0x92, 0x83, 0xbd, 0x40, 0xf7, 0x1f, 0xd7,
    0x82, 0xfe, 0x76, 0x11, 0x7d, 0x27, 0x6a, 0x3a, 0xf8, 0x24, 0x10, 0x76, 0x27, 0x92, 0xfc, 0x82,
    0xfd, 0xdd, 0x75, 0xdd, 0x3e, 0x1f, 0xff, 0x4d, 0x9d, 0xff, 0xc0, 0xa8, 0x21, 0x97, 0xb8, 0x70,
    0x41, 0x4d, 0x55, 0xa4, 0x54, 0xfc, 0xca, 0xff, 0x8a, 0x84, 0xed, 0x5f, 0x12, 0x6b, 0x99, 0xb6,
    0x1d, 0xf7, 0xa2, 0xdd, 0x57, 0x48, 0xb0, 0xc2, 0xc2, 0xd4, 0xda, 0xa1, 0xed, 0x86, 0xf1, 0xc1,
    0x4a, 0x1e, 0x7d, 0x01, 0x6f, 0xea, 0x3b, 0xd9
};
#endif

PyTypeObject *init_KCalendarCore_Calendar(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]));
    auto *base2 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]));
    auto *base3 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]));
    Shiboken::AutoDecRef Sbk_KCalendarCore_Calendar_Type_bases(PyTuple_Pack(3, base1, base2, base3));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Calendar",
        "KCalendarCore::Calendar*",
        &Sbk_KCalendarCore_Calendar_spec,
        &Shiboken::callCppDestructor< ::KCalendarCore::Calendar >,
        Sbk_KCalendarCore_Calendar_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_Calendar_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_Calendar_SignatureBytes, KCalendarCore_Calendar_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_Calendar_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Calendar_PythonToCpp_Calendar_PTR,
        is_Calendar_PythonToCpp_Calendar_PTR_Convertible,
        Calendar_PTR_CppToPython_Calendar);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Calendar");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Calendar*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Calendar&");
    Shiboken::Conversions::registerConverterAlias(converter, "Calendar");
    Shiboken::Conversions::registerConverterAlias(converter, "Calendar*");
    Shiboken::Conversions::registerConverterAlias(converter, "Calendar&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::Calendar).name());

    MultipleInheritanceInitFunction func = Sbk_KCalendarCore_Calendar_mi_init;
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_KCalendarCore_Calendar_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_KCalendarCore_Calendar_TypeF(), &Sbk_KCalendarCore_CalendarSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_KCalendarCore_Calendar_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::KCalendarCore::Calendar::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::KCalendarCore::Calendar::staticMetaObject, sizeof(::KCalendarCore::Calendar));

    return pyType;
}
