
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_customproperties_wrapper.h"

// Wrappers providing overrides
#include "kcalendarcore_customproperties_wrapper.h"

// Argument includes
#include <QMap>
#include <QString>
#include <customproperties.h>
#include <qbytearray.h>
#include <qdatastream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_CustomProperties_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void CustomPropertiesWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

CustomPropertiesWrapper::CustomPropertiesWrapper()
{
}

void CustomPropertiesWrapper::customPropertyUpdate()
{
    static const char *funcName = "customPropertyUpdate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_CustomProperties_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::CustomProperties::customPropertyUpdate();
    }
    sbk_o_customPropertyUpdate("CustomProperties", funcName, gil, pyOverride);
}

void CustomPropertiesWrapper::sbk_o_customPropertyUpdate([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void CustomPropertiesWrapper::customPropertyUpdated()
{
    static const char *funcName = "customPropertyUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_CustomProperties_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::CustomProperties::customPropertyUpdated();
    }
    CustomPropertiesWrapper::sbk_o_customPropertyUpdate("CustomProperties", funcName, gil, pyOverride);
}

CustomPropertiesWrapper::~CustomPropertiesWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_KCalendarCore_CustomProperties_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_CustomProperties_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KCalendarCore::CustomProperties >()))
        return -1;

    CustomPropertiesWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "CustomProperties", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: CustomProperties::CustomProperties()
    // 1: CustomProperties::CustomProperties(const KCalendarCore::CustomProperties&)
    if (numArgs == 0) {
        overloadId = 0; // CustomProperties()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), (pyArgs[0])))) {
        overloadId = 1; // CustomProperties::CustomProperties(const KCalendarCore::CustomProperties&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // CustomProperties()
        {

            // CustomProperties::CustomProperties()
            cptr = new CustomPropertiesWrapper();
            break;
        }
        case 1: // CustomProperties(const KCalendarCore::CustomProperties &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KCalendarCore::CustomProperties *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // CustomProperties::CustomProperties(const KCalendarCore::CustomProperties&)
                cptr = new CustomPropertiesWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< KCalendarCore::CustomProperties >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_customProperties(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CustomProperties::customProperties()const->QMap<QByteArray,QString>
        QMap<QByteArray,QString> cppResult = const_cast<const ::KCalendarCore::CustomProperties *>(cppSelf)->customProperties();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QMap_QByteArray_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_customProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "customProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: CustomProperties::customProperty(const QByteArray&,const QByteArray&)const->QString
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // CustomProperties::customProperty(const QByteArray&,const QByteArray&)const->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "customProperty", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // CustomProperties::customProperty(const QByteArray&,const QByteArray&)const->QString
            QString cppResult = const_cast<const ::KCalendarCore::CustomProperties *>(cppSelf)->customProperty(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_customPropertyName([[maybe_unused]] PyObject *self, PyObject *args)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "customPropertyName", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static CustomProperties::customPropertyName(const QByteArray&,const QByteArray&)->QByteArray
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // static CustomProperties::customPropertyName(const QByteArray&,const QByteArray&)->QByteArray
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "customPropertyName", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static CustomProperties::customPropertyName(const QByteArray&,const QByteArray&)->QByteArray
            QByteArray cppResult = ::KCalendarCore::CustomProperties::customPropertyName(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_customPropertyUpdate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CustomProperties::customPropertyUpdate()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::KCalendarCore::CustomProperties::customPropertyUpdate()
            : cppSelf->customPropertyUpdate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_customPropertyUpdated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CustomProperties::customPropertyUpdated()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::KCalendarCore::CustomProperties::customPropertyUpdated()
            : cppSelf->customPropertyUpdated();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_nonKDECustomProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CustomProperties::nonKDECustomProperty(const QByteArray&)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // CustomProperties::nonKDECustomProperty(const QByteArray&)const->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "nonKDECustomProperty", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // CustomProperties::nonKDECustomProperty(const QByteArray&)const->QString
            QString cppResult = const_cast<const ::KCalendarCore::CustomProperties *>(cppSelf)->nonKDECustomProperty(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_nonKDECustomPropertyParameters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CustomProperties::nonKDECustomPropertyParameters(const QByteArray&)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // CustomProperties::nonKDECustomPropertyParameters(const QByteArray&)const->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "nonKDECustomPropertyParameters", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // CustomProperties::nonKDECustomPropertyParameters(const QByteArray&)const->QString
            QString cppResult = const_cast<const ::KCalendarCore::CustomProperties *>(cppSelf)->nonKDECustomPropertyParameters(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_removeCustomProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "removeCustomProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: CustomProperties::removeCustomProperty(const QByteArray&,const QByteArray&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // CustomProperties::removeCustomProperty(const QByteArray&,const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "removeCustomProperty", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // CustomProperties::removeCustomProperty(const QByteArray&,const QByteArray&)
            cppSelf->removeCustomProperty(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_removeNonKDECustomProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CustomProperties::removeNonKDECustomProperty(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // CustomProperties::removeNonKDECustomProperty(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeNonKDECustomProperty", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // CustomProperties::removeNonKDECustomProperty(const QByteArray&)
            cppSelf->removeNonKDECustomProperty(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_setCustomProperties(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CustomProperties::setCustomProperties(const QMap<QByteArray,QString>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QMap_QByteArray_QString_IDX], (pyArg)))) {
        overloadId = 0; // CustomProperties::setCustomProperties(const QMap<QByteArray,QString>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCustomProperties", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

    // Call function/method
    {
        ::QMap<QByteArray,QString> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CustomProperties::setCustomProperties(const QMap<QByteArray,QString>&)
            cppSelf->setCustomProperties(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_setCustomProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setCustomProperty", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: CustomProperties::setCustomProperty(const QByteArray&,const QByteArray&,const QString&)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // CustomProperties::setCustomProperty(const QByteArray&,const QByteArray&,const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCustomProperty", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CustomProperties::setCustomProperty(const QByteArray&,const QByteArray&,const QString&)
            cppSelf->setCustomProperty(*cppArg0, *cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc_setNonKDECustomProperty(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setNonKDECustomProperty", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setNonKDECustomProperty", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: CustomProperties::setNonKDECustomProperty(const QByteArray&,const QString&,const QString&=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setNonKDECustomProperty(QByteArray,QString,QString)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 0; // CustomProperties::setNonKDECustomProperty(const QByteArray&,const QString&,const QString&=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setNonKDECustomProperty", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parameters", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setNonKDECustomProperty", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2 = QString();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CustomProperties::setNonKDECustomProperty(const QByteArray&,const QString&,const QString&=)
            cppSelf->setNonKDECustomProperty(*cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_KCalendarCore_CustomProperties_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_CustomProperties_methods[] = {
    {"customProperties", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_customProperties), METH_NOARGS, nullptr},
    {"customProperty", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_customProperty), METH_VARARGS, nullptr},
    {"customPropertyName", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_customPropertyName), METH_VARARGS|METH_STATIC, nullptr},
    {"customPropertyUpdate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_customPropertyUpdate), METH_NOARGS, nullptr},
    {"customPropertyUpdated", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_customPropertyUpdated), METH_NOARGS, nullptr},
    {"nonKDECustomProperty", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_nonKDECustomProperty), METH_O, nullptr},
    {"nonKDECustomPropertyParameters", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_nonKDECustomPropertyParameters), METH_O, nullptr},
    {"removeCustomProperty", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_removeCustomProperty), METH_VARARGS, nullptr},
    {"removeNonKDECustomProperty", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_removeNonKDECustomProperty), METH_O, nullptr},
    {"setCustomProperties", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_setCustomProperties), METH_O, nullptr},
    {"setCustomProperty", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_setCustomProperty), METH_VARARGS, nullptr},
    {"setNonKDECustomProperty", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_CustomPropertiesFunc_setNonKDECustomProperty), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_KCalendarCore_CustomProperties_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<CustomPropertiesWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: CustomProperties::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // CustomProperties::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // CustomProperties::operator<<(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_CustomPropertiesFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: CustomProperties::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // CustomProperties::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // CustomProperties::operator>>(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

// Rich comparison
static PyObject * Sbk_KCalendarCore_CustomProperties_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::KCalendarCore::CustomProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), (pyArg)))) {
                // CustomProperties::operator==(const KCalendarCore::CustomProperties&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::CustomProperties *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_KCalendarCore_CustomProperties_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_CustomProperties_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_CustomProperties_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_KCalendarCore_CustomProperties_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_CustomProperties_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_CustomProperties_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_KCalendarCore_CustomProperties_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_CustomProperties_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_CustomProperties_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_CustomPropertiesFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_CustomPropertiesFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_CustomProperties_spec = {
    "1:KCalendarCore.KCalendarCore.CustomProperties",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_CustomProperties_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void CustomProperties_PythonToCpp_CustomProperties_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_CustomProperties_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_CustomProperties_PythonToCpp_CustomProperties_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_CustomProperties_TypeF()))
        return CustomProperties_PythonToCpp_CustomProperties_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *CustomProperties_PTR_CppToPython_CustomProperties(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_CustomProperties_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::KCalendarCore::CustomProperties *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_KCalendarCore_CustomProperties_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_CustomProperties_SignatureStrings[] = {
    "1:KCalendarCore.KCalendarCore.CustomProperties(self)",
    "0:KCalendarCore.KCalendarCore.CustomProperties(self,other:KCalendarCore.KCalendarCore.CustomProperties)",
    "KCalendarCore.KCalendarCore.CustomProperties.customProperties(self)->QMap[PySide6.QtCore.QByteArray, QString]",
    "KCalendarCore.KCalendarCore.CustomProperties.customProperty(self,app:typing.Union[PySide6.QtCore.QByteArray, char*],key:typing.Union[PySide6.QtCore.QByteArray, char*])->QString",
    "KCalendarCore.KCalendarCore.CustomProperties.customPropertyName(app:typing.Union[PySide6.QtCore.QByteArray, char*],key:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "KCalendarCore.KCalendarCore.CustomProperties.customPropertyUpdate(self)",
    "KCalendarCore.KCalendarCore.CustomProperties.customPropertyUpdated(self)",
    "KCalendarCore.KCalendarCore.CustomProperties.nonKDECustomProperty(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])->QString",
    "KCalendarCore.KCalendarCore.CustomProperties.nonKDECustomPropertyParameters(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])->QString",
    "KCalendarCore.KCalendarCore.CustomProperties.removeCustomProperty(self,app:typing.Union[PySide6.QtCore.QByteArray, char*],key:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "KCalendarCore.KCalendarCore.CustomProperties.removeNonKDECustomProperty(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "KCalendarCore.KCalendarCore.CustomProperties.setCustomProperties(self,properties:QMap[PySide6.QtCore.QByteArray, QString])",
    "KCalendarCore.KCalendarCore.CustomProperties.setCustomProperty(self,app:typing.Union[PySide6.QtCore.QByteArray, char*],key:typing.Union[PySide6.QtCore.QByteArray, char*],value:QString)",
    "KCalendarCore.KCalendarCore.CustomProperties.setNonKDECustomProperty(self,name:typing.Union[PySide6.QtCore.QByteArray, char*],value:QString,parameters:QString=QString())",
    "KCalendarCore.KCalendarCore.CustomProperties.__lshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.CustomProperties.__rshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.CustomProperties.__eq__(self,properties:KCalendarCore.KCalendarCore.CustomProperties)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_CustomProperties_SignatureByteSize = 314;
static constexpr uint8_t KCalendarCore_CustomProperties_SignatureBytes[314] = {
    0x78, 0xda, 0xc5, 0x95, 0x4d, 0x4f, 0x83, 0x40, 0x10, 0x86, 0xef, 0xfc, 0x0a, 0x8f, 0x60, 0x28,
    0xd1, 0x8b, 0x07, 0x12, 0x9b, 0x28, 0xf5, 0xd4, 0xd8, 0x40, 0x48, 0x4f, 0xa6, 0x21, 0x63, 0x99,
    0x0a, 0x11, 0x76, 0xd7, 0xd9, 0x69, 0x13, 0xfe, 0xbd, 0x58, 0x68, 0xb5, 0x86, 0x1a, 0xb7, 0x34,
    0xf4, 0xb4, 0xd9, 0x8f, 0x99, 0xf7, 0x99, 0x9d, 0xd9, 0xd9, 0x5b, 0x7f, 0x1a, 0x40, 0x81, 0x22,
    0x05, 0x0a, 0x24, 0xa1, 0x77, 0x38, 0x0b, 0xd6, 0x9a, 0x65, 0x19, 0x92, 0x54, 0x48, 0x9c, 0xa3,
    0xb6, 0x35, 0x16, 0x2b, 0xc7, 0xba, 0x31, 0x37, 0x72, 0x25, 0x67, 0x48, 0x46, 0x76, 0x8e, 0x65,
    0x72, 0xda, 0x5b, 0x76, 0xb2, 0x8e, 0xc6, 0xd1, 0x33, 0xa8, 0x97, 0xb0, 0x8a, 0xf3, 0x14, 0xef,
    0xbc, 0x88, 0xb7, 0xc6, 0xd1, 0x63, 0xc5, 0xf8, 0x40, 0x04, 0x95, 0x7b, 0x15, 0xc5, 0x4c, 0xb9,
    0x78, 0x5b, 0xf4, 0x50, 0xab, 0x9a, 0x10, 0x41, 0x29, 0x9f, 0x2b, 0x55, 0x3b, 0xf3, 0xe6, 0x22,
    0x97, 0xe2, 0x2f, 0xd5, 0x65, 0x06, 0x74, 0xbd, 0x70, 0xdf, 0xb1, 0x32, 0x34, 0xf9, 0x8a, 0xa8,
    0x21, 0xee, 0x03, 0x3c, 0x83, 0x12, 0xed, 0xa1, 0x78, 0x8f, 0x9e, 0xe9, 0x13, 0xc1, 0x5c, 0xa5,
    0xc0, 0xd8, 0x16, 0x64, 0x6f, 0x3f, 0xe9, 0x29, 0x8e, 0x84, 0x14, 0xd3, 0xc9, 0x53, 0xd0, 0x51,
    0x09, 0xa2, 0xbe, 0xde, 0x81, 0xf2, 0xda, 0x05, 0x11, 0x02, 0xd5, 0x00, 0x8c, 0xa4, 0x07, 0xc7,
    0x21, 0x2c, 0xe5, 0x06, 0x83, 0x8b, 0xbd, 0x8e, 0x53, 0x68, 0x67, 0x67, 0xcd, 0xa3, 0x19, 0x81,
    0x46, 0xee, 0xee, 0x97, 0x6a, 0x3f, 0xf7, 0xff, 0xdb, 0xc1, 0x7a, 0x4a, 0x0f, 0x99, 0x27, 0x77,
    0x03, 0xc5, 0x1a, 0xfd, 0x96, 0xdc, 0x1c, 0xfc, 0xac, 0x29, 0x3b, 0x84, 0x71, 0xd5, 0xfe, 0xf5,
    0xec, 0x96, 0xee, 0xdb, 0xd1, 0x76, 0x0c, 0x49, 0x93, 0xa4, 0xd0, 0x59, 0xbe, 0xe2, 0x24, 0x69,
    0xe0, 0x34, 0x13, 0x42, 0xe9, 0xff, 0x26, 0x9a, 0x00, 0x43, 0xbc, 0xdd, 0xea, 0xe8, 0x96, 0xdf,
    0x9b, 0xa6, 0xda, 0x74, 0x41, 0x6d, 0xfc, 0xd8, 0xe9, 0xfe, 0x28, 0x64, 0xa3, 0xdf, 0x7f, 0x34,
    0x7e, 0x95, 0xb2, 0xb0, 0x3e, 0x01, 0xbb, 0x42, 0x31, 0x53
};
#endif

PyTypeObject *init_KCalendarCore_CustomProperties(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_KCalendarCore_CustomProperties_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "CustomProperties",
        "KCalendarCore::CustomProperties*",
        &Sbk_KCalendarCore_CustomProperties_spec,
        &Shiboken::callCppDestructor< KCalendarCore::CustomProperties >,
        Sbk_KCalendarCore_CustomProperties_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_CustomProperties_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_CustomProperties_SignatureBytes, KCalendarCore_CustomProperties_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_CustomProperties_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        CustomProperties_PythonToCpp_CustomProperties_PTR,
        is_CustomProperties_PythonToCpp_CustomProperties_PTR_Convertible,
        CustomProperties_PTR_CppToPython_CustomProperties);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::CustomProperties");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::CustomProperties*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::CustomProperties&");
    Shiboken::Conversions::registerConverterAlias(converter, "CustomProperties");
    Shiboken::Conversions::registerConverterAlias(converter, "CustomProperties*");
    Shiboken::Conversions::registerConverterAlias(converter, "CustomProperties&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::CustomProperties).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(CustomPropertiesWrapper).name());

    qRegisterMetaType< ::KCalendarCore::CustomProperties *>();

    return pyType;
}
