
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_freebusy_wrapper.h"

// Wrappers providing overrides
#include "kcalendarcore_incidencebase_wrapper.h"
#include "kcalendarcore_customproperties_wrapper.h"

// Argument includes
#include <QList>
#include <QtCore/qlatin1stringview.h>
#include <duration.h>
#include <freebusy.h>
#include <freebusyperiod.h>
#include <incidencebase.h>
#include <period.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qtimezone.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_FreeBusy_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void FreeBusyWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

FreeBusyWrapper::FreeBusyWrapper()
{
}

FreeBusyWrapper::FreeBusyWrapper(const ::QDateTime & start, const ::QDateTime & end) : KCalendarCore::FreeBusy(start, end)
{
}

FreeBusyWrapper::FreeBusyWrapper(const ::QList<KCalendarCore::FreeBusyPeriod> & busyPeriods) : KCalendarCore::FreeBusy(busyPeriods)
{
}

FreeBusyWrapper::FreeBusyWrapper(const ::QList<KCalendarCore::Period> & busyPeriods) : KCalendarCore::FreeBusy(busyPeriods)
{
}

void FreeBusyWrapper::customPropertyUpdate()
{
    static const char *funcName = "customPropertyUpdate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::customPropertyUpdate();
    }
    CustomPropertiesWrapper::sbk_o_customPropertyUpdate("FreeBusy", funcName, gil, pyOverride);
}

void FreeBusyWrapper::customPropertyUpdated()
{
    static const char *funcName = "customPropertyUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::customPropertyUpdated();
    }
    CustomPropertiesWrapper::sbk_o_customPropertyUpdate("FreeBusy", funcName, gil, pyOverride);
}

::QDateTime FreeBusyWrapper::dateTime(::KCalendarCore::IncidenceBase::DateTimeRole role) const
{
    static const char *funcName = "dateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::FreeBusy::dateTime(role);
    }
    return IncidenceBaseWrapper::sbk_o_dateTime("FreeBusy", funcName, gil, pyOverride, role);
}

void FreeBusyWrapper::deserialize(::QDataStream & in)
{
    static const char *funcName = "deserialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::deserialize(in);
    }
    IncidenceBaseWrapper::sbk_o_deserialize("FreeBusy", funcName, gil, pyOverride, in);
}

::QDateTime FreeBusyWrapper::dtEnd() const
{
    static const char *funcName = "dtEnd";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::FreeBusy::dtEnd();
    }
    return IncidenceBaseWrapper::sbk_o_dtStart("FreeBusy", funcName, gil, pyOverride);
}

::QDateTime FreeBusyWrapper::dtStart() const
{
    // This method belongs to a property.
    static const char *funcName = "1:dtStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::dtStart();
    }
    return IncidenceBaseWrapper::sbk_o_dtStart("FreeBusy", funcName, gil, pyOverride);
}

bool FreeBusyWrapper::equals(const ::KCalendarCore::IncidenceBase & freebusy) const
{
    static const char *funcName = "equals";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::FreeBusy::equals(freebusy);
    }
    return IncidenceBaseWrapper::sbk_o_equals("FreeBusy", funcName, gil, pyOverride, freebusy);
}

::QLatin1String FreeBusyWrapper::mimeType() const
{
    static const char *funcName = "mimeType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::FreeBusy::mimeType();
    }
    return IncidenceBaseWrapper::sbk_o_mimeType("FreeBusy", funcName, gil, pyOverride);
}

::QDateTime FreeBusyWrapper::recurrenceId() const
{
    static const char *funcName = "recurrenceId";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::recurrenceId();
    }
    return IncidenceBaseWrapper::sbk_o_dtStart("FreeBusy", funcName, gil, pyOverride);
}

void FreeBusyWrapper::serialize(::QDataStream & out) const
{
    static const char *funcName = "serialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::serialize(out);
    }
    IncidenceBaseWrapper::sbk_o_deserialize("FreeBusy", funcName, gil, pyOverride, out);
}

void FreeBusyWrapper::setAllDay(bool allDay)
{
    // This method belongs to a property.
    static const char *funcName = "2:setAllDay";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::setAllDay(allDay);
    }
    IncidenceBaseWrapper::sbk_o_setAllDay("FreeBusy", funcName, gil, pyOverride, allDay);
}

void FreeBusyWrapper::setDateTime(const ::QDateTime & dateTime, ::KCalendarCore::IncidenceBase::DateTimeRole role)
{
    static const char *funcName = "setDateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::FreeBusy::setDateTime(dateTime, role);
    }
    IncidenceBaseWrapper::sbk_o_setDateTime("FreeBusy", funcName, gil, pyOverride, dateTime, role);
}

void FreeBusyWrapper::setDtStart(const ::QDateTime & start)
{
    static const char *funcName = "setDtStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::FreeBusy::setDtStart(start);
    }
    IncidenceBaseWrapper::sbk_o_setDtStart("FreeBusy", funcName, gil, pyOverride, start);
}

void FreeBusyWrapper::setDuration(const ::KCalendarCore::Duration & duration)
{
    static const char *funcName = "setDuration";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::setDuration(duration);
    }
    IncidenceBaseWrapper::sbk_o_setDuration("FreeBusy", funcName, gil, pyOverride, duration);
}

void FreeBusyWrapper::setLastModified(const ::QDateTime & lm)
{
    // This method belongs to a property.
    static const char *funcName = "2:setLastModified";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::setLastModified(lm);
    }
    IncidenceBaseWrapper::sbk_o_setDtStart("FreeBusy", funcName, gil, pyOverride, lm);
}

void FreeBusyWrapper::setReadOnly(bool readOnly)
{
    static const char *funcName = "setReadOnly";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::setReadOnly(readOnly);
    }
    IncidenceBaseWrapper::sbk_o_setAllDay("FreeBusy", funcName, gil, pyOverride, readOnly);
}

void FreeBusyWrapper::shiftTimes(const ::QTimeZone & oldZone, const ::QTimeZone & newZone)
{
    static const char *funcName = "shiftTimes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::FreeBusy::shiftTimes(oldZone, newZone);
    }
    IncidenceBaseWrapper::sbk_o_shiftTimes("FreeBusy", funcName, gil, pyOverride, oldZone, newZone);
}

::KCalendarCore::IncidenceBase::IncidenceType FreeBusyWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::FreeBusy::type();
    }
    return IncidenceBaseWrapper::sbk_o_type("FreeBusy", funcName, gil, pyOverride);
}

::QByteArray FreeBusyWrapper::typeStr() const
{
    static const char *funcName = "typeStr";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::FreeBusy::typeStr();
    }
    return IncidenceBaseWrapper::sbk_o_typeStr("FreeBusy", funcName, gil, pyOverride);
}

void FreeBusyWrapper::virtual_hook(::KCalendarCore::IncidenceBase::VirtualHook id, void * data)
{
    static const char *funcName = "virtual_hook";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_FreeBusy_TypeF(), gil, funcName, m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::FreeBusy::virtual_hook(id, data);
    }
    IncidenceBaseWrapper::sbk_o_virtual_hook("FreeBusy", funcName, gil, pyOverride, id, data);
}

FreeBusyWrapper::~FreeBusyWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_KCalendarCore_FreeBusy_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_FreeBusy_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KCalendarCore::FreeBusy >()))
        return -1;

    FreeBusyWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "FreeBusy", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: FreeBusy::FreeBusy()
    // 1: FreeBusy::FreeBusy(const KCalendarCore::FreeBusy&)
    // 2: FreeBusy::FreeBusy(const QDateTime&,const QDateTime&)
    // 3: FreeBusy::FreeBusy(const QList<KCalendarCore::FreeBusyPeriod>&)
    // 4: FreeBusy::FreeBusy(const QList<KCalendarCore::Period>&)
    if (numArgs == 0) {
        overloadId = 0; // FreeBusy()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_Period_IDX], (pyArgs[0])))) {
        overloadId = 4; // FreeBusy::FreeBusy(const QList<KCalendarCore::Period>&)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_FreeBusyPeriod_IDX], (pyArgs[0])))) {
        overloadId = 3; // FreeBusy::FreeBusy(const QList<KCalendarCore::FreeBusyPeriod>&)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[1])))) {
        overloadId = 2; // FreeBusy::FreeBusy(const QDateTime&,const QDateTime&)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), (pyArgs[0])))) {
        overloadId = 1; // FreeBusy::FreeBusy(const KCalendarCore::FreeBusy&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // FreeBusy()
        {

            // FreeBusy::FreeBusy()
            cptr = new FreeBusyWrapper();
            break;
        }
        case 1: // FreeBusy(const KCalendarCore::FreeBusy &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KCalendarCore::FreeBusy *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // FreeBusy::FreeBusy(const KCalendarCore::FreeBusy&)
                cptr = new FreeBusyWrapper(*cppArg0);
            }
            break;
        }
        case 2: // FreeBusy(const QDateTime &start, const QDateTime &end)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QDateTime cppArg1_local;
            ::QDateTime *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // FreeBusy::FreeBusy(const QDateTime&,const QDateTime&)
                cptr = new FreeBusyWrapper(*cppArg0, *cppArg1);
            }
            break;
        }
        case 3: // FreeBusy(const QList<KCalendarCore::FreeBusyPeriod> &busyPeriods)
        {
            ::QList<KCalendarCore::FreeBusyPeriod> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // FreeBusy::FreeBusy(const QList<KCalendarCore::FreeBusyPeriod>&)
                cptr = new FreeBusyWrapper(cppArg0);
            }
            break;
        }
        case 4: // FreeBusy(const QList<KCalendarCore::Period> &busyPeriods)
        {
            ::QList<KCalendarCore::Period> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // FreeBusy::FreeBusy(const QList<KCalendarCore::Period>&)
                cptr = new FreeBusyWrapper(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< KCalendarCore::FreeBusy >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_addPeriod(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addPeriod", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: FreeBusy::addPeriod(const QDateTime&,const KCalendarCore::Duration&)
    // 1: FreeBusy::addPeriod(const QDateTime&,const QDateTime&)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[1])))) {
            overloadId = 1; // FreeBusy::addPeriod(const QDateTime&,const QDateTime&)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Duration_IDX]), (pyArgs[1])))) {
            overloadId = 0; // FreeBusy::addPeriod(const QDateTime&,const KCalendarCore::Duration&)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addPeriod", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addPeriod(const QDateTime &start, const KCalendarCore::Duration &duration)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::KCalendarCore::Duration cppArg1_local;
            ::KCalendarCore::Duration *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // FreeBusy::addPeriod(const QDateTime&,const KCalendarCore::Duration&)
                cppSelf->addPeriod(*cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // addPeriod(const QDateTime &start, const QDateTime &end)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QDateTime cppArg1_local;
            ::QDateTime *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // FreeBusy::addPeriod(const QDateTime&,const QDateTime&)
                cppSelf->addPeriod(*cppArg0, *cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_addPeriods(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: FreeBusy::addPeriods(const QList<KCalendarCore::FreeBusyPeriod>&)
    // 1: FreeBusy::addPeriods(const QList<KCalendarCore::Period>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_Period_IDX], (pyArg)))) {
        overloadId = 1; // FreeBusy::addPeriods(const QList<KCalendarCore::Period>&)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_FreeBusyPeriod_IDX], (pyArg)))) {
        overloadId = 0; // FreeBusy::addPeriods(const QList<KCalendarCore::FreeBusyPeriod>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addPeriods", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addPeriods(const QList<KCalendarCore::FreeBusyPeriod> &list)
        {
            ::QList<KCalendarCore::FreeBusyPeriod> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // FreeBusy::addPeriods(const QList<KCalendarCore::FreeBusyPeriod>&)
                cppSelf->addPeriods(cppArg0);
            }
            break;
        }
        case 1: // addPeriods(const QList<KCalendarCore::Period> &list)
        {
            ::QList<KCalendarCore::Period> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // FreeBusy::addPeriods(const QList<KCalendarCore::Period>&)
                cppSelf->addPeriods(cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_busyPeriods(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // FreeBusy::busyPeriods()const->QList<KCalendarCore::Period>
        QList<KCalendarCore::Period> cppResult = const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->busyPeriods();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_Period_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_dateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), (pyArg)))) {
        overloadId = 0; // IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);

    // Call function/method
    {
        ::KCalendarCore::IncidenceBase::DateTimeRole cppArg0{KCalendarCore::IncidenceBase::RoleAlarmStartOffset};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
            QDateTime cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->::KCalendarCore::FreeBusy::dateTime(cppArg0)
                : const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->dateTime(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_dtEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // FreeBusy::dtEnd()const->QDateTime
        QDateTime cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->::KCalendarCore::FreeBusy::dtEnd()
            : const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->dtEnd();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_equals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "equals", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::IncidenceBase *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->::KCalendarCore::FreeBusy::equals(*cppArg0)
                : const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->equals(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_freeBusyMimeType([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static FreeBusy::freeBusyMimeType()->QLatin1String
        QLatin1String cppResult = ::KCalendarCore::FreeBusy::freeBusyMimeType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_fullBusyPeriods(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // FreeBusy::fullBusyPeriods()const->QList<KCalendarCore::FreeBusyPeriod>
        QList<KCalendarCore::FreeBusyPeriod> cppResult = const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->fullBusyPeriods();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_FreeBusyPeriod_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_mimeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::mimeType()const->QLatin1String
        QLatin1String cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->::KCalendarCore::FreeBusy::mimeType()
            : const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->mimeType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_setDateTime(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDateTime", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::KCalendarCore::IncidenceBase::DateTimeRole cppArg1{KCalendarCore::IncidenceBase::RoleAlarmStartOffset};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::FreeBusy::setDateTime(*cppArg0, cppArg1)
                : cppSelf->setDateTime(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_setDtEnd(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: FreeBusy::setDtEnd(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // FreeBusy::setDtEnd(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDtEnd", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // FreeBusy::setDtEnd(const QDateTime&)
            cppSelf->setDtEnd(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_setDtStart(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setDtStart(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setDtStart(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDtStart", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setDtStart(const QDateTime&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::FreeBusy::setDtStart(*cppArg0)
                : cppSelf->setDtStart(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_shiftTimes(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "shiftTimes", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "shiftTimes", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::FreeBusy::shiftTimes(*cppArg0, *cppArg1)
                : cppSelf->shiftTimes(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_sortList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // FreeBusy::sortList()
        cppSelf->sortList();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::type()const->KCalendarCore::IncidenceBase::IncidenceType
        KCalendarCore::IncidenceBase::IncidenceType cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->::KCalendarCore::FreeBusy::type()
            : const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceType_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_typeStr(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::typeStr()const->QByteArray
        QByteArray cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->::KCalendarCore::FreeBusy::typeStr()
            : const_cast<const ::KCalendarCore::FreeBusy *>(cppSelf)->typeStr();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_FreeBusyFunc_virtual_hook(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "virtual_hook", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_VirtualHook_IDX]))), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "virtual_hook", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]);

    // Call function/method
    {
        ::KCalendarCore::IncidenceBase::VirtualHook cppArg0 = static_cast< ::KCalendarCore::IncidenceBase::VirtualHook>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        void* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::FreeBusy::virtual_hook(cppArg0, cppArg1)
                : cppSelf->virtual_hook(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_KCalendarCore_FreeBusy_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_FreeBusy_methods[] = {
    {"addPeriod", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_addPeriod), METH_VARARGS, nullptr},
    {"addPeriods", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_addPeriods), METH_O, nullptr},
    {"busyPeriods", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_busyPeriods), METH_NOARGS, nullptr},
    {"dateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_dateTime), METH_O, nullptr},
    {"dtEnd", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_dtEnd), METH_NOARGS, nullptr},
    {"equals", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_equals), METH_O, nullptr},
    {"freeBusyMimeType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_freeBusyMimeType), METH_NOARGS|METH_STATIC, nullptr},
    {"fullBusyPeriods", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_fullBusyPeriods), METH_NOARGS, nullptr},
    {"mimeType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_mimeType), METH_NOARGS, nullptr},
    {"setDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_setDateTime), METH_VARARGS, nullptr},
    {"setDtEnd", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_setDtEnd), METH_O, nullptr},
    {"setDtStart", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_setDtStart), METH_O, nullptr},
    {"shiftTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_shiftTimes), METH_VARARGS, nullptr},
    {"sortList", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_sortList), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_type), METH_NOARGS, nullptr},
    {"typeStr", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_typeStr), METH_NOARGS, nullptr},
    {"virtual_hook", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_FreeBusyFunc_virtual_hook), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_KCalendarCore_FreeBusy_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::KCalendarCore::FreeBusy *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<FreeBusyWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_KCalendarCore_FreeBusy_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_FreeBusy_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_FreeBusy_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_KCalendarCore_FreeBusy_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_FreeBusy_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_FreeBusy_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_FreeBusy_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_FreeBusy_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_FreeBusy_spec = {
    "1:KCalendarCore.KCalendarCore.FreeBusy",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_FreeBusy_slots
};

} //extern "C"

static void *Sbk_KCalendarCore_FreeBusy_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::CustomProperties >())
        return dynamic_cast< ::KCalendarCore::FreeBusy *>(reinterpret_cast< ::KCalendarCore::CustomProperties *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void FreeBusy_PythonToCpp_FreeBusy_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_FreeBusy_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_FreeBusy_PythonToCpp_FreeBusy_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_FreeBusy_TypeF()))
        return FreeBusy_PythonToCpp_FreeBusy_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *FreeBusy_PTR_CppToPython_FreeBusy(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_FreeBusy_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::KCalendarCore::FreeBusy *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_KCalendarCore_FreeBusy_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_FreeBusy_SignatureStrings[] = {
    "4:KCalendarCore.KCalendarCore.FreeBusy(self)",
    "3:KCalendarCore.KCalendarCore.FreeBusy(self,other:KCalendarCore.KCalendarCore.FreeBusy)",
    "2:KCalendarCore.KCalendarCore.FreeBusy(self,start:PySide6.QtCore.QDateTime,end:PySide6.QtCore.QDateTime)",
    "1:KCalendarCore.KCalendarCore.FreeBusy(self,busyPeriods:QList[KCalendarCore.KCalendarCore.FreeBusyPeriod])",
    "0:KCalendarCore.KCalendarCore.FreeBusy(self,busyPeriods:QList[KCalendarCore.KCalendarCore.Period])",
    "1:KCalendarCore.KCalendarCore.FreeBusy.addPeriod(self,start:PySide6.QtCore.QDateTime,duration:typing.Union[KCalendarCore.KCalendarCore.Duration, int])",
    "0:KCalendarCore.KCalendarCore.FreeBusy.addPeriod(self,start:PySide6.QtCore.QDateTime,end:PySide6.QtCore.QDateTime)",
    "1:KCalendarCore.KCalendarCore.FreeBusy.addPeriods(self,list:QList[KCalendarCore.KCalendarCore.FreeBusyPeriod])",
    "0:KCalendarCore.KCalendarCore.FreeBusy.addPeriods(self,list:QList[KCalendarCore.KCalendarCore.Period])",
    "KCalendarCore.KCalendarCore.FreeBusy.busyPeriods(self)->QList[KCalendarCore.KCalendarCore.Period]",
    "KCalendarCore.KCalendarCore.FreeBusy.dateTime(self,role:KCalendarCore.KCalendarCore.IncidenceBase.DateTimeRole)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.FreeBusy.dtEnd(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.FreeBusy.equals(self,freebusy:KCalendarCore.KCalendarCore.IncidenceBase)->bool",
    "KCalendarCore.KCalendarCore.FreeBusy.freeBusyMimeType()->QLatin1String",
    "KCalendarCore.KCalendarCore.FreeBusy.fullBusyPeriods(self)->QList[KCalendarCore.KCalendarCore.FreeBusyPeriod]",
    "KCalendarCore.KCalendarCore.FreeBusy.mimeType(self)->QLatin1String",
    "KCalendarCore.KCalendarCore.FreeBusy.setDateTime(self,dateTime:PySide6.QtCore.QDateTime,role:KCalendarCore.KCalendarCore.IncidenceBase.DateTimeRole)",
    "KCalendarCore.KCalendarCore.FreeBusy.setDtEnd(self,end:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.FreeBusy.setDtStart(self,start:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.FreeBusy.shiftTimes(self,oldZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization],newZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "KCalendarCore.KCalendarCore.FreeBusy.sortList(self)",
    "KCalendarCore.KCalendarCore.FreeBusy.type(self)->KCalendarCore.KCalendarCore.IncidenceBase.IncidenceType",
    "KCalendarCore.KCalendarCore.FreeBusy.typeStr(self)->PySide6.QtCore.QByteArray",
    "KCalendarCore.KCalendarCore.FreeBusy.virtual_hook(self,id:KCalendarCore.KCalendarCore.IncidenceBase.VirtualHook,data:void)",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_FreeBusy_SignatureByteSize = 439;
static constexpr uint8_t KCalendarCore_FreeBusy_SignatureBytes[439] = {
    0x78, 0xda, 0xb5, 0x56, 0x4d, 0x4f, 0xc2, 0x40, 0x10, 0xbd, 0xf7, 0x57, 0x70, 0xa4, 0x49, 0x25,
    0xa2, 0xc6, 0x43, 0x0f, 0x26, 0x02, 0x1a, 0x8d, 0x9a, 0x80, 0xa0, 0x07, 0x0d, 0x31, 0x0b, 0x3b,
    0xc8, 0xc6, 0x65, 0x17, 0xb7, 0x03, 0xa6, 0xfe, 0x7a, 0xa7, 0xb4, 0x54, 0x20, 0x29, 0x4e, 0x41,
    0x6e, 0xbb, 0xdd, 0x79, 0xf3, 0xe6, 0xe3, 0xcd, 0xa4, 0x67, 0xe1, 0x5d, 0x53, 0x68, 0x30, 0x52,
    0xb8, 0xa6, 0x75, 0x50, 0x5b, 0xbf, 0x5d, 0x3b, 0x80, 0xc6, 0x2c, 0x8a, 0xab, 0x11, 0xe8, 0x91,
    0xef, 0x9d, 0xf2, 0x8d, 0x03, 0x8b, 0x63, 0x70, 0x2c, 0x7b, 0xdf, 0x3b, 0x29, 0xe1, 0x37, 0x42,
    0xe1, 0x30, 0x6c, 0xc7, 0x5d, 0x25, 0xe1, 0xbc, 0xd6, 0xc1, 0x85, 0x49, 0xa7, 0x25, 0x10, 0x7a,
    0x6a, 0x02, 0x01, 0xc1, 0x0a, 0x1f, 0x7d, 0xaf, 0x5e, 0x82, 0x68, 0x40, 0xa7, 0x36, 0x38, 0x65,
    0x65, 0x14, 0x76, 0xee, 0x55, 0x84, 0xaf, 0x1c, 0x6c, 0x8a, 0xe8, 0xfb, 0xde, 0xf1, 0xc1, 0xa8,
    0x72, 0x0a, 0x5e, 0x36, 0x35, 0x21, 0x65, 0x0a, 0x61, 0x15, 0x50, 0xce, 0x9c, 0x40, 0x65, 0x4d,
    0x88, 0xf1, 0x54, 0x99, 0xf7, 0xda, 0x93, 0xa1, 0xcb, 0xd6, 0x78, 0x5a, 0x19, 0x22, 0xa8, 0x28,
    0x83, 0xec, 0xcc, 0x4b, 0x86, 0xf5, 0x1f, 0x7d, 0xfd, 0xa5, 0x8c, 0x52, 0x4e, 0x4d, 0xa5, 0x3e,
    0x5c, 0x6f, 0x77, 0xa5, 0xcb, 0x69, 0x58, 0x24, 0x2b, 0xda, 0x49, 0xa7, 0xf4, 0xe8, 0x82, 0x4d,
    0xc1, 0x63, 0x90, 0x59, 0x99, 0xd3, 0x24, 0x9c, 0xd5, 0xb0, 0x35, 0xfd, 0x5b, 0x33, 0xa4, 0x2e,
    0x99, 0x21, 0x34, 0x44, 0x44, 0xe2, 0xc8, 0xc0, 0x8f, 0x04, 0xa3, 0xd0, 0x8a, 0x5a, 0xc8, 0x8c,
    0x04, 0xaf, 0x8c, 0x5c, 0x66, 0xb9, 0x9f, 0x2b, 0xf8, 0x9c, 0x09, 0x9d, 0xf5, 0x65, 0x44, 0x1f,
    0x93, 0x32, 0xf2, 0xd3, 0x22, 0xfa, 0x81, 0xb5, 0x9a, 0x47, 0x35, 0xca, 0x0e, 0x0f, 0x14, 0x5c,
    0x2f, 0x9e, 0x42, 0x75, 0xd1, 0x22, 0x1a, 0x19, 0x53, 0xef, 0xa2, 0xa3, 0x19, 0x63, 0xba, 0x99,
    0x69, 0xdd, 0xd8, 0xa5, 0xd9, 0x1b, 0xf2, 0xe5, 0xb1, 0x4d, 0x96, 0xc1, 0xe6, 0x34, 0xa5, 0x03,
    0x8e, 0x00, 0x5b, 0x6b, 0xd2, 0x59, 0x0a, 0xa9, 0x78, 0xca, 0xf7, 0x11, 0x17, 0x3f, 0xa8, 0x5c,
    0x45, 0x7f, 0x6c, 0x15, 0xbe, 0xc3, 0x6e, 0xb2, 0xbc, 0x38, 0x7b, 0x8c, 0xeb, 0x74, 0xac, 0x46,
    0x98, 0xd8, 0x67, 0x0a, 0xb5, 0x5a, 0xbe, 0x58, 0x03, 0xeb, 0x3b, 0x79, 0x93, 0x23, 0xb1, 0x4f,
    0xac, 0x82, 0x4a, 0xd1, 0x0b, 0x95, 0x4f, 0xa1, 0x12, 0x5a, 0x7d, 0x2f, 0x16, 0x76, 0x3f, 0x30,
    0xf0, 0x75, 0x08, 0xbf, 0xdc, 0x2c, 0xad, 0xc3, 0x44, 0xbd, 0xd9, 0xdf, 0x05, 0x0b, 0x83, 0x2b,
    0x9a, 0xe4, 0x0b, 0x25, 0xbf, 0x25, 0x92, 0xe6, 0x13, 0x91, 0xda, 0x8b, 0xb6, 0x4d, 0x23, 0x46,
    0xb8, 0x74, 0x4e, 0xc4, 0x3c, 0x6f, 0x73, 0xe5, 0x90, 0x16, 0xce, 0xdb, 0xd8, 0xda, 0x8f, 0xb4,
    0xa5, 0x4a, 0x96, 0x10, 0xfa, 0x73, 0x0a, 0xbf, 0x21, 0x74, 0x32, 0x45, 0x22, 0x9c, 0x5b, 0x25,
    0x7d, 0xef, 0x07, 0x50, 0x8e, 0x88, 0x5b
};
#endif

PyTypeObject *init_KCalendarCore_FreeBusy(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_FreeBusy_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]));
    Shiboken::AutoDecRef Sbk_KCalendarCore_FreeBusy_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "FreeBusy",
        "KCalendarCore::FreeBusy*",
        &Sbk_KCalendarCore_FreeBusy_spec,
        &Shiboken::callCppDestructor< KCalendarCore::FreeBusy >,
        Sbk_KCalendarCore_FreeBusy_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_FreeBusy_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_FreeBusy_SignatureBytes, KCalendarCore_FreeBusy_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_FreeBusy_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        FreeBusy_PythonToCpp_FreeBusy_PTR,
        is_FreeBusy_PythonToCpp_FreeBusy_PTR_Convertible,
        FreeBusy_PTR_CppToPython_FreeBusy);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::FreeBusy");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::FreeBusy*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::FreeBusy&");
    Shiboken::Conversions::registerConverterAlias(converter, "FreeBusy");
    Shiboken::Conversions::registerConverterAlias(converter, "FreeBusy*");
    Shiboken::Conversions::registerConverterAlias(converter, "FreeBusy&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::FreeBusy).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(FreeBusyWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_KCalendarCore_FreeBusy_typeDiscovery);

    qRegisterMetaType< ::KCalendarCore::FreeBusy *>();

    return pyType;
}
