#ifndef SBK_VCALFORMATWRAPPER_H
#define SBK_VCALFORMATWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <vcalformat.h>

#include <sbkpython.h>

#include <array>
namespace Shiboken { struct AutoDecRef; class GilState; }

class VCalFormatWrapper : public KCalendarCore::VCalFormat
{
public:
    VCalFormatWrapper();
    VCalFormatWrapper(const VCalFormatWrapper &) = delete;
    VCalFormatWrapper& operator=(const VCalFormatWrapper &) = delete;
    VCalFormatWrapper(VCalFormatWrapper &&) = delete;
    VCalFormatWrapper& operator=(VCalFormatWrapper &&) = delete;
    ~VCalFormatWrapper() override;

    static void pysideInitQtMetaTypes();

private:
};

#endif // SBK_VCALFORMATWRAPPER_H
