#ifndef SBK_VISITORWRAPPER_H
#define SBK_VISITORWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <visitor.h>

#include <sbkpython.h>

#include <array>
namespace Shiboken { struct AutoDecRef; class GilState; }

class VisitorWrapper : public KCalendarCore::Visitor
{
public:
    VisitorWrapper();
    VisitorWrapper(const VisitorWrapper &) = delete;
    VisitorWrapper& operator=(const VisitorWrapper &) = delete;
    VisitorWrapper(VisitorWrapper &&) = delete;
    VisitorWrapper& operator=(VisitorWrapper &&) = delete;
    ~VisitorWrapper() override;

    static void pysideInitQtMetaTypes();

private:
};

#endif // SBK_VISITORWRAPPER_H
