/****************************************************************************
** Meta object code from reading C++ file 'incidence.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kcalendarcore-6.26.0/src/incidence.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'incidence.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KCalendarCore9IncidenceE_t {};
} // unnamed namespace

template <> constexpr inline auto KCalendarCore::Incidence::qt_create_metaobjectdata<qt_meta_tag_ZN13KCalendarCore9IncidenceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCalendarCore::Incidence",
        "description",
        "summary",
        "location",
        "hasGeo",
        "geoLatitude",
        "geoLongitude",
        "categories",
        "priority",
        "created",
        "secrecy",
        "KCalendarCore::Incidence::Secrecy",
        "status",
        "KCalendarCore::Incidence::Status",
        "attachments",
        "QList<KCalendarCore::Attachment>",
        "conferences",
        "QList<KCalendarCore::Conference>",
        "Status",
        "StatusNone",
        "StatusTentative",
        "StatusConfirmed",
        "StatusCompleted",
        "StatusNeedsAction",
        "StatusCanceled",
        "StatusInProcess",
        "StatusDraft",
        "StatusFinal",
        "StatusX",
        "Secrecy",
        "SecrecyPublic",
        "SecrecyPrivate",
        "SecrecyConfidential"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'description'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'summary'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'location'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hasGeo'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'geoLatitude'
        QtMocHelpers::PropertyData<float>(5, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'geoLongitude'
        QtMocHelpers::PropertyData<float>(6, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'categories'
        QtMocHelpers::PropertyData<QStringList>(7, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'priority'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'created'
        QtMocHelpers::PropertyData<QDateTime>(9, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'secrecy'
        QtMocHelpers::PropertyData<KCalendarCore::Incidence::Secrecy>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'status'
        QtMocHelpers::PropertyData<KCalendarCore::Incidence::Status>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'attachments'
        QtMocHelpers::PropertyData<QList<KCalendarCore::Attachment>>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'conferences'
        QtMocHelpers::PropertyData<QList<KCalendarCore::Conference>>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(18, 18, QMC::EnumFlags{}).add({
            {   19, Status::StatusNone },
            {   20, Status::StatusTentative },
            {   21, Status::StatusConfirmed },
            {   22, Status::StatusCompleted },
            {   23, Status::StatusNeedsAction },
            {   24, Status::StatusCanceled },
            {   25, Status::StatusInProcess },
            {   26, Status::StatusDraft },
            {   27, Status::StatusFinal },
            {   28, Status::StatusX },
        }),
        // enum 'Secrecy'
        QtMocHelpers::EnumData<enum Secrecy>(29, 29, QMC::EnumFlags{}).add({
            {   30, Secrecy::SecrecyPublic },
            {   31, Secrecy::SecrecyPrivate },
            {   32, Secrecy::SecrecyConfidential },
        }),
    };
    return QtMocHelpers::metaObjectData<Incidence, qt_meta_tag_ZN13KCalendarCore9IncidenceE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCalendarCore::Incidence::staticMetaObject = { {
    QtPrivate::MetaObjectForType<IncidenceBase>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore9IncidenceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore9IncidenceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KCalendarCore9IncidenceE_t>.metaTypes,
    nullptr
} };

void KCalendarCore::Incidence::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Incidence *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KCalendarCore::Attachment> >(); break;
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KCalendarCore::Conference> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->summary(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->location(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasGeo(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->geoLatitude(); break;
        case 5: *reinterpret_cast<float*>(_v) = _t->geoLongitude(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->categories(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->priority(); break;
        case 8: *reinterpret_cast<QDateTime*>(_v) = _t->created(); break;
        case 9: *reinterpret_cast<KCalendarCore::Incidence::Secrecy*>(_v) = _t->secrecy(); break;
        case 10: *reinterpret_cast<KCalendarCore::Incidence::Status*>(_v) = _t->status(); break;
        case 11: *reinterpret_cast<QList<KCalendarCore::Attachment>*>(_v) = _t->attachments(); break;
        case 12: *reinterpret_cast<QList<KCalendarCore::Conference>*>(_v) = _t->conferences(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDescription(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setSummary(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setLocation(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setGeoLatitude(*reinterpret_cast<float*>(_v)); break;
        case 5: _t->setGeoLongitude(*reinterpret_cast<float*>(_v)); break;
        case 6: _t->setCategories(*reinterpret_cast<QStringList*>(_v)); break;
        case 7: _t->setPriority(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setCreated(*reinterpret_cast<QDateTime*>(_v)); break;
        case 9: _t->setSecrecy(*reinterpret_cast<KCalendarCore::Incidence::Secrecy*>(_v)); break;
        case 10: _t->setStatus(*reinterpret_cast<KCalendarCore::Incidence::Status*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
