
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_wrapper.h"

// inner classes
#include "kcalendarcore_visitor_wrapper.h"
#include "kcalendarcore_incidences_wrapper.h"
#include "kcalendarcore_journals_wrapper.h"
#include "kcalendarcore_todos_wrapper.h"
#include "kcalendarcore_events_wrapper.h"
#include "kcalendarcore_occurrenceiterator_wrapper.h"
#include "kcalendarcore_schedulemessage_wrapper.h"
#include "kcalendarcore_freebusycache_wrapper.h"
#include "kcalendarcore_exception_wrapper.h"
#include "kcalendarcore_calendarpluginloader_wrapper.h"
#include "kcalendarcore_calendarplugin_wrapper.h"
#include "kcalendarcore_calendarlistmodel_wrapper.h"
#include "kcalendarcore_calstorage_wrapper.h"
#include "kcalendarcore_filestorage_wrapper.h"
#include "kcalendarcore_calformat_wrapper.h"
#include "kcalendarcore_vcalformat_wrapper.h"
#include "kcalendarcore_icalformat_wrapper.h"
#include "kcalendarcore_calfilter_wrapper.h"
#include "kcalendarcore_recurrence_wrapper.h"
#include "kcalendarcore_recurrencerule_wrapper.h"
#include "kcalendarcore_period_wrapper.h"
#include "kcalendarcore_freebusyperiod_wrapper.h"
#include "kcalendarcore_conference_wrapper.h"
#include "kcalendarcore_attendee_wrapper.h"
#include "kcalendarcore_attachment_wrapper.h"
#include "kcalendarcore_person_wrapper.h"
#include "kcalendarcore_duration_wrapper.h"
#include "kcalendarcore_customproperties_wrapper.h"
#include "kcalendarcore_calendar_wrapper.h"
#include "kcalendarcore_memorycalendar_wrapper.h"
#include "kcalendarcore_incidencebase_wrapper.h"
#include "kcalendarcore_freebusy_wrapper.h"
#include "kcalendarcore_incidence_wrapper.h"
#include "kcalendarcore_todo_wrapper.h"
#include "kcalendarcore_journal_wrapper.h"
#include "kcalendarcore_event_wrapper.h"
#include "kcalendarcore_alarm_wrapper.h"

// Argument includes
#include <duration.h>
#include <period.h>
#include <person.h>
#include <qdatetime.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int Sbk_KCalendarCore_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNamespace("KCalendarCore");
    return -1;
}

static PyObject *Sbk_KCalendarCoreFunc_identical([[maybe_unused]] PyObject *self, PyObject *args)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "identical", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static KCalendarCore::identical(const QDateTime&,const QDateTime&)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[1])))) {
        overloadId = 0; // static KCalendarCore::identical(const QDateTime&,const QDateTime&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "identical", SbkKCalendarCoreTypeStructs[SBK_KCalendarCoreKCalendarCore_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDateTime cppArg1_local;
        ::QDateTime *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static KCalendarCore::identical(const QDateTime&,const QDateTime&)->bool
            bool cppResult = ::KCalendarCore::identical(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCoreFunc_qHash([[maybe_unused]] PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "qHash", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCoreKCalendarCore_IDX]);

    if (PyArg_ParseTuple(args, "|OO:qHash", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static KCalendarCore::qHash(const KCalendarCore::Duration&,size_t=)->size_t
    // 1: static KCalendarCore::qHash(const KCalendarCore::Period&,size_t=)->size_t
    // 2: static KCalendarCore::qHash(const KCalendarCore::Person&,size_t=)->size_t
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // qHash(KCalendarCore::Person,size_t)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyArgs[1])))) {
            overloadId = 2; // static KCalendarCore::qHash(const KCalendarCore::Person&,size_t=)->size_t
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Period_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // qHash(KCalendarCore::Period,size_t)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyArgs[1])))) {
            overloadId = 1; // static KCalendarCore::qHash(const KCalendarCore::Period&,size_t=)->size_t
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Duration_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qHash(KCalendarCore::Duration,size_t)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyArgs[1])))) {
            overloadId = 0; // static KCalendarCore::qHash(const KCalendarCore::Duration&,size_t=)->size_t
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qHash", SbkKCalendarCoreTypeStructs[SBK_KCalendarCoreKCalendarCore_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // qHash(const KCalendarCore::Duration &duration, size_t seed)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"seed", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyArgs[1])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "qHash", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCoreKCalendarCore_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::KCalendarCore::Duration cppArg0_local;
            ::KCalendarCore::Duration *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            size_t cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // static KCalendarCore::qHash(const KCalendarCore::Duration&,size_t=)->size_t
                size_t cppResult = ::KCalendarCore::qHash(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), &cppResult);
            }
            break;
        }
        case 1: // qHash(const KCalendarCore::Period &key, size_t seed)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"seed", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyArgs[1])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "qHash", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCoreKCalendarCore_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::KCalendarCore::Period cppArg0_local;
            ::KCalendarCore::Period *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            size_t cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // static KCalendarCore::qHash(const KCalendarCore::Period&,size_t=)->size_t
                size_t cppResult = ::KCalendarCore::qHash(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), &cppResult);
            }
            break;
        }
        case 2: // qHash(const KCalendarCore::Person &key, size_t seed)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"seed", 1}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyArgs[1])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "qHash", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCoreKCalendarCore_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::KCalendarCore::Person *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            size_t cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // static KCalendarCore::qHash(const KCalendarCore::Person&,size_t=)->size_t
                size_t cppResult = ::KCalendarCore::qHash(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_KCalendarCore_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_KCalendarCore_EnumFlagInfo[] = {
    "AccessMode:IntEnum",
    "EventSortField:IntEnum",
    "JournalSortField:IntEnum",
    "SortDirection:IntEnum",
    "TodoSortField:IntEnum",
    "iTIPMethod:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_methods[] = {
    {"identical", reinterpret_cast<PyCFunction>(Sbk_KCalendarCoreFunc_identical), METH_VARARGS|METH_STATIC, nullptr},
    {"qHash", reinterpret_cast<PyCFunction>(Sbk_KCalendarCoreFunc_qHash), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_KCalendarCore_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(Sbk_object_dealloc /* PYSIDE-832: Prevent replacement of "0" with subtype_dealloc. */)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkDummyNew /* PYSIDE-595: Prevent replacement of "0" with base->tp_new. */)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_spec = {
    "1:KCalendarCore.KCalendarCore",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_KCalendarCore_SortDirection(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::SortDirection>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::SortDirection *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_SortDirection_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_SortDirection_IDX])))
        return Enum_PythonToCpp_KCalendarCore_SortDirection;
    return {};
}

static PyObject *KCalendarCore_SortDirection_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::SortDirection>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::SortDirection *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_EventSortField(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::EventSortField>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::EventSortField *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_EventSortField_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_EventSortField_IDX])))
        return Enum_PythonToCpp_KCalendarCore_EventSortField;
    return {};
}

static PyObject *KCalendarCore_EventSortField_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::EventSortField>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::EventSortField *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_TodoSortField(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::TodoSortField>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::TodoSortField *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_TodoSortField_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_TodoSortField_IDX])))
        return Enum_PythonToCpp_KCalendarCore_TodoSortField;
    return {};
}

static PyObject *KCalendarCore_TodoSortField_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::TodoSortField>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::TodoSortField *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_JournalSortField(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::JournalSortField>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::JournalSortField *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_JournalSortField_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_JournalSortField_IDX])))
        return Enum_PythonToCpp_KCalendarCore_JournalSortField;
    return {};
}

static PyObject *KCalendarCore_JournalSortField_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::JournalSortField>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::JournalSortField *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_AccessMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::AccessMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::AccessMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_AccessMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_AccessMode_IDX])))
        return Enum_PythonToCpp_KCalendarCore_AccessMode;
    return {};
}

static PyObject *KCalendarCore_AccessMode_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::AccessMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::AccessMode *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_iTIPMethod(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::iTIPMethod>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::iTIPMethod *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_iTIPMethod_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_iTIPMethod_IDX])))
        return Enum_PythonToCpp_KCalendarCore_iTIPMethod;
    return {};
}

static PyObject *KCalendarCore_iTIPMethod_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::iTIPMethod>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::iTIPMethod *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCoreKCalendarCore_SignatureStrings[] = {
    "KCalendarCore.KCalendarCore.identical(dt1:PySide6.QtCore.QDateTime,dt2:PySide6.QtCore.QDateTime)->bool",
    "2:KCalendarCore.KCalendarCore.qHash(duration:typing.Union[KCalendarCore.KCalendarCore.Duration, int],seed:size_t=0)->size_t",
    "1:KCalendarCore.KCalendarCore.qHash(key:KCalendarCore.KCalendarCore.Period,seed:size_t=0)->size_t",
    "0:KCalendarCore.KCalendarCore.qHash(key:KCalendarCore.KCalendarCore.Person,seed:size_t=0)->size_t",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCoreKCalendarCore_SignatureByteSize = 161;
static constexpr uint8_t KCalendarCoreKCalendarCore_SignatureBytes[161] = {
    0x78, 0xda, 0xf3, 0x76, 0x4e, 0xcc, 0x49, 0xcd, 0x4b, 0x49, 0x2c, 0x72, 0xce, 0x2f, 0x4a, 0xd5,
    0xf3, 0x46, 0xe1, 0x65, 0xa6, 0xa4, 0xe6, 0x95, 0x64, 0x26, 0x27, 0xe6, 0x68, 0xa4, 0x94, 0x18,
    0x5a, 0x05, 0x54, 0x06, 0x03, 0x05, 0xcc, 0xf4, 0x02, 0x4b, 0xc0, 0x92, 0x81, 0x2e, 0x89, 0x25,
    0xa9, 0x21, 0x99, 0xb9, 0xa9, 0x3a, 0x29, 0x25, 0x46, 0x38, 0x25, 0x35, 0x75, 0xed, 0x92, 0xf2,
    0xf3, 0x73, 0xb8, 0x8c, 0xac, 0xbc, 0xf1, 0x58, 0x54, 0xe8, 0x91, 0x58, 0x9c, 0xa1, 0x91, 0x52,
    0x5a, 0x94, 0x58, 0x92, 0x99, 0x9f, 0x67, 0x55, 0x52, 0x59, 0x90, 0x99, 0x97, 0xae, 0x17, 0x9a,
    0x07, 0xe4, 0x44, 0xe3, 0xd3, 0xe7, 0x02, 0xd5, 0xa1, 0xa3, 0x90, 0x99, 0x57, 0x12, 0xab, 0x53,
    0x9c, 0x9a, 0x9a, 0x62, 0x55, 0x9c, 0x59, 0x95, 0x1a, 0x5f, 0x62, 0x6b, 0x00, 0xb4, 0x19, 0xc2,
    0xe4, 0x32, 0x24, 0xc2, 0xee, 0xec, 0xd4, 0x4a, 0xbc, 0xaa, 0x02, 0x52, 0x8b, 0x32, 0xf3, 0x53,
    0x70, 0xd9, 0x60, 0x40, 0x1d, 0x1b, 0x8a, 0x81, 0x3e, 0xc1, 0x61, 0x03, 0x00, 0x6b, 0xed, 0x97,
    0x7c
};
#endif

PyTypeObject *init_KCalendarCoreKCalendarCore(PyObject *module)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCoreKCalendarCore_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_KCalendarCore_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        module,
        "KCalendarCore",
        "KCalendarCore",
        &Sbk_KCalendarCore_spec,
        nullptr,
        Sbk_KCalendarCore_Type_bases.object(),
        0);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCoreKCalendarCore_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCoreKCalendarCore_SignatureBytes, KCalendarCoreKCalendarCore_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_PropertyStrings);
    typeStruct.type = pyType;


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_KCalendarCore_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'SortDirection'.
    const char *SortDirection_Initializer[] = {
        "SortDirectionAscending",
        "SortDirectionDescending",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SortDirection_InitializerValues[] = {
        uint8_t(KCalendarCore::SortDirection::SortDirectionAscending), //  0x00  0
        uint8_t(KCalendarCore::SortDirection::SortDirectionDescending) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.SortDirection",
        SortDirection_Initializer, SortDirection_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_SortDirection_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::SortDirection'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_SortDirection_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_SortDirection,
            is_Enum_PythonToCpp_KCalendarCore_SortDirection_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::SortDirection");
        Shiboken::Conversions::registerConverterAlias(converter, "SortDirection");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SortDirection' enum.

    // Initialization of enum 'EventSortField'.
    const char *EventSortField_Initializer[] = {
        "EventSortUnsorted",
        "EventSortStartDate",
        "EventSortEndDate",
        "EventSortSummary",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t EventSortField_InitializerValues[] = {
        uint8_t(KCalendarCore::EventSortField::EventSortUnsorted),  //  0x00  0
        uint8_t(KCalendarCore::EventSortField::EventSortStartDate), //  0x01  1
        uint8_t(KCalendarCore::EventSortField::EventSortEndDate),   //  0x02  2
        uint8_t(KCalendarCore::EventSortField::EventSortSummary)    //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.EventSortField",
        EventSortField_Initializer, EventSortField_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_EventSortField_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::EventSortField'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_EventSortField_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_EventSortField,
            is_Enum_PythonToCpp_KCalendarCore_EventSortField_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::EventSortField");
        Shiboken::Conversions::registerConverterAlias(converter, "EventSortField");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'EventSortField' enum.

    // Initialization of enum 'TodoSortField'.
    const char *TodoSortField_Initializer[] = {
        "TodoSortUnsorted",
        "TodoSortStartDate",
        "TodoSortDueDate",
        "TodoSortPriority",
        "TodoSortPercentComplete",
        "TodoSortSummary",
        "TodoSortCreated",
        "TodoSortCategories",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TodoSortField_InitializerValues[] = {
        uint8_t(KCalendarCore::TodoSortField::TodoSortUnsorted),        //  0x00  0
        uint8_t(KCalendarCore::TodoSortField::TodoSortStartDate),       //  0x01  1
        uint8_t(KCalendarCore::TodoSortField::TodoSortDueDate),         //  0x02  2
        uint8_t(KCalendarCore::TodoSortField::TodoSortPriority),        //  0x03  3
        uint8_t(KCalendarCore::TodoSortField::TodoSortPercentComplete), //  0x04  4
        uint8_t(KCalendarCore::TodoSortField::TodoSortSummary),         //  0x05  5
        uint8_t(KCalendarCore::TodoSortField::TodoSortCreated),         //  0x06  6
        uint8_t(KCalendarCore::TodoSortField::TodoSortCategories)       //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.TodoSortField",
        TodoSortField_Initializer, TodoSortField_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_TodoSortField_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::TodoSortField'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_TodoSortField_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_TodoSortField,
            is_Enum_PythonToCpp_KCalendarCore_TodoSortField_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::TodoSortField");
        Shiboken::Conversions::registerConverterAlias(converter, "TodoSortField");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TodoSortField' enum.

    // Initialization of enum 'JournalSortField'.
    const char *JournalSortField_Initializer[] = {
        "JournalSortUnsorted",
        "JournalSortDate",
        "JournalSortSummary",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t JournalSortField_InitializerValues[] = {
        uint8_t(KCalendarCore::JournalSortField::JournalSortUnsorted), //  0x00  0
        uint8_t(KCalendarCore::JournalSortField::JournalSortDate),     //  0x01  1
        uint8_t(KCalendarCore::JournalSortField::JournalSortSummary)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.JournalSortField",
        JournalSortField_Initializer, JournalSortField_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_JournalSortField_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::JournalSortField'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_JournalSortField_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_JournalSortField,
            is_Enum_PythonToCpp_KCalendarCore_JournalSortField_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::JournalSortField");
        Shiboken::Conversions::registerConverterAlias(converter, "JournalSortField");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'JournalSortField' enum.

    // Initialization of enum 'AccessMode'.
    const char *AccessMode_Initializer[] = {
        "ReadOnly",
        "ReadWrite",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AccessMode_InitializerValues[] = {
        uint8_t(KCalendarCore::AccessMode::ReadOnly), //  0x00  0
        uint8_t(KCalendarCore::AccessMode::ReadWrite) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.AccessMode",
        AccessMode_Initializer, AccessMode_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_AccessMode_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::AccessMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_AccessMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_AccessMode,
            is_Enum_PythonToCpp_KCalendarCore_AccessMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::AccessMode");
        Shiboken::Conversions::registerConverterAlias(converter, "AccessMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AccessMode' enum.

    // Initialization of enum 'iTIPMethod'.
    const char *iTIPMethod_Initializer[] = {
        "iTIPPublish",
        "iTIPRequest",
        "iTIPReply",
        "iTIPAdd",
        "iTIPCancel",
        "iTIPRefresh",
        "iTIPCounter",
        "iTIPDeclineCounter",
        "iTIPNoMethod",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t iTIPMethod_InitializerValues[] = {
        uint8_t(KCalendarCore::iTIPMethod::iTIPPublish),        //  0x00  0
        uint8_t(KCalendarCore::iTIPMethod::iTIPRequest),        //  0x01  1
        uint8_t(KCalendarCore::iTIPMethod::iTIPReply),          //  0x02  2
        uint8_t(KCalendarCore::iTIPMethod::iTIPAdd),            //  0x03  3
        uint8_t(KCalendarCore::iTIPMethod::iTIPCancel),         //  0x04  4
        uint8_t(KCalendarCore::iTIPMethod::iTIPRefresh),        //  0x05  5
        uint8_t(KCalendarCore::iTIPMethod::iTIPCounter),        //  0x06  6
        uint8_t(KCalendarCore::iTIPMethod::iTIPDeclineCounter), //  0x07  7
        uint8_t(KCalendarCore::iTIPMethod::iTIPNoMethod)        //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.iTIPMethod",
        iTIPMethod_Initializer, iTIPMethod_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_iTIPMethod_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::iTIPMethod'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_iTIPMethod_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_iTIPMethod,
            is_Enum_PythonToCpp_KCalendarCore_iTIPMethod_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::iTIPMethod");
        Shiboken::Conversions::registerConverterAlias(converter, "iTIPMethod");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'iTIPMethod' enum.

    qRegisterMetaType< ::KCalendarCore::SortDirection >("KCalendarCore::SortDirection");
    qRegisterMetaType< ::KCalendarCore::EventSortField >("KCalendarCore::EventSortField");
    qRegisterMetaType< ::KCalendarCore::TodoSortField >("KCalendarCore::TodoSortField");
    qRegisterMetaType< ::KCalendarCore::JournalSortField >("KCalendarCore::JournalSortField");
    qRegisterMetaType< ::KCalendarCore::AccessMode >("KCalendarCore::AccessMode");
    qRegisterMetaType< ::KCalendarCore::iTIPMethod >("KCalendarCore::iTIPMethod");

    return pyType;
}
