/****************************************************************************
** Meta object code from reading C++ file 'calendar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kcalendarcore-6.26.0/src/calendar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KCalendarCore8CalendarE_t {};
} // unnamed namespace

template <> constexpr inline auto KCalendarCore::Calendar::qt_create_metaobjectdata<qt_meta_tag_ZN13KCalendarCore8CalendarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCalendarCore::Calendar",
        "filterChanged",
        "",
        "idChanged",
        "nameChanged",
        "iconChanged",
        "colorChanged",
        "accessModeChanged",
        "ownerChanged",
        "isLoadingChanged",
        "productId",
        "owner",
        "KCalendarCore::Person",
        "id",
        "name",
        "icon",
        "QIcon",
        "color",
        "accessMode",
        "KCalendarCore::AccessMode",
        "isLoading"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accessModeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ownerChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isLoadingChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'productId'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'owner'
        QtMocHelpers::PropertyData<KCalendarCore::Person>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'id'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'icon'
        QtMocHelpers::PropertyData<QIcon>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'color'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'accessMode'
        QtMocHelpers::PropertyData<KCalendarCore::AccessMode>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'isLoading'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Calendar, qt_meta_tag_ZN13KCalendarCore8CalendarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN13KCalendarCore8CalendarE[] = {
    QMetaObject::SuperData::link<KCalendarCore::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KCalendarCore::Calendar::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore8CalendarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore8CalendarE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN13KCalendarCore8CalendarE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KCalendarCore8CalendarE_t>.metaTypes,
    nullptr
} };

void KCalendarCore::Calendar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Calendar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterChanged(); break;
        case 1: _t->idChanged(); break;
        case 2: _t->nameChanged(); break;
        case 3: _t->iconChanged(); break;
        case 4: _t->colorChanged(); break;
        case 5: _t->accessModeChanged(); break;
        case 6: _t->ownerChanged(); break;
        case 7: _t->isLoadingChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::filterChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::idChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::nameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::iconChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::colorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::accessModeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::ownerChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)()>(_a, &Calendar::isLoadingChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KCalendarCore::Person >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->productId(); break;
        case 1: *reinterpret_cast<KCalendarCore::Person*>(_v) = _t->owner(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 4: *reinterpret_cast<QIcon*>(_v) = _t->icon(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->color(); break;
        case 6: *reinterpret_cast<KCalendarCore::AccessMode*>(_v) = _t->accessMode(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isLoading(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setProductId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setOwner(*reinterpret_cast<KCalendarCore::Person*>(_v)); break;
        case 2: _t->setId(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setIcon(*reinterpret_cast<QIcon*>(_v)); break;
        case 5: _t->setColor(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setAccessMode(*reinterpret_cast<KCalendarCore::AccessMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KCalendarCore::Calendar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCalendarCore::Calendar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KCalendarCore8CalendarE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "CustomProperties"))
        return static_cast< CustomProperties*>(this);
    if (!strcmp(_clname, "IncidenceBase::IncidenceObserver"))
        return static_cast< IncidenceBase::IncidenceObserver*>(this);
    return QObject::qt_metacast(_clname);
}

int KCalendarCore::Calendar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KCalendarCore::Calendar::filterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KCalendarCore::Calendar::idChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KCalendarCore::Calendar::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KCalendarCore::Calendar::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KCalendarCore::Calendar::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KCalendarCore::Calendar::accessModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KCalendarCore::Calendar::ownerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KCalendarCore::Calendar::isLoadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
namespace {
struct qt_meta_tag_ZN13KCalendarCoreE_t {};
} // unnamed namespace

template <> constexpr inline auto KCalendarCore::qt_create_metaobjectdata<qt_meta_tag_ZN13KCalendarCoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCalendarCore",
        "AccessMode",
        "ReadOnly",
        "ReadWrite"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AccessMode'
        QtMocHelpers::EnumData<AccessMode>(1, 1, QMC::EnumFlags{}).add({
            {    2, AccessMode::ReadOnly },
            {    3, AccessMode::ReadWrite },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN13KCalendarCoreE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN13KCalendarCoreE =
    KCalendarCore::qt_create_metaobjectdata<qt_meta_tag_ZN13KCalendarCoreE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN13KCalendarCoreE =
    qt_staticMetaObjectContent_ZN13KCalendarCoreE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN13KCalendarCoreE =
    qt_staticMetaObjectContent_ZN13KCalendarCoreE.relocatingData;

Q_CONSTINIT const QMetaObject KCalendarCore::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN13KCalendarCoreE.stringdata,
    qt_staticMetaObjectStaticContent_ZN13KCalendarCoreE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN13KCalendarCoreE.metaTypes,
    nullptr
} };

QT_WARNING_POP
