/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_calendarcore()
{
    qmlRegisterModule("org.kde.calendarcore", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<CalendarListModelForeign>("org.kde.calendarcore", 254);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KCalendarCore::staticMetaObject;},
            "KCalendarCore");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KCalendarCore::staticMetaObject, "org.kde.calendarcore", 254, nullptr, &KCalendarCoreForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<KCalendarCore::AccessMode>("KCalendarCore::AccessMode");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.calendarcore", 254, 254);
}

static const QQmlModuleRegistration orgkdecalendarcoreRegistration("org.kde.calendarcore", qml_register_types_org_kde_calendarcore);
