
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_attendee_wrapper.h"

// Argument includes
#include <QString>
#include <attendee.h>
#include <customproperties.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_Attendee_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX].type;
}
} // extern "C"


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_KCalendarCore_Attendee_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::KCalendarCore::Attendee >()))
        return -1;

    ::KCalendarCore::Attendee *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:Attendee", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Attendee::Attendee()
    // 1: Attendee::Attendee(const KCalendarCore::Attendee&)
    // 2: Attendee::Attendee(const QString&,const QString&,bool=,KCalendarCore::Attendee::PartStat=,KCalendarCore::Attendee::Role=,const QString&=)
    if (numArgs == 0) {
        overloadId = 0; // Attendee()
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // Attendee(QString,QString,bool,KCalendarCore::Attendee::PartStat,KCalendarCore::Attendee::Role,QString)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // Attendee(QString,QString,bool,KCalendarCore::Attendee::PartStat,KCalendarCore::Attendee::Role,QString)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_PartStat_IDX]))), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 2; // Attendee(QString,QString,bool,KCalendarCore::Attendee::PartStat,KCalendarCore::Attendee::Role,QString)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_Role_IDX]))), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 2; // Attendee(QString,QString,bool,KCalendarCore::Attendee::PartStat,KCalendarCore::Attendee::Role,QString)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5])))) {
                        overloadId = 2; // Attendee::Attendee(const QString&,const QString&,bool=,KCalendarCore::Attendee::PartStat=,KCalendarCore::Attendee::Role=,const QString&=)
                    }
                }
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Attendee::Attendee(const KCalendarCore::Attendee&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    // Resolve keyword arguments
    switch (overloadId) {
        case 0: // Attendee::Attendee()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);
            }
            break;
        }
        case 1: // Attendee::Attendee(const KCalendarCore::Attendee&)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);
            }
            break;
        }
        case 2: // Attendee::Attendee(const QString&,const QString&,bool=,KCalendarCore::Attendee::PartStat=,KCalendarCore::Attendee::Role=,const QString&=)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[4] = {{"rsvp", 2}, {"status", 3}, {"role", 4}, {"uid", 5}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 4, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))))
                    || (pyArgs[3] != nullptr && !((pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_PartStat_IDX]))), (pyArgs[3])))))
                    || (pyArgs[4] != nullptr && !((pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_Role_IDX]))), (pyArgs[4])))))
                    || (pyArgs[5] != nullptr && !((pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);
                }
            }
            break;
        }
    }

    // PyMI support
    Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Attendee()
        {

            // Attendee::Attendee()
            cptr = new ::KCalendarCore::Attendee();
            break;
        }
        case 1: // Attendee(const KCalendarCore::Attendee &attendee)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::KCalendarCore::Attendee cppArg0_local;
            ::KCalendarCore::Attendee *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Attendee::Attendee(const KCalendarCore::Attendee&)
                cptr = new ::KCalendarCore::Attendee(*cppArg0);
            }
            break;
        }
        case 2: // Attendee(const QString &name, const QString &email, bool rsvp, KCalendarCore::Attendee::PartStat status, KCalendarCore::Attendee::Role role, const QString &uid)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            bool cppArg2 = false;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::KCalendarCore::Attendee::PartStat cppArg3(KCalendarCore::Attendee::PartStat::None);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            ::KCalendarCore::Attendee::Role cppArg4(KCalendarCore::Attendee::Role::ReqParticipant);
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QString cppArg5 = QString();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Attendee::Attendee(const QString&,const QString&,bool=,KCalendarCore::Attendee::PartStat=,KCalendarCore::Attendee::Role=,const QString&=)
                cptr = new ::KCalendarCore::Attendee(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::KCalendarCore::Attendee >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_RSVP(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::RSVP()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->RSVP();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_cuType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::cuType()const->KCalendarCore::Attendee::CuType
        KCalendarCore::Attendee::CuType cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->cuType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_CuType_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_cuTypeStr(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::cuTypeStr()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->cuTypeStr();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_customProperties(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::customProperties()->KCalendarCore::CustomProperties&
        KCalendarCore::CustomProperties & cppResult = cppSelf->customProperties();
        pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_delegate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::delegate()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->delegate();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_delegator(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::delegator()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->delegator();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_email(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::email()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->email();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_fullName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::fullName()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->fullName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::isNull()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::name()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->name();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_role(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::role()const->KCalendarCore::Attendee::Role
        KCalendarCore::Attendee::Role cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->role();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_Role_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_setCuType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attendee::setCuType(KCalendarCore::Attendee::CuType)
    // 1: Attendee::setCuType(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // Attendee::setCuType(const QString&)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_CuType_IDX]))), (pyArg)))) {
        overloadId = 0; // Attendee::setCuType(KCalendarCore::Attendee::CuType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCuType", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setCuType(KCalendarCore::Attendee::CuType cuType)
        {
            ::KCalendarCore::Attendee::CuType cppArg0{KCalendarCore::Attendee::Individual};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Attendee::setCuType(KCalendarCore::Attendee::CuType)
                cppSelf->setCuType(cppArg0);
            }
            break;
        }
        case 1: // setCuType(const QString &cuType)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Attendee::setCuType(const QString&)
                cppSelf->setCuType(cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_setCustomProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setCustomProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Attendee::setCustomProperty(const QByteArray&,const QString&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // Attendee::setCustomProperty(const QByteArray&,const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCustomProperty", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Attendee::setCustomProperty(const QByteArray&,const QString&)
            cppSelf->setCustomProperty(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_setDelegate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attendee::setDelegate(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Attendee::setDelegate(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDelegate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Attendee::setDelegate(const QString&)
            cppSelf->setDelegate(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_setDelegator(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attendee::setDelegator(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Attendee::setDelegator(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDelegator", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Attendee::setDelegator(const QString&)
            cppSelf->setDelegator(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_setEmail(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attendee::setEmail(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Attendee::setEmail(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEmail", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Attendee::setEmail(const QString&)
            cppSelf->setEmail(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attendee::setName(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Attendee::setName(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setName", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Attendee::setName(const QString&)
            cppSelf->setName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_setRSVP(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attendee::setRSVP(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Attendee::setRSVP(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRSVP", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Attendee::setRSVP(bool)
            cppSelf->setRSVP(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_setRole(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attendee::setRole(KCalendarCore::Attendee::Role)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_Role_IDX]))), (pyArg)))) {
        overloadId = 0; // Attendee::setRole(KCalendarCore::Attendee::Role)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRole", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    // Call function/method
    {
        ::KCalendarCore::Attendee::Role cppArg0{KCalendarCore::Attendee::ReqParticipant};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Attendee::setRole(KCalendarCore::Attendee::Role)
            cppSelf->setRole(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_setStatus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attendee::setStatus(KCalendarCore::Attendee::PartStat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_PartStat_IDX]))), (pyArg)))) {
        overloadId = 0; // Attendee::setStatus(KCalendarCore::Attendee::PartStat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStatus", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    // Call function/method
    {
        ::KCalendarCore::Attendee::PartStat cppArg0{KCalendarCore::Attendee::NeedsAction};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Attendee::setStatus(KCalendarCore::Attendee::PartStat)
            cppSelf->setStatus(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_setUid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attendee::setUid(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Attendee::setUid(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUid", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Attendee::setUid(const QString&)
            cppSelf->setUid(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::status()const->KCalendarCore::Attendee::PartStat
        KCalendarCore::Attendee::PartStat cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->status();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_PartStat_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc_uid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attendee::uid()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Attendee *>(cppSelf)->uid();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_Attendee__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_KCalendarCore_Attendee_PropertyStrings[] = {
    "cuType::",
    "delegate::",
    "delegator::",
    "email::",
    "fullName:",
    "isNull:",
    "name::",
    "role::",
    "rsvp:RSVP:setRSVP",
    "status::",
    "uid::",
    nullptr // Sentinel
};

static const char *Sbk_KCalendarCore_Attendee_EnumFlagInfo[] = {
    "CuType:IntEnum",
    "PartStat:IntEnum",
    "Role:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_Attendee_methods[] = {
    {"RSVP", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_RSVP), METH_NOARGS, nullptr},
    {"cuType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_cuType), METH_NOARGS, nullptr},
    {"cuTypeStr", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_cuTypeStr), METH_NOARGS, nullptr},
    {"customProperties", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_customProperties), METH_NOARGS, nullptr},
    {"delegate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_delegate), METH_NOARGS, nullptr},
    {"delegator", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_delegator), METH_NOARGS, nullptr},
    {"email", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_email), METH_NOARGS, nullptr},
    {"fullName", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_fullName), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_isNull), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_name), METH_NOARGS, nullptr},
    {"role", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_role), METH_NOARGS, nullptr},
    {"setCuType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_setCuType), METH_O, nullptr},
    {"setCustomProperty", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_setCustomProperty), METH_VARARGS, nullptr},
    {"setDelegate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_setDelegate), METH_O, nullptr},
    {"setDelegator", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_setDelegator), METH_O, nullptr},
    {"setEmail", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_setEmail), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_setName), METH_O, nullptr},
    {"setRSVP", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_setRSVP), METH_O, nullptr},
    {"setRole", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_setRole), METH_O, nullptr},
    {"setStatus", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_setStatus), METH_O, nullptr},
    {"setUid", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_setUid), METH_O, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_status), METH_NOARGS, nullptr},
    {"uid", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_AttendeeFunc_uid), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_Attendee__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_KCalendarCore_AttendeeFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: Attendee::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // Attendee::operator<<(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Attendee::operator<<(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_AttendeeFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: Attendee::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // Attendee::operator>>(QDataStream&)->QDataStream& [free reverse operator]
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Attendee::operator>>(QDataStream&)->QDataStream& [free reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    return Sbk_ReturnFromPython_Result(pyResult);
}

// Rich comparison
static PyObject * Sbk_KCalendarCore_Attendee_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), (pyArg)))) {
                // Attendee::operator!=(const KCalendarCore::Attendee&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::Attendee cppArg0_local;
                ::KCalendarCore::Attendee *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), (pyArg)))) {
                // Attendee::operator==(const KCalendarCore::Attendee&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::Attendee cppArg0_local;
                ::KCalendarCore::Attendee *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_KCalendarCore_Attendee_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_Attendee_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_Attendee_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_Attendee_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_Attendee_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_KCalendarCore_Attendee_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_Attendee_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_Attendee_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_AttendeeFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_KCalendarCore_AttendeeFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_Attendee_spec = {
    "1:KCalendarCore.KCalendarCore.Attendee",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_Attendee_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_KCalendarCore_Attendee_PartStat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::Attendee::PartStat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::Attendee::PartStat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_Attendee_PartStat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_PartStat_IDX])))
        return Enum_PythonToCpp_KCalendarCore_Attendee_PartStat;
    return {};
}

static PyObject *KCalendarCore_Attendee_PartStat_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::Attendee::PartStat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::Attendee::PartStat *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_Attendee_Role(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::Attendee::Role>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::Attendee::Role *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_Attendee_Role_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_Role_IDX])))
        return Enum_PythonToCpp_KCalendarCore_Attendee_Role;
    return {};
}

static PyObject *KCalendarCore_Attendee_Role_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::Attendee::Role>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::Attendee::Role *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_Attendee_CuType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::Attendee::CuType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::Attendee::CuType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_Attendee_CuType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_CuType_IDX])))
        return Enum_PythonToCpp_KCalendarCore_Attendee_CuType;
    return {};
}

static PyObject *KCalendarCore_Attendee_CuType_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::Attendee::CuType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::Attendee::CuType *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Attendee_PythonToCpp_Attendee_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_Attendee_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Attendee_PythonToCpp_Attendee_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_Attendee_TypeF()))
        return Attendee_PythonToCpp_Attendee_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Attendee_PTR_CppToPython_Attendee(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_Attendee_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_KCalendarCore_Attendee_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *Attendee_COPY_CppToPython_Attendee(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::KCalendarCore::Attendee *>(cppIn);
    return Shiboken::Object::newObject(Sbk_KCalendarCore_Attendee_TypeF(), new ::KCalendarCore::Attendee(*source), true, true);
}

// Python to C++ copy conversion.
static void Attendee_PythonToCpp_Attendee_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::KCalendarCore::Attendee *>(cppOut) = *reinterpret_cast< ::KCalendarCore::Attendee *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Attendee_PythonToCpp_Attendee_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_Attendee_TypeF()))
        return Attendee_PythonToCpp_Attendee_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_Attendee_SignatureStrings[] = {
    "2:KCalendarCore.KCalendarCore.Attendee(self,*:KeywordOnly=None,isNull:bool=None,name:QString=None,fullName:QString=None,email:QString=None,role:KCalendarCore.KCalendarCore.Attendee.Role=None,uid:QString=None,status:KCalendarCore.KCalendarCore.Attendee.PartStat=None,cuType:KCalendarCore.KCalendarCore.Attendee.CuType=None,rsvp:bool=None,delegate:QString=None,delegator:QString=None)",
    "1:KCalendarCore.KCalendarCore.Attendee(self,attendee:KCalendarCore.KCalendarCore.Attendee,*:KeywordOnly=None,isNull:bool=None,name:QString=None,fullName:QString=None,email:QString=None,role:KCalendarCore.KCalendarCore.Attendee.Role=None,uid:QString=None,status:KCalendarCore.KCalendarCore.Attendee.PartStat=None,cuType:KCalendarCore.KCalendarCore.Attendee.CuType=None,rsvp:bool=None,delegate:QString=None,delegator:QString=None)",
    "0:KCalendarCore.KCalendarCore.Attendee(self,name:QString,email:QString,rsvp:bool=false,status:KCalendarCore.KCalendarCore.Attendee.PartStat=KCalendarCore.Attendee.PartStat.None,role:KCalendarCore.KCalendarCore.Attendee.Role=KCalendarCore.Attendee.Role.ReqParticipant,uid:QString=QString(),*:KeywordOnly=None,isNull:bool=None,name:QString=None,fullName:QString=None,email:QString=None,role:KCalendarCore.KCalendarCore.Attendee.Role=None,uid:QString=None,status:KCalendarCore.KCalendarCore.Attendee.PartStat=None,cuType:KCalendarCore.KCalendarCore.Attendee.CuType=None,rsvp:bool=None,delegate:QString=None,delegator:QString=None)",
    "KCalendarCore.KCalendarCore.Attendee.RSVP(self)->bool",
    "KCalendarCore.KCalendarCore.Attendee.cuType(self)->KCalendarCore.KCalendarCore.Attendee.CuType",
    "KCalendarCore.KCalendarCore.Attendee.cuTypeStr(self)->QString",
    "KCalendarCore.KCalendarCore.Attendee.customProperties(self)->KCalendarCore.KCalendarCore.CustomProperties",
    "KCalendarCore.KCalendarCore.Attendee.delegate(self)->QString",
    "KCalendarCore.KCalendarCore.Attendee.delegator(self)->QString",
    "KCalendarCore.KCalendarCore.Attendee.email(self)->QString",
    "KCalendarCore.KCalendarCore.Attendee.fullName(self)->QString",
    "KCalendarCore.KCalendarCore.Attendee.isNull(self)->bool",
    "KCalendarCore.KCalendarCore.Attendee.name(self)->QString",
    "KCalendarCore.KCalendarCore.Attendee.role(self)->KCalendarCore.KCalendarCore.Attendee.Role",
    "1:KCalendarCore.KCalendarCore.Attendee.setCuType(self,cuType:KCalendarCore.KCalendarCore.Attendee.CuType)",
    "0:KCalendarCore.KCalendarCore.Attendee.setCuType(self,cuType:QString)",
    "KCalendarCore.KCalendarCore.Attendee.setCustomProperty(self,xname:typing.Union[PySide6.QtCore.QByteArray, char*],xvalue:QString)",
    "KCalendarCore.KCalendarCore.Attendee.setDelegate(self,delegate:QString)",
    "KCalendarCore.KCalendarCore.Attendee.setDelegator(self,delegator:QString)",
    "KCalendarCore.KCalendarCore.Attendee.setEmail(self,email:QString)",
    "KCalendarCore.KCalendarCore.Attendee.setName(self,name:QString)",
    "KCalendarCore.KCalendarCore.Attendee.setRSVP(self,rsvp:bool)",
    "KCalendarCore.KCalendarCore.Attendee.setRole(self,role:KCalendarCore.KCalendarCore.Attendee.Role)",
    "KCalendarCore.KCalendarCore.Attendee.setStatus(self,status:KCalendarCore.KCalendarCore.Attendee.PartStat)",
    "KCalendarCore.KCalendarCore.Attendee.setUid(self,uid:QString)",
    "KCalendarCore.KCalendarCore.Attendee.status(self)->KCalendarCore.KCalendarCore.Attendee.PartStat",
    "KCalendarCore.KCalendarCore.Attendee.uid(self)->QString",
    "KCalendarCore.KCalendarCore.Attendee.__copy__(self)->typing._Self",
    "KCalendarCore.KCalendarCore.Attendee.__lshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.Attendee.__rshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "KCalendarCore.KCalendarCore.Attendee.__ne__(self,attendee:KCalendarCore.KCalendarCore.Attendee)->bool",
    "KCalendarCore.KCalendarCore.Attendee.__eq__(self,attendee:KCalendarCore.KCalendarCore.Attendee)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_Attendee_SignatureByteSize = 516;
static constexpr uint8_t KCalendarCore_Attendee_SignatureBytes[516] = {
    0x78, 0xda, 0xed, 0x57, 0x3d, 0x4f, 0xc3, 0x30, 0x10, 0xdd, 0xf9, 0x15, 0x8c, 0x14, 0x95, 0x08,
    0x18, 0x18, 0x22, 0x81, 0x04, 0x81, 0x09, 0xa9, 0xb4, 0x04, 0x58, 0x10, 0x8a, 0x4c, 0x73, 0x05,
    0x4b, 0xae, 0x1d, 0x6c, 0x07, 0xf0, 0xbf, 0xc7, 0x8d, 0x9d, 0x36, 0x69, 0x05, 0x9c, 0x0d, 0x12,
    0x0b, 0x53, 0xe4, 0x8f, 0xf7, 0xde, 0x9d, 0xef, 0x4b, 0x39, 0x4c, 0x2f, 0x33, 0xc2, 0x80, 0x97,
    0x44, 0x66, 0x42, 0x42, 0xd2, 0x5f, 0x9d, 0x6a, 0x6d, 0x17, 0x00, 0x3b, 0x0a, 0xd8, 0x6c, 0xb8,
    0x9b, 0x5e, 0x82, 0x79, 0x13, 0xb2, 0xbc, 0xe2, 0xcc, 0x1c, 0x8f, 0x04, 0x87, 0x21, 0x55, 0xa3,
    0x9a, 0xb1, 0xf4, 0x51, 0x08, 0xe6, 0x36, 0x38, 0x99, 0x43, 0x3a, 0xc9, 0xb5, 0xa4, 0xfc, 0xc9,
    0xed, 0xcc, 0xec, 0x85, 0xd1, 0xc6, 0x2e, 0xcc, 0x09, 0x65, 0xfd, 0x2d, 0x29, 0x18, 0xa0, 0xac,
    0x49, 0xae, 0xed, 0x4d, 0x87, 0xa9, 0x69, 0xd9, 0x27, 0x51, 0x9a, 0xe8, 0x5a, 0xe1, 0x68, 0xc6,
    0x44, 0xea, 0xdc, 0xde, 0x77, 0xc8, 0x69, 0x7d, 0x63, 0x2a, 0xa4, 0x01, 0x59, 0x73, 0xd7, 0x9b,
    0xad, 0x5e, 0xab, 0xce, 0x03, 0x94, 0xc0, 0xe0, 0x89, 0xe8, 0x35, 0x77, 0xfd, 0xae, 0x90, 0xbd,
    0xed, 0xc1, 0xd6, 0x41, 0xc0, 0xf3, 0x13, 0xbf, 0x42, 0x41, 0xfe, 0x83, 0xf5, 0xfb, 0xc1, 0xda,
    0x0f, 0x08, 0x56, 0xf7, 0x69, 0xfb, 0xef, 0xd7, 0xb1, 0x61, 0x46, 0x98, 0x8a, 0x7c, 0x85, 0x6f,
    0xce, 0x93, 0x98, 0x20, 0x7d, 0x71, 0x96, 0x5c, 0xc3, 0xcb, 0x82, 0x9b, 0x4e, 0x69, 0x45, 0xb8,
    0xee, 0x85, 0xd2, 0x7f, 0x77, 0x06, 0xff, 0x39, 0xf7, 0xfb, 0x39, 0x87, 0x73, 0x37, 0xbf, 0x1b,
    0x37, 0x69, 0x37, 0xd8, 0x3b, 0x59, 0x08, 0xe1, 0x50, 0xce, 0x9f, 0x16, 0x17, 0xe0, 0x56, 0x08,
    0xbd, 0x75, 0xa6, 0x55, 0xf0, 0x8e, 0x61, 0xd1, 0x4a, 0x8b, 0xf9, 0x58, 0x8a, 0x0a, 0x6c, 0xd6,
    0x81, 0xc2, 0x98, 0x99, 0xad, 0x61, 0x70, 0x4a, 0x6d, 0x3c, 0xa2, 0xcc, 0x5c, 0x86, 0x2d, 0x0a,
    0xdd, 0xe4, 0x78, 0x14, 0xb2, 0xad, 0x99, 0x28, 0xb0, 0xab, 0xc9, 0xf0, 0x84, 0xe1, 0xb1, 0x82,
    0x8b, 0xc2, 0x0d, 0xca, 0xb3, 0x45, 0xfd, 0x22, 0x67, 0x63, 0xa2, 0x40, 0x67, 0xab, 0x4c, 0x8e,
    0xa8, 0x52, 0x6c, 0x63, 0xff, 0x44, 0xc9, 0xbf, 0x04, 0xb2, 0x54, 0x1b, 0x8e, 0x4e, 0x9a, 0x1a,
    0xc7, 0xf5, 0xde, 0xb4, 0x45, 0x6d, 0x2a, 0xcb, 0x94, 0xdc, 0x72, 0x2a, 0xf8, 0xfd, 0xd8, 0xe4,
    0xb4, 0x84, 0xa3, 0x64, 0xa2, 0x1b, 0x86, 0xc9, 0x99, 0xd1, 0x70, 0x2a, 0x25, 0x31, 0xc3, 0xed,
    0xe9, 0x33, 0x91, 0xbb, 0x0f, 0xc3, 0xf7, 0x57, 0xc2, 0xea, 0x08, 0x03, 0xce, 0xbb, 0x19, 0xbf,
    0xd1, 0x8f, 0x82, 0x79, 0x7c, 0xf2, 0x6f, 0xb6, 0x30, 0x3c, 0xd3, 0xc5, 0xb2, 0x10, 0xfa, 0x7d,
    0x1f, 0xcf, 0xb0, 0x2c, 0x86, 0xde, 0x80, 0xc1, 0xe3, 0x97, 0x2d, 0x74, 0xd5, 0xae, 0x03, 0xc0,
    0x6d, 0x7e, 0x07, 0x8e, 0x28, 0xbc, 0x42, 0xde, 0x4c, 0x2d, 0xa7, 0x11, 0x33, 0xc1, 0xf0, 0x4a,
    0xb7, 0xb4, 0x74, 0x32, 0x9d, 0xc9, 0x89, 0x45, 0xaf, 0x8c, 0xc4, 0x16, 0x7a, 0x6b, 0x1f, 0x4e,
    0xa0, 0xf6, 0xb6, 0x85, 0xf6, 0x9f, 0xa2, 0x98, 0x8a, 0xca, 0x14, 0x45, 0x0b, 0xf6, 0x75, 0x56,
    0xe4, 0x76, 0x89, 0x65, 0x60, 0xea, 0x99, 0xce, 0xb4, 0xe7, 0xb0, 0x31, 0x90, 0x40, 0xe6, 0xe9,
    0x7a, 0x8d, 0x9e, 0x13, 0x4d, 0xf2, 0xe6, 0xc8, 0xaa, 0x7c, 0x7e, 0x88, 0xd5, 0x94, 0x7f, 0xa0,
    0xc9, 0xa1, 0xd5, 0x0b, 0xfa, 0xdf, 0x08, 0x1a, 0x24, 0x45, 0x01, 0x2f, 0x3f, 0x52, 0xf9, 0x00,
    0x93, 0x95, 0x5f, 0x9c
};
#endif

PyTypeObject *init_KCalendarCore_Attendee(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = SbkObject_TypeF();
    Shiboken::AutoDecRef Sbk_KCalendarCore_Attendee_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Attendee",
        "KCalendarCore::Attendee",
        &Sbk_KCalendarCore_Attendee_spec,
        &Shiboken::callCppDestructor< ::KCalendarCore::Attendee >,
        Sbk_KCalendarCore_Attendee_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_Attendee_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_Attendee_SignatureBytes, KCalendarCore_Attendee_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_Attendee_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Attendee_PythonToCpp_Attendee_PTR,
        is_Attendee_PythonToCpp_Attendee_PTR_Convertible,
        Attendee_PTR_CppToPython_Attendee,
        Attendee_COPY_CppToPython_Attendee);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Attendee");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Attendee*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Attendee&");
    Shiboken::Conversions::registerConverterAlias(converter, "Attendee");
    Shiboken::Conversions::registerConverterAlias(converter, "Attendee*");
    Shiboken::Conversions::registerConverterAlias(converter, "Attendee&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::Attendee).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Attendee_PythonToCpp_Attendee_COPY,
        is_Attendee_PythonToCpp_Attendee_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_KCalendarCore_Attendee_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'PartStat'.
    const char *PartStat_Initializer[] = {
        "NeedsAction",
        "Accepted",
        "Declined",
        "Tentative",
        "Delegated",
        "Completed",
        "InProcess",
        "None_",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PartStat_InitializerValues[] = {
        uint8_t(KCalendarCore::Attendee::PartStat::NeedsAction), //  0x00  0
        uint8_t(KCalendarCore::Attendee::PartStat::Accepted),    //  0x01  1
        uint8_t(KCalendarCore::Attendee::PartStat::Declined),    //  0x02  2
        uint8_t(KCalendarCore::Attendee::PartStat::Tentative),   //  0x03  3
        uint8_t(KCalendarCore::Attendee::PartStat::Delegated),   //  0x04  4
        uint8_t(KCalendarCore::Attendee::PartStat::Completed),   //  0x05  5
        uint8_t(KCalendarCore::Attendee::PartStat::InProcess),   //  0x06  6
        uint8_t(KCalendarCore::Attendee::PartStat::None)         //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.Attendee.PartStat",
        PartStat_Initializer, PartStat_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_PartStat_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::Attendee::PartStat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_Attendee_PartStat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_Attendee_PartStat,
            is_Enum_PythonToCpp_KCalendarCore_Attendee_PartStat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Attendee::PartStat");
        Shiboken::Conversions::registerConverterAlias(converter, "Attendee::PartStat");
        Shiboken::Conversions::registerConverterAlias(converter, "PartStat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PartStat' enum.

    // Initialization of enum 'Role'.
    const char *Role_Initializer[] = {
        "ReqParticipant",
        "OptParticipant",
        "NonParticipant",
        "Chair",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Role_InitializerValues[] = {
        uint8_t(KCalendarCore::Attendee::Role::ReqParticipant), //  0x00  0
        uint8_t(KCalendarCore::Attendee::Role::OptParticipant), //  0x01  1
        uint8_t(KCalendarCore::Attendee::Role::NonParticipant), //  0x02  2
        uint8_t(KCalendarCore::Attendee::Role::Chair)           //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.Attendee.Role",
        Role_Initializer, Role_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_Role_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::Attendee::Role'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_Attendee_Role_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_Attendee_Role,
            is_Enum_PythonToCpp_KCalendarCore_Attendee_Role_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Attendee::Role");
        Shiboken::Conversions::registerConverterAlias(converter, "Attendee::Role");
        Shiboken::Conversions::registerConverterAlias(converter, "Role");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Role' enum.

    // Initialization of enum 'CuType'.
    const char *CuType_Initializer[] = {
        "Individual",
        "Group",
        "Resource",
        "Room",
        "Unknown",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CuType_InitializerValues[] = {
        uint8_t(KCalendarCore::Attendee::CuType::Individual), //  0x00  0
        uint8_t(KCalendarCore::Attendee::CuType::Group),      //  0x01  1
        uint8_t(KCalendarCore::Attendee::CuType::Resource),   //  0x02  2
        uint8_t(KCalendarCore::Attendee::CuType::Room),       //  0x03  3
        uint8_t(KCalendarCore::Attendee::CuType::Unknown)     //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.Attendee.CuType",
        CuType_Initializer, CuType_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_CuType_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::Attendee::CuType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_Attendee_CuType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_Attendee_CuType,
            is_Enum_PythonToCpp_KCalendarCore_Attendee_CuType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Attendee::CuType");
        Shiboken::Conversions::registerConverterAlias(converter, "Attendee::CuType");
        Shiboken::Conversions::registerConverterAlias(converter, "CuType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CuType' enum.

    qRegisterMetaType< ::KCalendarCore::Attendee >("Attendee");
    qRegisterMetaType< ::KCalendarCore::Attendee >("KCalendarCore::Attendee");
    qRegisterMetaType< ::KCalendarCore::Attendee::PartStat >("Attendee::PartStat");
    qRegisterMetaType< ::KCalendarCore::Attendee::PartStat >("KCalendarCore::Attendee::PartStat");
    qRegisterMetaType< ::KCalendarCore::Attendee::Role >("Attendee::Role");
    qRegisterMetaType< ::KCalendarCore::Attendee::Role >("KCalendarCore::Attendee::Role");
    qRegisterMetaType< ::KCalendarCore::Attendee::CuType >("Attendee::CuType");
    qRegisterMetaType< ::KCalendarCore::Attendee::CuType >("KCalendarCore::Attendee::CuType");

    return pyType;
}
